# دليل التثبيت التلقائي - نظام إدارة التدريب المحسن

## نظرة عامة
يوفر نظام إدارة التدريب الآن ملف تثبيت تلقائي (`install.php`) يجعل عملية التثبيت سهلة وسريعة. لا تحتاج لتنفيذ أوامر SQL يدوياً أو إعداد ملفات الإعدادات بنفسك.

## التثبيت التلقائي (الطريقة المُوصى بها)

### الخطوة 1: رفع الملفات
1. قم بتحميل جميع ملفات المشروع إلى مجلد `td` على الخادم
2. تأكد من رفع جميع الملفات بما في ذلك:
   - `install.php`
   - `seed.sql`
   - `database_updates.sql`
   - `security_updates.sql`
   - جميع المجلدات والملفات الأخرى

### الخطوة 2: الوصول لملف التثبيت
1. افتح المتصفح واذهب إلى: `http://yourdomain.com/td/install.php`
2. ستظهر لك واجهة التثبيت التلقائي

### الخطوة 3: اتباع معالج التثبيت

#### الخطوة الأولى: التحقق من المتطلبات
- سيتم فحص جميع المتطلبات تلقائياً
- تأكد من أن جميع العناصر تظهر بعلامة ✅
- إذا ظهرت أي مشاكل، قم بحلها قبل المتابعة

#### الخطوة الثانية: إعدادات قاعدة البيانات
أدخل البيانات التالية:

**بيانات قاعدة البيانات:**
- خادم قاعدة البيانات: `localhost` (عادة)
- المنفذ: `3306` (افتراضي)
- اسم قاعدة البيانات: اسم قاعدة البيانات المطلوبة
- اسم المستخدم: اسم مستخدم قاعدة البيانات
- كلمة المرور: كلمة مرور قاعدة البيانات

**حساب المدير:**
- البريد الإلكتروني: البريد الإلكتروني لحساب المدير
- كلمة المرور: كلمة مرور قوية (8 أحرف على الأقل)

#### الخطوة الثالثة: تأكيد التثبيت
- راجع الإعدادات المدخلة
- اضغط "بدء التثبيت"

#### الخطوة الرابعة: اكتمال التثبيت
- ستظهر رسالة نجاح التثبيت
- سيتم إنشاء جميع الجداول والإعدادات تلقائياً

### الخطوة 4: ما بعد التثبيت
1. **احذف ملف التثبيت**: `rm install.php` (لأسباب أمنية)
2. **تسجيل الدخول**: اذهب إلى `login.php` واستخدم بيانات المدير
3. **تحقق من حالة النظام**: زر `system_status.php` للتأكد من سلامة التثبيت

## الميزات الجديدة في ملف التثبيت

### 1. التحقق التلقائي من المتطلبات
- فحص إصدار PHP
- فحص امتدادات PHP المطلوبة
- فحص أذونات الكتابة
- فحص اتصال قاعدة البيانات

### 2. إنشاء قاعدة البيانات تلقائياً
- إنشاء قاعدة البيانات إذا لم تكن موجودة
- تنفيذ جميع ملفات SQL بالترتيب الصحيح
- إنشاء حساب المدير الأول

### 3. إعداد الملفات والمجلدات
- إنشاء ملف `includes/db.php` تلقائياً
- إنشاء المجلدات المطلوبة (`uploads`, `cache`, `backups`)
- إعداد ملف `.htaccess` للأمان
- إنشاء ملف علامة التثبيت

### 4. الحماية الأمنية
- منع الوصول لملف التثبيت بعد اكتمال التثبيت
- حماية الملفات الحساسة
- تشفير كلمات المرور
- إعداد رؤوس الأمان

## التثبيت اليدوي (للمطورين المتقدمين)

إذا كنت تفضل التثبيت اليدوي، يمكنك اتباع الخطوات التالية:

### 1. تحضير البيئة
```bash
# إنشاء مجلد المشروع
mkdir /var/www/td_project
cd /var/www/td_project

# نسخ ملفات المشروع
# (نسخ جميع الملفات من المجلد المضغوط)

# إعداد الأذونات
chmod -R 755 .
chmod -R 777 cache
chmod -R 777 uploads
chmod 600 includes/db.php
```

### 2. إعداد قاعدة البيانات
```sql
-- إنشاء قاعدة البيانات
CREATE DATABASE td_db CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

-- إنشاء مستخدم قاعدة البيانات
CREATE USER 'td_user'@'localhost' IDENTIFIED BY 'secure_password_here';
GRANT ALL PRIVILEGES ON td_db.* TO 'td_user'@'localhost';
FLUSH PRIVILEGES;
```

### 3. تنفيذ ملفات قاعدة البيانات
```bash
# تنفيذ الجداول الأساسية
mysql -u td_user -p td_db < seed.sql

# تنفيذ تحديثات ميزة أولياء الأمور
mysql -u td_user -p td_db < database_updates.sql

# تنفيذ تحديثات الأمان
mysql -u td_user -p td_db < security_updates.sql
```

### 4. تحديث إعدادات الاتصال
```php
// تحديث ملف includes/db.php
<?php
$host = 'localhost';
$dbname = 'td_db';
$username = 'td_user';
$password = 'secure_password_here';

try {
    $pdo = new PDO("mysql:host=$host;dbname=$dbname;charset=utf8mb4", $username, $password);
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
} catch (PDOException $e) {
    die("فشل الاتصال بقاعدة البيانات");
}
?>
```

### 5. إعداد الخادم (Apache)
```apache
# إنشاء ملف .htaccess في المجلد الجذر
RewriteEngine On

# إعادة توجيه HTTP إلى HTTPS (اختياري)
RewriteCond %{HTTPS} off
RewriteRule ^(.*)$ https://%{HTTP_HOST}%{REQUEST_URI} [L,R=301]

# حماية الملفات الحساسة
<Files "*.sql">
    Order allow,deny
    Deny from all
</Files>

<Files "*.md">
    Order allow,deny
    Deny from all
</Files>

# تفعيل الضغط
<IfModule mod_deflate.c>
    AddOutputFilterByType DEFLATE text/plain
    AddOutputFilterByType DEFLATE text/html
    AddOutputFilterByType DEFLATE text/xml
    AddOutputFilterByType DEFLATE text/css
    AddOutputFilterByType DEFLATE application/xml
    AddOutputFilterByType DEFLATE application/xhtml+xml
    AddOutputFilterByType DEFLATE application/rss+xml
    AddOutputFilterByType DEFLATE application/javascript
    AddOutputFilterByType DEFLATE application/x-javascript
</IfModule>

# تعيين رؤوس التخزين المؤقت
<IfModule mod_expires.c>
    ExpiresActive on
    ExpiresByType text/css "access plus 1 year"
    ExpiresByType application/javascript "access plus 1 year"
    ExpiresByType image/png "access plus 1 year"
    ExpiresByType image/jpg "access plus 1 year"
    ExpiresByType image/jpeg "access plus 1 year"
    ExpiresByType image/gif "access plus 1 year"
    ExpiresByType image/svg+xml "access plus 1 year"
</IfModule>
```

## تحديث النظام الحالي

### 1. نسخ احتياطية
```bash
# نسخة احتياطية من قاعدة البيانات
mysqldump -u td_user -p td_db > backup_$(date +%Y%m%d_%H%M%S).sql

# نسخة احتياطية من الملفات
tar -czf backup_files_$(date +%Y%m%d_%H%M%S).tar.gz /var/www/td_project
```

### 2. تحديث الملفات
```bash
# نسخ الملفات الجديدة (تجنب الكتابة فوق includes/db.php)
cp -r new_files/* /var/www/td_project/
# تأكد من عدم الكتابة فوق إعدادات قاعدة البيانات الحالية
```

### 3. تنفيذ تحديثات قاعدة البيانات
```bash
# تنفيذ التحديثات الجديدة فقط
mysql -u td_user -p td_db < database_updates.sql
mysql -u td_user -p td_db < security_updates.sql
```

### 4. التحقق من التحديث
```bash
# التحقق من الجداول الجديدة
mysql -u td_user -p td_db -e "SHOW TABLES LIKE 'parents';"
mysql -u td_user -p td_db -e "SHOW TABLES LIKE 'student_parent';"
```

## إعداد المهام المجدولة (Cron Jobs)

### 1. إنشاء ملفات المهام
```php
// إنشاء ملف cleanup_cache.php
<?php
require_once '/var/www/td_project/includes/cache.php';
cleanup_cache();
echo "Cache cleanup completed at " . date('Y-m-d H:i:s') . "\n";
?>
```

```php
// إنشاء ملف optimize_database.php
<?php
require_once '/var/www/td_project/includes/db.php';
require_once '/var/www/td_project/includes/performance.php';

$optimizer = new DatabaseOptimizer($pdo);
$optimizer->analyzeTables();
$optimizer->optimizeTables();
echo "Database optimization completed at " . date('Y-m-d H:i:s') . "\n";
?>
```

### 2. إضافة المهام إلى Cron
```bash
# تحرير crontab
crontab -e

# إضافة المهام التالية:
# تنظيف التخزين المؤقت يومياً في الساعة 2:00 صباحاً
0 2 * * * /usr/bin/php /var/www/td_project/cleanup_cache.php >> /var/log/td_cleanup.log 2>&1

# تنظيف البيانات القديمة أسبوعياً يوم الأحد في الساعة 3:00 صباحاً
0 3 * * 0 /usr/bin/mysql -u td_user -p'password' td_db -e "CALL CleanupOldData();" >> /var/log/td_cleanup.log 2>&1

# تحسين قاعدة البيانات شهرياً في اليوم الأول من كل شهر في الساعة 4:00 صباحاً
0 4 1 * * /usr/bin/php /var/www/td_project/optimize_database.php >> /var/log/td_optimization.log 2>&1

# نسخة احتياطية يومية في الساعة 1:00 صباحاً
0 1 * * * /usr/bin/mysqldump -u td_user -p'password' td_db > /var/backups/td_backup_$(date +\%Y\%m\%d).sql
```

## إعداد الأمان

### 1. إعداد SSL/HTTPS
```bash
# الحصول على شهادة SSL (Let's Encrypt)
sudo apt install certbot python3-certbot-apache
sudo certbot --apache -d yourdomain.com
```

### 2. تحديث كلمات المرور الافتراضية
```sql
-- تحديث كلمة مرور المدير الافتراضية
UPDATE distributors SET password = '$2y$10$newhashedpassword' WHERE email = 'admin@example.com';

-- تحديث كلمات مرور أولياء الأمور التجريبية
UPDATE parents SET password = '$2y$10$newhashedpassword' WHERE email LIKE '%@example.com';
```

### 3. إعداد جدار الحماية
```bash
# تفعيل UFW
sudo ufw enable

# السماح بـ HTTP و HTTPS
sudo ufw allow 80
sudo ufw allow 443

# السماح بـ SSH (إذا لزم الأمر)
sudo ufw allow 22
```

## اختبار النظام

### 1. اختبار تسجيل الدخول
```bash
# اختبار تسجيل دخول المدير
# URL: https://yourdomain.com/login.php
# اختر "مدير" وأدخل بيانات الاعتماد

# اختبار تسجيل دخول المعلم
# اختر "معلم" وأدخل بيانات الاعتماد

# اختبار تسجيل دخول ولي الأمر
# اختر "ولي أمر" وأدخل بيانات الاعتماد التجريبية
```

### 2. اختبار ميزة أولياء الأمور
1. تسجيل دخول كمعلم
2. الذهاب إلى "إدارة أولياء الأمور"
3. إضافة ولي أمر جديد
4. ربط طالب بولي الأمر
5. تسجيل دخول كولي أمر والتحقق من البيانات

### 3. اختبار الأداء
```bash
# اختبار سرعة التحميل
curl -w "@curl-format.txt" -o /dev/null -s "https://yourdomain.com/"

# مراقبة استهلاك الذاكرة
top -p $(pgrep apache2)
```

## استكشاف الأخطاء وإصلاحها

### مشاكل شائعة وحلولها:

#### 1. خطأ في الاتصال بقاعدة البيانات
```bash
# التحقق من حالة MySQL
sudo systemctl status mysql

# التحقق من بيانات الاعتماد
mysql -u td_user -p td_db -e "SELECT 1;"
```

#### 2. مشاكل الأذونات
```bash
# إعادة تعيين الأذونات
sudo chown -R www-data:www-data /var/www/td_project
sudo chmod -R 755 /var/www/td_project
sudo chmod -R 777 /var/www/td_project/cache
sudo chmod -R 777 /var/www/td_project/uploads
```

#### 3. مشاكل التخزين المؤقت
```bash
# مسح التخزين المؤقت يدوياً
rm -rf /var/www/td_project/cache/*
```

#### 4. مشاكل الأداء
```sql
-- التحقق من الاستعلامات البطيئة
SHOW GLOBAL STATUS LIKE 'Slow_queries';

-- تحليل الجداول
ANALYZE TABLE students, teachers, parents;
```

## المراقبة والصيانة

### 1. مراقبة السجلات
```bash
# مراقبة سجلات Apache
tail -f /var/log/apache2/error.log

# مراقبة سجلات PHP
tail -f /var/log/php_errors.log

# مراقبة سجلات MySQL
tail -f /var/log/mysql/error.log
```

### 2. مراقبة الأداء
```bash
# مراقبة استهلاك القرص
df -h

# مراقبة استهلاك الذاكرة
free -h

# مراقبة العمليات
htop
```

### 3. النسخ الاحتياطية التلقائية
```bash
# إنشاء سكريبت النسخ الاحتياطي
#!/bin/bash
DATE=$(date +%Y%m%d_%H%M%S)
BACKUP_DIR="/var/backups/td_project"
mkdir -p $BACKUP_DIR

# نسخة احتياطية من قاعدة البيانات
mysqldump -u td_user -p'password' td_db > $BACKUP_DIR/db_backup_$DATE.sql

# نسخة احتياطية من الملفات
tar -czf $BACKUP_DIR/files_backup_$DATE.tar.gz /var/www/td_project

# حذف النسخ القديمة (أكثر من 30 يوم)
find $BACKUP_DIR -name "*.sql" -mtime +30 -delete
find $BACKUP_DIR -name "*.tar.gz" -mtime +30 -delete

echo "Backup completed: $DATE"
```

## الدعم والمساعدة

### معلومات الاتصال:
- **الوثائق**: راجع ملف `IMPROVEMENTS_SUMMARY.md`
- **السجلات**: تحقق من `/var/log/` للسجلات
- **النسخ الاحتياطية**: موجودة في `/var/backups/td_project/`

### نصائح مهمة:
1. **قم بعمل نسخة احتياطية** قبل أي تحديث
2. **اختبر التحديثات** في بيئة تطوير أولاً
3. **راقب السجلات** بانتظام للتحقق من الأخطاء
4. **حدث كلمات المرور** بانتظام
5. **راقب الأداء** وقم بالتحسين حسب الحاجة

---

تم إعداد هذا الدليل لضمان تثبيت وتشغيل النظام بنجاح. في حالة مواجهة أي مشاكل، راجع قسم استكشاف الأخطاء أو تحقق من السجلات للحصول على مزيد من التفاصيل.



### المتطلبات الأساسية للتثبيت اليدوي:
- **PHP**: الإصدار 7.4 أو أحدث (يُفضل PHP 8.0+)
- **MySQL**: الإصدار 5.7 أو أحدث (يُفضل MySQL 8.0+)
- **Apache/Nginx**: خادم ويب مع دعم mod_rewrite
- **مساحة التخزين**: 500 ميجابايت على الأقل
- **الذاكرة**: 512 ميجابايت RAM على الأقل

### امتدادات PHP المطلوبة:
```bash
php-mysql
php-pdo
php-gd
php-curl
php-mbstring
php-zip
php-xml
php-json
```

### 1. تحضير البيئة
```bash
# إنشاء مجلد المشروع
mkdir /var/www/td
cd /var/www/td

# نسخ ملفات المشروع
# (نسخ جميع الملفات من المجلد المضغوط)

# إعداد الأذونات
chmod -R 755 .
chmod -R 777 cache
chmod -R 777 uploads
chmod 600 includes/db.php
```

### 2. إعداد قاعدة البيانات
```sql
-- إنشاء قاعدة البيانات
CREATE DATABASE td_db CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

-- إنشاء مستخدم قاعدة البيانات
CREATE USER 'td_user'@'localhost' IDENTIFIED BY 'secure_password_here';
GRANT ALL PRIVILEGES ON td_db.* TO 'td_user'@'localhost';
FLUSH PRIVILEGES;
```

### 3. تنفيذ ملفات قاعدة البيانات
```bash
# تنفيذ الجداول الأساسية
mysql -u td_user -p td_db < seed.sql

# تنفيذ تحديثات ميزة أولياء الأمور
mysql -u td_user -p td_db < database_updates.sql

# تنفيذ تحديثات الأمان
mysql -u td_user -p td_db < security_updates.sql
```

### 4. تحديث إعدادات الاتصال
```php
// إنشاء ملف includes/db.php
<?php
$host = 'localhost';
$dbname = 'td_db';
$username = 'td_user';
$password = 'secure_password_here';

try {
    $pdo = new PDO("mysql:host=$host;dbname=$dbname;charset=utf8mb4", $username, $password);
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
} catch (PDOException $e) {
    die("فشل الاتصال بقاعدة البيانات");
}
?>
```

## استكشاف الأخطاء وإصلاحها

### مشاكل شائعة في التثبيت التلقائي:

#### 1. خطأ "النظام مثبت بالفعل"
**الحل:**
```bash
# احذف ملف علامة التثبيت
rm includes/.installed
# أو احذف ملف إعدادات قاعدة البيانات
rm includes/db.php
```

#### 2. خطأ في الاتصال بقاعدة البيانات
**الأسباب المحتملة:**
- بيانات اعتماد خاطئة
- قاعدة البيانات غير موجودة
- خادم MySQL غير متاح

**الحل:**
- تحقق من بيانات الاعتماد
- تأكد من تشغيل خادم MySQL
- تحقق من أذونات المستخدم

#### 3. خطأ في الأذونات
**الحل:**
```bash
# إعادة تعيين الأذونات
sudo chown -R www-data:www-data /var/www/td
sudo chmod -R 755 /var/www/td
sudo chmod -R 777 /var/www/td/cache
sudo chmod -R 777 /var/www/td/uploads
```

#### 4. امتدادات PHP مفقودة
**الحل (Ubuntu/Debian):**
```bash
sudo apt update
sudo apt install php-mysql php-gd php-curl php-mbstring php-zip php-xml
sudo systemctl restart apache2
```

#### 5. خطأ في تنفيذ ملفات SQL
**الحل:**
- تحقق من وجود ملفات SQL في المجلد الجذر
- تأكد من صحة بنية ملفات SQL
- تحقق من أذونات قاعدة البيانات

## التحقق من نجاح التثبيت

### 1. فحص الملفات المطلوبة
```bash
# التحقق من وجود الملفات الأساسية
ls -la includes/db.php
ls -la includes/.installed
ls -la .htaccess
```

### 2. فحص قاعدة البيانات
```sql
-- التحقق من الجداول
USE td_db;
SHOW TABLES;

-- التحقق من حساب المدير
SELECT * FROM distributors WHERE email = 'your_admin_email@example.com';
```

### 3. فحص صفحة حالة النظام
- اذهب إلى: `http://yourdomain.com/td/system_status.php`
- تسجيل دخول كمدير
- تحقق من جميع العناصر تظهر باللون الأخضر

### 4. اختبار تسجيل الدخول
1. اذهب إلى `login.php`
2. اختر "مدير"
3. أدخل بيانات المدير المُنشأة
4. تأكد من الوصول للوحة التحكم

## الصيانة والتحديث

### تحديث النظام
1. **نسخة احتياطية**: قم بعمل نسخة احتياطية كاملة
2. **رفع الملفات الجديدة**: استبدل الملفات القديمة
3. **تنفيذ تحديثات قاعدة البيانات**: إذا لزم الأمر
4. **اختبار النظام**: تأكد من عمل جميع الوظائف

### النسخ الاحتياطية
```bash
# نسخة احتياطية من قاعدة البيانات
mysqldump -u td_user -p td_db > backup_$(date +%Y%m%d_%H%M%S).sql

# نسخة احتياطية من الملفات
tar -czf backup_files_$(date +%Y%m%d_%H%M%S).tar.gz /var/www/td
```

### مراقبة النظام
- راجع سجلات الأخطاء بانتظام
- راقب استهلاك مساحة التخزين
- تحقق من أداء قاعدة البيانات
- راجع تقارير الأمان

## الأمان

### إعدادات الأمان الموصى بها
1. **SSL/HTTPS**: تفعيل شهادة SSL
2. **جدار الحماية**: إعداد قواعد الجدار
3. **تحديث كلمات المرور**: تغيير كلمات المرور الافتراضية
4. **النسخ الاحتياطية**: إعداد نسخ احتياطية دورية
5. **مراقبة السجلات**: مراجعة سجلات النشاط

### حماية ملف التثبيت
بعد اكتمال التثبيت، تأكد من:
```bash
# حذف ملف التثبيت
rm install.php

# أو تعطيل الوصول إليه في .htaccess
echo '<Files "install.php">
    Order allow,deny
    Deny from all
</Files>' >> .htaccess
```

## الدعم والمساعدة

### الملفات المرجعية
- `IMPROVEMENTS_SUMMARY.md` - ملخص التحسينات
- `system_status.php` - صفحة حالة النظام
- `includes/install_check.php` - فحص حالة التثبيت

### معلومات الاتصال
- **الوثائق**: راجع ملف `IMPROVEMENTS_SUMMARY.md`
- **السجلات**: تحقق من `/var/log/` للسجلات
- **حالة النظام**: استخدم `system_status.php`

### نصائح مهمة
1. **احذف ملف التثبيت** بعد اكتمال التثبيت
2. **استخدم HTTPS** في الإنتاج
3. **قم بعمل نسخ احتياطية** دورية
4. **راقب السجلات** للتحقق من الأخطاء
5. **حدث النظام** بانتظام

---

تم تصميم ملف التثبيت التلقائي لجعل عملية التثبيت سهلة وآمنة. في حالة مواجهة أي مشاكل، راجع قسم استكشاف الأخطاء أو استخدم صفحة حالة النظام للتشخيص.

