<?php
session_start();
require_once '../includes/db.php';

// Check if user is logged in and is a distributor
if (!isset($_SESSION['user_id']) || $_SESSION['role'] !== 'distributor') {
    header('Location: ../login.php');
    exit();
}

$distributor_id = $_SESSION['user_id'];
$message = '';
$error = '';

// Handle form submissions
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['action'])) {
        switch ($_POST['action']) {
            case 'create_course':
                $name = trim($_POST['name']);
                $description = trim($_POST['description']);
                $category = trim($_POST['category']);
                $level = $_POST['level'];
                $duration_weeks = intval($_POST['duration_weeks']);
                $price_per_session = floatval($_POST['price_per_session']);
                $price_monthly = floatval($_POST['price_monthly']);
                $max_students = intval($_POST['max_students']);
                $prerequisites = trim($_POST['prerequisites']);
                $learning_objectives = trim($_POST['learning_objectives']);
                
                if (!empty($name) && !empty($category)) {
                    try {
                        $stmt = $pdo->prepare("INSERT INTO courses (name, description, category, level, duration_weeks, price_per_session, price_monthly, max_students, prerequisites, learning_objectives, created_by) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)");
                        $stmt->execute([$name, $description, $category, $level, $duration_weeks, $price_per_session, $price_monthly, $max_students, $prerequisites, $learning_objectives, $distributor_id]);
                        $message = "تم إنشاء المقرر بنجاح";
                    } catch (PDOException $e) {
                        $error = "خطأ في إنشاء المقرر: " . $e->getMessage();
                    }
                } else {
                    $error = "اسم المقرر والفئة مطلوبان";
                }
                break;
                
            case 'update_course':
                $course_id = $_POST['course_id'];
                $name = trim($_POST['name']);
                $description = trim($_POST['description']);
                $category = trim($_POST['category']);
                $level = $_POST['level'];
                $duration_weeks = intval($_POST['duration_weeks']);
                $price_per_session = floatval($_POST['price_per_session']);
                $price_monthly = floatval($_POST['price_monthly']);
                $max_students = intval($_POST['max_students']);
                $prerequisites = trim($_POST['prerequisites']);
                $learning_objectives = trim($_POST['learning_objectives']);
                $is_active = isset($_POST['is_active']) ? 1 : 0;
                
                try {
                    $stmt = $pdo->prepare("UPDATE courses SET name = ?, description = ?, category = ?, level = ?, duration_weeks = ?, price_per_session = ?, price_monthly = ?, max_students = ?, prerequisites = ?, learning_objectives = ?, is_active = ? WHERE id = ?");
                    $stmt->execute([$name, $description, $category, $level, $duration_weeks, $price_per_session, $price_monthly, $max_students, $prerequisites, $learning_objectives, $is_active, $course_id]);
                    $message = "تم تحديث المقرر بنجاح";
                } catch (PDOException $e) {
                    $error = "خطأ في تحديث المقرر: " . $e->getMessage();
                }
                break;
                
            case 'delete_course':
                $course_id = $_POST['course_id'];
                
                try {
                    // Check if course is being used by any groups
                    $stmt = $pdo->prepare("SELECT COUNT(*) FROM study_groups WHERE course_id = ?");
                    $stmt->execute([$course_id]);
                    $groups_count = $stmt->fetchColumn();
                    
                    if ($groups_count > 0) {
                        $error = "لا يمكن حذف المقرر لأنه مرتبط بـ $groups_count مجموعة دراسية";
                    } else {
                        $stmt = $pdo->prepare("DELETE FROM courses WHERE id = ?");
                        $stmt->execute([$course_id]);
                        $message = "تم حذف المقرر بنجاح";
                    }
                } catch (PDOException $e) {
                    $error = "خطأ في حذف المقرر: " . $e->getMessage();
                }
                break;
                
            case 'assign_teacher':
                $course_id = $_POST['course_id'];
                $teacher_id = $_POST['teacher_id'];
                
                try {
                    // Check if assignment already exists
                    $stmt = $pdo->prepare("SELECT id FROM course_teachers WHERE course_id = ? AND teacher_id = ?");
                    $stmt->execute([$course_id, $teacher_id]);
                    
                    if (!$stmt->fetch()) {
                        $stmt = $pdo->prepare("INSERT INTO course_teachers (course_id, teacher_id, assigned_by) VALUES (?, ?, ?)");
                        $stmt->execute([$course_id, $teacher_id, $distributor_id]);
                        $message = "تم تعيين المعلم للمقرر بنجاح";
                    } else {
                        $error = "المعلم مُعيَّن بالفعل لهذا المقرر";
                    }
                } catch (PDOException $e) {
                    $error = "خطأ في تعيين المعلم: " . $e->getMessage();
                }
                break;
                
            case 'remove_teacher':
                $assignment_id = $_POST['assignment_id'];
                
                try {
                    $stmt = $pdo->prepare("DELETE FROM course_teachers WHERE id = ?");
                    $stmt->execute([$assignment_id]);
                    $message = "تم إلغاء تعيين المعلم بنجاح";
                } catch (PDOException $e) {
                    $error = "خطأ في إلغاء تعيين المعلم: " . $e->getMessage();
                }
                break;
        }
    }
}

// Get filter parameters
$category_filter = $_GET['category'] ?? '';
$level_filter = $_GET['level'] ?? '';
$status_filter = $_GET['status'] ?? '';

// Build WHERE clause for filters
$where_conditions = [];
$params = [];

if ($category_filter) {
    $where_conditions[] = "category = ?";
    $params[] = $category_filter;
}

if ($level_filter) {
    $where_conditions[] = "level = ?";
    $params[] = $level_filter;
}

if ($status_filter !== '') {
    $where_conditions[] = "is_active = ?";
    $params[] = $status_filter;
}

$where_clause = !empty($where_conditions) ? "WHERE " . implode(" AND ", $where_conditions) : "";

// Get all courses
$stmt = $pdo->prepare("SELECT * FROM courses $where_clause ORDER BY created_at DESC");
$stmt->execute($params);
$courses = $stmt->fetchAll();

// Get course statistics
$stmt = $pdo->query("
    SELECT 
        COUNT(*) as total_courses,
        COUNT(CASE WHEN is_active = 1 THEN 1 END) as active_courses,
        COUNT(CASE WHEN is_active = 0 THEN 1 END) as inactive_courses,
        COUNT(DISTINCT category) as total_categories
    FROM courses
");
$stats = $stmt->fetch();

// Get all categories for filter
$stmt = $pdo->query("SELECT DISTINCT category FROM courses WHERE category IS NOT NULL ORDER BY category");
$categories = $stmt->fetchAll(PDO::FETCH_COLUMN);

// Get all teachers for assignment
$stmt = $pdo->prepare("SELECT id, name, email FROM teachers WHERE role = 'teacher' AND is_active = 1 ORDER BY name");
$stmt->execute();
$teachers = $stmt->fetchAll();

// Get course for editing if requested
$edit_course = null;
if (isset($_GET['edit']) && is_numeric($_GET['edit'])) {
    $stmt = $pdo->prepare("SELECT * FROM courses WHERE id = ?");
    $stmt->execute([$_GET['edit']]);
    $edit_course = $stmt->fetch();
}

// Get course assignments if viewing specific course
$course_assignments = [];
if (isset($_GET['view']) && is_numeric($_GET['view'])) {
    $stmt = $pdo->prepare("
        SELECT 
            ct.*,
            t.name as teacher_name,
            t.email as teacher_email,
            COUNT(sg.id) as groups_count
        FROM course_teachers ct
        JOIN teachers t ON ct.teacher_id = t.id
        LEFT JOIN study_groups sg ON ct.course_id = sg.course_id AND sg.teacher_id = ct.teacher_id
        WHERE ct.course_id = ?
        GROUP BY ct.id, t.name, t.email
        ORDER BY ct.assigned_at DESC
    ");
    $stmt->execute([$_GET['view']]);
    $course_assignments = $stmt->fetchAll();
}
?>

<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>إدارة المقررات التعليمية</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
    <style>
        body { font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif; }
        .sidebar { background: linear-gradient(135deg, #667eea 0%, #764ba2 100%); }
        .card { border: none; box-shadow: 0 0.125rem 0.25rem rgba(0, 0, 0, 0.075); }
        .btn-primary { background: linear-gradient(135deg, #667eea 0%, #764ba2 100%); border: none; }
        .course-card { transition: transform 0.2s; }
        .course-card:hover { transform: translateY(-2px); }
        .level-badge { font-size: 0.75rem; }
        .price-tag { background: linear-gradient(135deg, #28a745 0%, #20c997 100%); }
    </style>
</head>
<body class="bg-light">
    <div class="container-fluid">
        <div class="row">
            <!-- Sidebar -->
            <div class="col-md-3 col-lg-2 px-0">
                <?php include '../includes/sidebar.php'; ?>
            </div>
            
            <!-- Main Content -->
            <div class="col-md-9 col-lg-10">
                <div class="container-fluid py-4">
                    <div class="d-flex justify-content-between align-items-center mb-4">
                        <h2><i class="fas fa-book me-2"></i>إدارة المقررات التعليمية</h2>
                        <div>
                            <button type="button" class="btn btn-primary me-2" data-bs-toggle="modal" data-bs-target="#courseModal">
                                <i class="fas fa-plus me-2"></i>مقرر جديد
                            </button>
                            <a href="dashboard.php" class="btn btn-outline-secondary">
                                <i class="fas fa-arrow-right me-2"></i>العودة للوحة التحكم
                            </a>
                        </div>
                    </div>

                    <?php if ($message): ?>
                        <div class="alert alert-success alert-dismissible fade show" role="alert">
                            <?= htmlspecialchars($message) ?>
                            <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
                        </div>
                    <?php endif; ?>

                    <?php if ($error): ?>
                        <div class="alert alert-danger alert-dismissible fade show" role="alert">
                            <?= htmlspecialchars($error) ?>
                            <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
                        </div>
                    <?php endif; ?>

                    <!-- Statistics Cards -->
                    <div class="row mb-4">
                        <div class="col-md-3">
                            <div class="card text-center">
                                <div class="card-body">
                                    <i class="fas fa-book fa-2x text-primary mb-2"></i>
                                    <h4 class="mb-0"><?= $stats['total_courses'] ?></h4>
                                    <small class="text-muted">إجمالي المقررات</small>
                                </div>
                            </div>
                        </div>
                        <div class="col-md-3">
                            <div class="card text-center">
                                <div class="card-body">
                                    <i class="fas fa-check-circle fa-2x text-success mb-2"></i>
                                    <h4 class="mb-0"><?= $stats['active_courses'] ?></h4>
                                    <small class="text-muted">مقررات نشطة</small>
                                </div>
                            </div>
                        </div>
                        <div class="col-md-3">
                            <div class="card text-center">
                                <div class="card-body">
                                    <i class="fas fa-pause-circle fa-2x text-warning mb-2"></i>
                                    <h4 class="mb-0"><?= $stats['inactive_courses'] ?></h4>
                                    <small class="text-muted">مقررات متوقفة</small>
                                </div>
                            </div>
                        </div>
                        <div class="col-md-3">
                            <div class="card text-center">
                                <div class="card-body">
                                    <i class="fas fa-tags fa-2x text-info mb-2"></i>
                                    <h4 class="mb-0"><?= $stats['total_categories'] ?></h4>
                                    <small class="text-muted">فئات المقررات</small>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Filters -->
                    <div class="card mb-4">
                        <div class="card-body">
                            <form method="GET" class="row g-3">
                                <div class="col-md-3">
                                    <label for="category" class="form-label">الفئة</label>
                                    <select class="form-select" id="category" name="category" onchange="this.form.submit()">
                                        <option value="">جميع الفئات</option>
                                        <?php foreach ($categories as $category): ?>
                                            <option value="<?= htmlspecialchars($category) ?>" <?= $category_filter === $category ? 'selected' : '' ?>>
                                                <?= htmlspecialchars($category) ?>
                                            </option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                                <div class="col-md-3">
                                    <label for="level" class="form-label">المستوى</label>
                                    <select class="form-select" id="level" name="level" onchange="this.form.submit()">
                                        <option value="">جميع المستويات</option>
                                        <option value="beginner" <?= $level_filter === 'beginner' ? 'selected' : '' ?>>مبتدئ</option>
                                        <option value="intermediate" <?= $level_filter === 'intermediate' ? 'selected' : '' ?>>متوسط</option>
                                        <option value="advanced" <?= $level_filter === 'advanced' ? 'selected' : '' ?>>متقدم</option>
                                    </select>
                                </div>
                                <div class="col-md-3">
                                    <label for="status" class="form-label">الحالة</label>
                                    <select class="form-select" id="status" name="status" onchange="this.form.submit()">
                                        <option value="">جميع الحالات</option>
                                        <option value="1" <?= $status_filter === '1' ? 'selected' : '' ?>>نشط</option>
                                        <option value="0" <?= $status_filter === '0' ? 'selected' : '' ?>>متوقف</option>
                                    </select>
                                </div>
                                <div class="col-md-3">
                                    <label class="form-label">&nbsp;</label>
                                    <a href="courses.php" class="btn btn-outline-secondary w-100">
                                        <i class="fas fa-refresh me-2"></i>إعادة تعيين
                                    </a>
                                </div>
                            </form>
                        </div>
                    </div>

                    <!-- Courses Grid -->
                    <div class="row">
                        <?php if (empty($courses)): ?>
                            <div class="col-12">
                                <div class="card">
                                    <div class="card-body text-center py-5">
                                        <i class="fas fa-book fa-3x text-muted mb-3"></i>
                                        <p class="text-muted">لا توجد مقررات متاحة</p>
                                        <button type="button" class="btn btn-primary" data-bs-toggle="modal" data-bs-target="#courseModal">
                                            <i class="fas fa-plus me-2"></i>إنشاء مقرر جديد
                                        </button>
                                    </div>
                                </div>
                            </div>
                        <?php else: ?>
                            <?php foreach ($courses as $course): ?>
                                <div class="col-md-6 col-lg-4 mb-4">
                                    <div class="card course-card h-100">
                                        <div class="card-header d-flex justify-content-between align-items-center">
                                            <h6 class="mb-0"><?= htmlspecialchars($course['name']) ?></h6>
                                            <div>
                                                <span class="badge level-badge <?= $course['level'] === 'beginner' ? 'bg-success' : ($course['level'] === 'intermediate' ? 'bg-warning' : 'bg-danger') ?>">
                                                    <?= $course['level'] === 'beginner' ? 'مبتدئ' : ($course['level'] === 'intermediate' ? 'متوسط' : 'متقدم') ?>
                                                </span>
                                                <span class="badge <?= $course['is_active'] ? 'bg-success' : 'bg-secondary' ?> ms-1">
                                                    <?= $course['is_active'] ? 'نشط' : 'متوقف' ?>
                                                </span>
                                            </div>
                                        </div>
                                        <div class="card-body">
                                            <p class="card-text small text-muted mb-2">
                                                <i class="fas fa-tag me-1"></i><?= htmlspecialchars($course['category']) ?>
                                            </p>
                                            <p class="card-text"><?= htmlspecialchars(substr($course['description'], 0, 100)) ?><?= strlen($course['description']) > 100 ? '...' : '' ?></p>
                                            
                                            <div class="row text-center mb-3">
                                                <div class="col-6">
                                                    <div class="price-tag text-white rounded p-2">
                                                        <small>بالحصة</small><br>
                                                        <strong><?= number_format($course['price_per_session'], 2) ?> ر.س</strong>
                                                    </div>
                                                </div>
                                                <div class="col-6">
                                                    <div class="price-tag text-white rounded p-2">
                                                        <small>شهرياً</small><br>
                                                        <strong><?= number_format($course['price_monthly'], 2) ?> ر.س</strong>
                                                    </div>
                                                </div>
                                            </div>
                                            
                                            <div class="row text-center small text-muted">
                                                <div class="col-6">
                                                    <i class="fas fa-clock me-1"></i><?= $course['duration_weeks'] ?> أسبوع
                                                </div>
                                                <div class="col-6">
                                                    <i class="fas fa-users me-1"></i>حد أقصى <?= $course['max_students'] ?>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="card-footer">
                                            <div class="btn-group w-100" role="group">
                                                <a href="?view=<?= $course['id'] ?>" class="btn btn-outline-info btn-sm">
                                                    <i class="fas fa-eye"></i> عرض
                                                </a>
                                                <a href="?edit=<?= $course['id'] ?>" class="btn btn-outline-primary btn-sm">
                                                    <i class="fas fa-edit"></i> تعديل
                                                </a>
                                                <button type="button" class="btn btn-outline-success btn-sm" 
                                                        data-bs-toggle="modal" data-bs-target="#assignTeacherModal"
                                                        data-course-id="<?= $course['id'] ?>" data-course-name="<?= htmlspecialchars($course['name']) ?>">
                                                    <i class="fas fa-user-plus"></i> تعيين
                                                </button>
                                                <form method="POST" style="display: inline;" 
                                                      onsubmit="return confirm('هل أنت متأكد من حذف هذا المقرر؟')">
                                                    <input type="hidden" name="action" value="delete_course">
                                                    <input type="hidden" name="course_id" value="<?= $course['id'] ?>">
                                                    <button type="submit" class="btn btn-outline-danger btn-sm">
                                                        <i class="fas fa-trash"></i>
                                                    </button>
                                                </form>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </div>

                    <!-- Course Assignments View -->
                    <?php if (isset($_GET['view']) && !empty($course_assignments)): ?>
                        <div class="card mt-4">
                            <div class="card-header">
                                <h5 class="mb-0">المعلمون المُعيَّنون للمقرر</h5>
                            </div>
                            <div class="card-body">
                                <div class="table-responsive">
                                    <table class="table">
                                        <thead>
                                            <tr>
                                                <th>اسم المعلم</th>
                                                <th>البريد الإلكتروني</th>
                                                <th>عدد المجموعات</th>
                                                <th>تاريخ التعيين</th>
                                                <th>الإجراءات</th>
                                            </tr>
                                        </thead>
                                        <tbody>
                                            <?php foreach ($course_assignments as $assignment): ?>
                                                <tr>
                                                    <td><?= htmlspecialchars($assignment['teacher_name']) ?></td>
                                                    <td><?= htmlspecialchars($assignment['teacher_email']) ?></td>
                                                    <td><span class="badge bg-info"><?= $assignment['groups_count'] ?></span></td>
                                                    <td><?= date('d/m/Y', strtotime($assignment['assigned_at'])) ?></td>
                                                    <td>
                                                        <form method="POST" style="display: inline;" 
                                                              onsubmit="return confirm('هل أنت متأكد من إلغاء تعيين هذا المعلم؟')">
                                                            <input type="hidden" name="action" value="remove_teacher">
                                                            <input type="hidden" name="assignment_id" value="<?= $assignment['id'] ?>">
                                                            <button type="submit" class="btn btn-sm btn-outline-danger">
                                                                <i class="fas fa-user-minus"></i> إلغاء التعيين
                                                            </button>
                                                        </form>
                                                    </td>
                                                </tr>
                                            <?php endforeach; ?>
                                        </tbody>
                                    </table>
                                </div>
                            </div>
                        </div>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </div>

    <!-- Course Modal -->
    <div class="modal fade" id="courseModal" tabindex="-1">
        <div class="modal-dialog modal-lg">
            <div class="modal-content">
                <form method="POST">
                    <input type="hidden" name="action" value="<?= $edit_course ? 'update_course' : 'create_course' ?>">
                    <?php if ($edit_course): ?>
                        <input type="hidden" name="course_id" value="<?= $edit_course['id'] ?>">
                    <?php endif; ?>
                    
                    <div class="modal-header">
                        <h5 class="modal-title"><?= $edit_course ? 'تعديل المقرر' : 'إنشاء مقرر جديد' ?></h5>
                        <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                    </div>
                    <div class="modal-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="mb-3">
                                    <label for="name" class="form-label">اسم المقرر *</label>
                                    <input type="text" class="form-control" id="name" name="name" required
                                           value="<?= $edit_course ? htmlspecialchars($edit_course['name']) : '' ?>">
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="mb-3">
                                    <label for="category" class="form-label">الفئة *</label>
                                    <input type="text" class="form-control" id="category" name="category" required
                                           value="<?= $edit_course ? htmlspecialchars($edit_course['category']) : '' ?>"
                                           placeholder="مثال: الرياضيات، العلوم، اللغة العربية">
                                </div>
                            </div>
                        </div>
                        
                        <div class="mb-3">
                            <label for="description" class="form-label">الوصف</label>
                            <textarea class="form-control" id="description" name="description" rows="3"
                                      placeholder="وصف مفصل للمقرر ومحتوياته"><?= $edit_course ? htmlspecialchars($edit_course['description']) : '' ?></textarea>
                        </div>
                        
                        <div class="row">
                            <div class="col-md-4">
                                <div class="mb-3">
                                    <label for="level" class="form-label">المستوى</label>
                                    <select class="form-select" id="level" name="level">
                                        <option value="beginner" <?= $edit_course && $edit_course['level'] === 'beginner' ? 'selected' : '' ?>>مبتدئ</option>
                                        <option value="intermediate" <?= $edit_course && $edit_course['level'] === 'intermediate' ? 'selected' : '' ?>>متوسط</option>
                                        <option value="advanced" <?= $edit_course && $edit_course['level'] === 'advanced' ? 'selected' : '' ?>>متقدم</option>
                                    </select>
                                </div>
                            </div>
                            <div class="col-md-4">
                                <div class="mb-3">
                                    <label for="duration_weeks" class="form-label">المدة (أسابيع)</label>
                                    <input type="number" class="form-control" id="duration_weeks" name="duration_weeks" min="1"
                                           value="<?= $edit_course ? $edit_course['duration_weeks'] : '12' ?>">
                                </div>
                            </div>
                            <div class="col-md-4">
                                <div class="mb-3">
                                    <label for="max_students" class="form-label">الحد الأقصى للطلاب</label>
                                    <input type="number" class="form-control" id="max_students" name="max_students" min="1"
                                           value="<?= $edit_course ? $edit_course['max_students'] : '20' ?>">
                                </div>
                            </div>
                        </div>
                        
                        <div class="row">
                            <div class="col-md-6">
                                <div class="mb-3">
                                    <label for="price_per_session" class="form-label">السعر بالحصة (ر.س)</label>
                                    <input type="number" step="0.01" class="form-control" id="price_per_session" name="price_per_session"
                                           value="<?= $edit_course ? $edit_course['price_per_session'] : '' ?>">
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="mb-3">
                                    <label for="price_monthly" class="form-label">السعر الشهري (ر.س)</label>
                                    <input type="number" step="0.01" class="form-control" id="price_monthly" name="price_monthly"
                                           value="<?= $edit_course ? $edit_course['price_monthly'] : '' ?>">
                                </div>
                            </div>
                        </div>
                        
                        <div class="mb-3">
                            <label for="prerequisites" class="form-label">المتطلبات المسبقة</label>
                            <textarea class="form-control" id="prerequisites" name="prerequisites" rows="2"
                                      placeholder="المهارات أو المعرفة المطلوبة قبل دراسة هذا المقرر"><?= $edit_course ? htmlspecialchars($edit_course['prerequisites']) : '' ?></textarea>
                        </div>
                        
                        <div class="mb-3">
                            <label for="learning_objectives" class="form-label">أهداف التعلم</label>
                            <textarea class="form-control" id="learning_objectives" name="learning_objectives" rows="3"
                                      placeholder="ما سيتعلمه الطالب بعد إكمال هذا المقرر"><?= $edit_course ? htmlspecialchars($edit_course['learning_objectives']) : '' ?></textarea>
                        </div>
                        
                        <?php if ($edit_course): ?>
                            <div class="mb-3">
                                <div class="form-check">
                                    <input class="form-check-input" type="checkbox" id="is_active" name="is_active" 
                                           <?= $edit_course['is_active'] ? 'checked' : '' ?>>
                                    <label class="form-check-label" for="is_active">
                                        المقرر نشط
                                    </label>
                                </div>
                            </div>
                        <?php endif; ?>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">إلغاء</button>
                        <button type="submit" class="btn btn-primary">
                            <?= $edit_course ? 'تحديث المقرر' : 'إنشاء المقرر' ?>
                        </button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Assign Teacher Modal -->
    <div class="modal fade" id="assignTeacherModal" tabindex="-1">
        <div class="modal-dialog">
            <div class="modal-content">
                <form method="POST">
                    <input type="hidden" name="action" value="assign_teacher">
                    <input type="hidden" name="course_id" id="assign_course_id">
                    
                    <div class="modal-header">
                        <h5 class="modal-title">تعيين معلم للمقرر</h5>
                        <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                    </div>
                    <div class="modal-body">
                        <div class="mb-3">
                            <label class="form-label">المقرر</label>
                            <input type="text" class="form-control" id="assign_course_name" readonly>
                        </div>
                        <div class="mb-3">
                            <label for="teacher_id" class="form-label">المعلم *</label>
                            <select class="form-select" id="teacher_id" name="teacher_id" required>
                                <option value="">اختر المعلم</option>
                                <?php foreach ($teachers as $teacher): ?>
                                    <option value="<?= $teacher['id'] ?>">
                                        <?= htmlspecialchars($teacher['name']) ?> (<?= htmlspecialchars($teacher['email']) ?>)
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">إلغاء</button>
                        <button type="submit" class="btn btn-primary">تعيين المعلم</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        // Handle assign teacher modal
        document.getElementById('assignTeacherModal').addEventListener('show.bs.modal', function (event) {
            const button = event.relatedTarget;
            const courseId = button.getAttribute('data-course-id');
            const courseName = button.getAttribute('data-course-name');
            
            document.getElementById('assign_course_id').value = courseId;
            document.getElementById('assign_course_name').value = courseName;
        });
        
        // Show modal if editing
        <?php if ($edit_course): ?>
        document.addEventListener('DOMContentLoaded', function() {
            new bootstrap.Modal(document.getElementById('courseModal')).show();
        });
        <?php endif; ?>
    </script>
</body>
</html>

