<?php
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);
session_start();
if (!isset($_SESSION['distributor_id'])) {
    header("Location: ../login.php");
    exit;
}

include "../includes/db.php";

$distributor_id = $_SESSION['distributor_id'];

// Handle image upload
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_FILES['profile_image'])) {
    $upload_dir = '../uploads/profiles/';
    
    // Create directory if it doesn't exist
    if (!file_exists($upload_dir)) {
        mkdir($upload_dir, 0755, true);
    }
    
    $file = $_FILES['profile_image'];
    $file_extension = strtolower(pathinfo($file['name'], PATHINFO_EXTENSION));
    $allowed_extensions = ['jpg', 'jpeg', 'png', 'gif'];
    
    if (in_array($file_extension, $allowed_extensions) && $file['size'] <= 5000000) { // 5MB limit
        $new_filename = 'distributor_' . $distributor_id . '_' . time() . '.' . $file_extension;
        $upload_path = $upload_dir . $new_filename;
        
        if (move_uploaded_file($file['tmp_name'], $upload_path)) {
            // Update database with new image path
            $stmt = $pdo->prepare("UPDATE distributors SET profile_image = ? WHERE id = ?");
            $stmt->execute([$new_filename, $distributor_id]);
            $success_message = "تم رفع الصورة بنجاح!";
        } else {
            $error_message = "حدث خطأ أثناء رفع الصورة.";
        }
    } else {
        $error_message = "نوع الملف غير مدعوم أو حجم الملف كبير جداً.";
    }
}

// Get distributor info
$stmt = $pdo->prepare("SELECT * FROM distributors WHERE id = ?");
$stmt->execute([$distributor_id]);
$distributor = $stmt->fetch(PDO::FETCH_ASSOC);
?>

<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <title>الملف الشخصي - مدير النظام</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css" rel="stylesheet">
    <link rel="stylesheet" href="../assets/css/main.css">
    <style>
        .profile-image {
            width: 150px;
            height: 150px;
            object-fit: cover;
            border-radius: 50%;
            border: 4px solid #007bff;
        }
        .upload-area {
            border: 2px dashed #007bff;
            border-radius: 10px;
            padding: 20px;
            text-align: center;
            cursor: pointer;
            transition: all 0.3s;
        }
        .upload-area:hover {
            background-color: #f8f9fa;
            border-color: #0056b3;
        }
    </style>
</head>
<body>
    <?php include "../includes/header.php"; ?>
    
    <div class="container-fluid">
        <div class="row">
            <div class="col-md-3">
                <?php include "../includes/sidebar.php"; ?>
            </div>
            <div class="col-md-9">
                <div class="main-content p-4">
                    <div class="d-flex justify-content-between align-items-center mb-4">
                        <h2><i class="fas fa-user-circle me-2"></i> الملف الشخصي</h2>
                        <a href="dashboard.php" class="btn btn-secondary">
                            <i class="fas fa-arrow-left me-2"></i> العودة للوحة التحكم
                        </a>
                    </div>

                    <?php if (isset($success_message)): ?>
                        <div class="alert alert-success alert-dismissible fade show" role="alert">
                            <i class="fas fa-check-circle me-2"></i> <?= $success_message ?>
                            <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
                        </div>
                    <?php endif; ?>

                    <?php if (isset($error_message)): ?>
                        <div class="alert alert-danger alert-dismissible fade show" role="alert">
                            <i class="fas fa-exclamation-circle me-2"></i> <?= $error_message ?>
                            <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
                        </div>
                    <?php endif; ?>

                    <div class="row">
                        <div class="col-md-4">
                            <div class="card">
                                <div class="card-header bg-primary text-white">
                                    <i class="fas fa-camera me-2"></i> صورة الملف الشخصي
                                </div>
                                <div class="card-body text-center">
                                    <?php if ($distributor['profile_image']): ?>
                                        <img src="../uploads/profiles/<?= htmlspecialchars($distributor['profile_image']) ?>" 
                                             alt="صورة الملف الشخصي" class="profile-image mb-3">
                                    <?php else: ?>
                                        <div class="profile-image mb-3 d-flex align-items-center justify-content-center bg-light">
                                            <i class="fas fa-user fa-4x text-muted"></i>
                                        </div>
                                    <?php endif; ?>
                                    
                                    <form method="POST" enctype="multipart/form-data">
                                        <div class="upload-area mb-3" onclick="document.getElementById('profile_image').click()">
                                            <i class="fas fa-cloud-upload-alt fa-2x text-primary mb-2"></i>
                                            <p class="mb-0">اضغط لرفع صورة جديدة</p>
                                            <small class="text-muted">JPG, PNG, GIF (حد أقصى 5MB)</small>
                                        </div>
                                        <input type="file" id="profile_image" name="profile_image" 
                                               accept="image/*" style="display: none;" onchange="this.form.submit()">
                                    </form>
                                </div>
                            </div>
                        </div>
                        
                        <div class="col-md-8">
                            <div class="card">
                                <div class="card-header bg-info text-white">
                                    <i class="fas fa-info-circle me-2"></i> معلومات الحساب
                                </div>
                                <div class="card-body">
                                    <div class="row mb-3">
                                        <div class="col-sm-4"><strong>الاسم:</strong></div>
                                        <div class="col-sm-8"><?= htmlspecialchars($distributor['name']) ?></div>
                                    </div>
                                    <div class="row mb-3">
                                        <div class="col-sm-4"><strong>البريد الإلكتروني:</strong></div>
                                        <div class="col-sm-8"><?= htmlspecialchars($distributor['email']) ?></div>
                                    </div>
                                    <div class="row mb-3">
                                        <div class="col-sm-4"><strong>الدور:</strong></div>
                                        <div class="col-sm-8">
                                            <span class="badge bg-success">مدير النظام</span>
                                        </div>
                                    </div>
                                    <div class="row mb-3">
                                        <div class="col-sm-4"><strong>تاريخ التسجيل:</strong></div>
                                        <div class="col-sm-8"><?= date('Y-m-d', strtotime($distributor['created_at'])) ?></div>
                                    </div>
                                    <div class="row mb-3">
                                        <div class="col-sm-4"><strong>الحالة:</strong></div>
                                        <div class="col-sm-8">
                                            <?php if ($distributor['is_active']): ?>
                                                <span class="badge bg-success">نشط</span>
                                            <?php else: ?>
                                                <span class="badge bg-danger">غير نشط</span>
                                            <?php endif; ?>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            
                            <div class="card mt-4">
                                <div class="card-header bg-warning text-dark">
                                    <i class="fas fa-cog me-2"></i> إعدادات الحساب
                                </div>
                                <div class="card-body">
                                    <div class="d-grid gap-2">
                                        <a href="../settings/change-password.php" class="btn btn-outline-primary">
                                            <i class="fas fa-key me-2"></i> تغيير كلمة المرور
                                        </a>
                                        <a href="../settings/edit-profile.php" class="btn btn-outline-info">
                                            <i class="fas fa-edit me-2"></i> تعديل المعلومات الشخصية
                                        </a>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>

