<?php
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);
session_start();
if (!isset($_SESSION['distributor_id'])) {
    header("Location: ../login.php");
    exit;
}

include "../includes/db.php";

$error = "";
$success = "";

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // تنظيف وفلترة المدخلات
    $name = htmlspecialchars(trim($_POST['name']), ENT_QUOTES, 'UTF-8');
    $email = filter_var($_POST['email'], FILTER_VALIDATE_EMAIL);
    $password = $_POST['password'] ?? '';
    $subscription_type = in_array($_POST['subscription_type'], ['semi_annual', 'annual']) ? $_POST['subscription_type'] : null;
    // لم يعد الدومين الفرعي مطلوبًا
    $subdomain = null;

    if (!$name || !$email || !$password || !$subscription_type) {
        $error = "يرجى ملء جميع الحقول بشكل صحيح.";
    } else {
        $start_date = date('Y-m-d');
        $end_date = ($subscription_type == 'annual') ? date('Y-m-d', strtotime('+1 year')) : date('Y-m-d', strtotime('+6 months'));

        try {
            // التحقق من البريد فقط
            $stmt = $pdo->prepare("SELECT * FROM teachers WHERE email = ?");
            $stmt->execute([$email]);

            if ($stmt->fetch()) {
                $error = "البريد الإلكتروني مستخدم بالفعل";
            } else {
                // إدخال بيانات المعلم
                $insertStmt = $pdo->prepare("
                    INSERT INTO teachers 
                        (name, email, password, role, subscription_type, subscription_start, subscription_end)
                    VALUES 
                        (?, ?, ?, 'teacher', ?, ?, ?)
                ");
                $insertStmt->execute([$name, $email, password_hash($password, PASSWORD_DEFAULT), $subscription_type, $start_date, $end_date]);

                $success = "تم تسجيل المعلم بنجاح!";
            }
        } catch (PDOException $e) {
            $error = "حدث خطأ في تسجيل المعلم: " . $e->getMessage();
        }
    }
}
?>

<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <title>تسجيل معلم جديد</title>
    <!-- Bootstrap RTL -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.2/dist/css/bootstrap.rtl.min.css" rel="stylesheet">
    <!-- Font Awesome Icons -->
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css" rel="stylesheet">
    <!-- ملف CSS المشترك -->
    <link rel="stylesheet" href="../assets/css/main.css">
    <script src="../assets/js/main.js"></script>
    <style>
        /* تم نقل التنسيقات المشتركة إلى ملف main.css */
        .input-group-text {
            background-color: #e9ecef;
        }
    </style>
</head>
<body>

<?php include "../includes/header.php"; ?>
<?php include "../includes/sidebar.php"; ?>

<div class="main-content container mt-4 pt-5">
    <div class="d-flex justify-content-between align-items-center mb-4">
        <h2><i class="fas fa-chalkboard-teacher me-2"></i> تسجيل معلم جديد</h2>
        <div class="welcome-message bg-light p-2 rounded shadow-sm">
            <i class="fas fa-user-shield me-2 text-primary"></i> مرحبًا بك <span class="fw-bold text-primary"><?= $_SESSION['name'] ?? 'الموزع' ?></span>
        </div>
    </div>

    <?php if ($error): ?>
        <div class="alert alert-danger d-flex align-items-center" role="alert">
            <i class="fas fa-exclamation-circle me-2"></i>
            <span><?= $error ?></span>
        </div>
    <?php elseif ($success): ?>
        <div class="alert alert-success d-flex align-items-center" role="alert">
            <i class="fas fa-check-circle me-2"></i>
            <span><?= $success ?></span>
        </div>
    <?php endif; ?>

    <form method="post" novalidate>
        <div class="row g-3">

            <!-- الاسم الكامل -->
            <div class="col-md-6">
                <label for="name" class="form-label"><i class="fas fa-user me-1"></i> الاسم الكامل</label>
                <div class="input-group">
                    <span class="input-group-text"><i class="fas fa-user"></i></span>
                    <input type="text" name="name" id="name" class="form-control" required>
                </div>
                <div class="invalid-feedback">من فضلك أدخل اسم المعلم.</div>
            </div>

            <!-- البريد الإلكتروني -->
            <div class="col-md-6">
                <label for="email" class="form-label"><i class="fas fa-envelope me-1"></i> البريد الإلكتروني</label>
                <div class="input-group">
                    <span class="input-group-text"><i class="fas fa-envelope"></i></span>
                    <input type="email" name="email" id="email" class="form-control" required>
                </div>
                <div class="invalid-feedback">من فضلك أدخل بريد إلكتروني صحيح.</div>
            </div>

            <!-- كلمة المرور -->
            <div class="col-md-6">
                <label for="password" class="form-label"><i class="fas fa-lock me-1"></i> كلمة المرور</label>
                <div class="input-group">
                    <span class="input-group-text"><i class="fas fa-lock"></i></span>
                    <input type="password" name="password" id="password" class="form-control" minlength="6" required>
                </div>
                <div class="invalid-feedback">يجب أن تكون كلمة المرور 6 أحرف على الأقل.</div>
            </div>

            <!-- نوع الاشتراك -->
            <div class="col-md-6">
                <label for="subscription_type" class="form-label"><i class="fas fa-tag me-1"></i> نوع الاشتراك</label>
                <div class="input-group">
                    <span class="input-group-text"><i class="fas fa-tag"></i></span>
                    <select name="subscription_type" id="subscription_type" class="form-select" required>
                    <option value="">-- اختر نوع الاشتراك --</option>
                    <option value="semi_annual">نصف سنوي</option>
                    <option value="annual">سنوي</option>
                </select>
                </div>
                <div class="invalid-feedback">يرجى اختيار نوع الاشتراك.</div>
            </div>

            <!-- تم إزالة حقل الدومين الفرعي لأنه لم يعد مطلوبًا -->

        </div>

        <!-- زر الإرسال -->
        <div class="mt-4">
            <button type="submit" class="btn btn-primary w-100">
                <i class="fas fa-save me-2"></i> تسجيل المعلم
            </button>
        </div>
    </form>

    <!-- زر العودة -->
    <div class="mt-3">
        <a href="../index.php" class="btn btn-secondary">
            <i class="fas fa-arrow-left me-2"></i> العودة للرئيسية
        </a>
    </div>
</div>

<!-- Validation Script -->
<script>
    (function () {
        'use strict'
        var forms = document.querySelectorAll('.needs-validation')
        Array.prototype.slice.call(forms).forEach(function (form) {
            form.addEventListener('submit', function (event) {
                if (!form.checkValidity()) {
                    event.preventDefault()
                    event.stopPropagation()
                }
                form.classList.add('was-validated')
            }, false)
        })
    })()
</script>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.2/dist/js/bootstrap.bundle.min.js"></script> 
</body>
</html>