<?php
session_start();
if (!isset($_SESSION['distributor_id'])) {
    header("Location: ../../login.php");
    exit;
}

include "../../includes/db.php";

$stmt = $pdo->query("SELECT ticket_id, title, user_type, user_id, status FROM support_tickets ORDER BY created_at DESC");
$tickets = $stmt->fetchAll(PDO::FETCH_ASSOC);
?>

<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <title>تذاكر الدعم الفني</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css"  rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css" rel="stylesheet">
    <link rel="stylesheet" href="../../assets/css/main.css">
    <script src="../../assets/js/main.js"></script>
    <style>
        body {
            font-family: 'Cairo', sans-serif;
        }
        .ticket-card {
            transition: transform 0.2s;
        }
        .ticket-card:hover {
            transform: translateY(-5px);
        }
        .table-container {
            border-radius: 8px;
            overflow: hidden;
            box-shadow: 0 0 15px rgba(0,0,0,0.1);
        }
    </style>
</head>
<body>

<?php include "../../includes/header.php"; ?>
<?php include "../../includes/sidebar.php"; ?>

<div class="main-content container pt-5 mt-4">
    <div class="d-flex justify-content-between align-items-center mb-4">
        <h2><i class="fas fa-ticket-alt me-2"></i> تذاكر الدعم الفني</h2>
        <div class="welcome-message bg-light p-2 rounded shadow-sm">
            <i class="fas fa-user-shield me-2 text-primary"></i> مرحبًا بك <span class="fw-bold text-primary"><?= $_SESSION['name'] ?? 'الموزع' ?></span>
        </div>
    </div>

    <div class="card shadow-sm mb-4">
        <div class="card-body">
            <div class="table-container">
                <table class="table table-hover table-bordered text-center align-middle mb-0">
        <thead class="table-dark">
            <tr>
                <th>#</th>
                <th>العنوان</th>
                <th>نوع المستخدم</th>
                <th>رقم المستخدم</th>
                <th>الحالة</th>
                <th>الإجراءات</th>
            </tr>
        </thead>
        <tbody>
            <?php foreach ($tickets as $ticket): ?>
                <tr>
                    <td><?= $ticket['ticket_id'] ?></td>
                    <td><?= htmlspecialchars($ticket['title']) ?></td>
                    <td>
                        <span class="badge bg-<?= $ticket['user_type'] == 'teacher' ? 'primary' : 'info' ?>">
                            <i class="fas <?= $ticket['user_type'] == 'teacher' ? 'fa-chalkboard-teacher' : 'fa-user' ?> me-1"></i>
                            <?= $ticket['user_type'] == 'teacher' ? 'معلم' : 'موزع' ?>
                        </span>
                    </td>
                    <td><?= $ticket['user_id'] ?></td>
                    <td>
                        <span class="badge bg-<?= $ticket['status'] == 'open' ? 'success' : ($ticket['status'] == 'closed' ? 'danger' : 'warning') ?>">
                            <i class="fas <?= $ticket['status'] == 'open' ? 'fa-envelope-open' : ($ticket['status'] == 'closed' ? 'fa-envelope' : 'fa-clock') ?> me-1"></i>
                            <?= $ticket['status'] == 'open' ? 'مفتوحة' : ($ticket['status'] == 'closed' ? 'مغلقة' : 'قيد المعالجة') ?>
                        </span>
                    </td>
                    <td>
                        <a href="view-ticket.php?id=<?= $ticket['ticket_id'] ?>" class="btn btn-sm btn-primary">
                            <i class="fas fa-eye me-1"></i> عرض التذكرة
                        </a>
                    </td>
                </tr>
            <?php endforeach; ?>
        </tbody>
    </table>
            </div>
        </div>
    </div>
</div>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script> 
</body>
</html>