<?php
ini_set("display_errors", 1);
ini_set("display_startup_errors", 1);
error_reporting(E_ALL);
session_start();

if (!isset($_SESSION["distributor_id"])) {
    header("Location: ../login.php");
    exit;
}

include "../includes/db.php";

$teacher_id = isset($_GET["id"]) ? intval($_GET["id"]) : 0;

if ($teacher_id === 0) {
    header("Location: dashboard.php"); // Redirect if no ID is provided
    exit;
}

try {
    // Fetch teacher details
    $stmt = $pdo->prepare("SELECT * FROM teachers WHERE id = ?");
    $stmt->execute([$teacher_id]);
    $teacher = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$teacher) {
        echo "<div class=\"alert alert-danger\">المعلم غير موجود.</div>";
        exit;
    }

    // Fetch students associated with this teacher
    $stmt_students = $pdo->prepare("SELECT * FROM students WHERE teacher_id = ?");
    $stmt_students->execute([$teacher_id]);
    $students = $stmt_students->fetchAll(PDO::FETCH_ASSOC);

    // Fetch subjects taught by this teacher
    $stmt_subjects = $pdo->prepare("SELECT * FROM subjects WHERE teacher_id = ?");
    $stmt_subjects->execute([$teacher_id]);
    $subjects = $stmt_subjects->fetchAll(PDO::FETCH_ASSOC);

} catch (PDOException $e) {
    die("خطأ في النظام: " . $e->getMessage());
}
?>

<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <title>تفاصيل المعلم: <?= $teacher["name"] ?></title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css" rel="stylesheet">
    <link rel="stylesheet" href="../assets/css/main.css">
</head>
<body>

<?php include "../includes/header.php"; ?>
<?php include "../includes/sidebar.php"; ?>

<div class="main-content container pt-5 mt-4">
    <div class="d-flex justify-content-between align-items-center mb-4">
        <h2><i class="fas fa-user-tie me-2"></i> تفاصيل المعلم: <?= $teacher["name"] ?></h2>
        <a href="dashboard.php" class="btn btn-secondary"><i class="fas fa-arrow-right-to-bracket me-2"></i> العودة للوحة التحكم</a>
    </div>

    <div class="card mb-4">
        <div class="card-header bg-primary text-white">
            معلومات المعلم
        </div>
        <div class="card-body">
            <p><strong>الاسم:</strong> <?= $teacher["name"] ?></p>
            <p><strong>البريد الإلكتروني:</strong> <?= $teacher["email"] ?></p>
            <p><strong>الدور:</strong> <?= $teacher["role"] ?></p>
            <p><strong>نوع الاشتراك:</strong> <?= $teacher["subscription_type"] ?></p>
            <p><strong>تاريخ بدء الاشتراك:</strong> <?= $teacher["subscription_start"] ?></p>
            <p><strong>تاريخ انتهاء الاشتراك:</strong> <?= $teacher["subscription_end"] ?></p>
            <p><strong>نشط:</strong> <?= $teacher["is_active"] ? "نعم" : "لا" ?></p>
            <p><strong>النطاق الفرعي:</strong> <?= $teacher["subdomain"] ?></p>
                  <p><strong>CSS مخصص:</strong> <pre><?= htmlspecialchars(isset($teacher["custom_css"]) ? $teacher["custom_css"] : "") ?></pre></p>
        </div>
    </div>

    <div class="card mb-4">
        <div class="card-header bg-info text-white">
            الطلاب التابعون للمعلم
        </div>
        <div class="card-body">
            <?php if (count($students) > 0): ?>
                <ul class="list-group">
                    <?php foreach ($students as $student): ?>
                        <li class="list-group-item"><?= $student["name"] ?> (الصف: <?= $student["grade_level"] ?>)</li>
                    <?php endforeach; ?>
                </ul>
            <?php else: ?>
                <p>لا يوجد طلاب تابعون لهذا المعلم.</p>
            <?php endif; ?>
        </div>
    </div>

    <div class="card mb-4">
        <div class="card-header bg-warning text-white">
            المواد التي يدرسها المعلم
        </div>
        <div class="card-body">
            <?php if (count($subjects) > 0): ?>
                <ul class="list-group">
                    <?php foreach ($subjects as $subject): ?>
                        <li class="list-group-item"><?= $subject["subject_name"] ?></li>
                    <?php endforeach; ?>
                </ul>
            <?php else: ?>
                <p>لا يوجد مواد يدرسها هذا المعلم.</p>
            <?php endif; ?>
        </div>
    </div>
</div>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>

