/**
 * main.js - ملف JavaScript مشترك لتطبيق تحسينات واجهة المستخدم
 */

document.addEventListener("DOMContentLoaded", function () {
    // تطبيق تأثير التمرير على الهيدر
    const header = document.querySelector('.header');
    if (header) {
        window.addEventListener('scroll', function() {
            if (window.scrollY > 10) {
                header.classList.add('scrolled');
            } else {
                header.classList.remove('scrolled');
            }
        });
    }
    
    // تحديث التاريخ في الجداول إن وُجدت
    document.querySelectorAll(".current-date").forEach(function (el) {
        el.textContent = new Date().toLocaleDateString();
    });

    // تعديل ألوان الواجهة بناءً على اختيار المستخدم
    const colorPicker = document.getElementById("theme-color");
    if (colorPicker) {
        colorPicker.addEventListener("change", function () {
            document.body.style.setProperty('--primary-color', this.value);
        });
    }
    
    // تطبيق تأثيرات الحركة على البطاقات
    const cards = document.querySelectorAll('.card');
    cards.forEach(card => {
        card.addEventListener('mouseenter', function() {
            this.style.transform = 'translateY(-5px)';
            this.style.boxShadow = '0 10px 20px rgba(0, 0, 0, 0.1)';
        });
        
        card.addEventListener('mouseleave', function() {
            this.style.transform = 'translateY(0)';
            this.style.boxShadow = '0 4px 6px rgba(0, 0, 0, 0.05)';
        });
    });

    // تطبيق تأثيرات الحركة على الأزرار
    const buttons = document.querySelectorAll('.btn');
    buttons.forEach(button => {
        button.addEventListener('mouseenter', function() {
            this.style.transform = 'translateY(-2px)';
            this.style.boxShadow = '0 4px 8px rgba(0, 0, 0, 0.1)';
        });
        
        button.addEventListener('mouseleave', function() {
            this.style.transform = 'translateY(0)';
            this.style.boxShadow = 'none';
        });
    });

    // تطبيق تأثيرات الحركة على روابط القائمة الجانبية
    const navLinks = document.querySelectorAll('.sidebar .nav-link');
    navLinks.forEach(link => {
        link.addEventListener('mouseenter', function() {
            this.style.transform = 'translateX(-5px)';
        });
        
        link.addEventListener('mouseleave', function() {
            this.style.transform = 'translateX(0)';
        });
    });

    // تطبيق تأثير التركيز على حقول النموذج
    const formControls = document.querySelectorAll('.form-control, .form-select');
    formControls.forEach(control => {
        control.addEventListener('focus', function() {
            this.style.borderColor = '#0d6efd';
            this.style.boxShadow = '0 0 0 0.25rem rgba(13, 110, 253, 0.25)';
        });
        
        control.addEventListener('blur', function() {
            this.style.borderColor = '#dee2e6';
            this.style.boxShadow = 'none';
        });
    });
    
    // تطبيق تأثيرات الحركة على بطاقات الإحصائيات
    const statsCards = document.querySelectorAll('.stats-card');
    statsCards.forEach(card => {
        card.addEventListener('mouseenter', function() {
            this.style.transform = 'translateY(-5px)';
            this.style.boxShadow = '0 10px 20px rgba(0, 0, 0, 0.1)';
        });
        
        card.addEventListener('mouseleave', function() {
            this.style.transform = 'translateY(0)';
            this.style.boxShadow = '0 4px 6px rgba(0, 0, 0, 0.05)';
        });
    });
});