-- database_updates_fixed.sql - تحديثات قاعدة البيانات المصححة
-- تم إصلاح جميع المراجع والتبعيات

SET SQL_MODE = "NO_AUTO_VALUE_ON_ZERO";
START TRANSACTION;
SET time_zone = "+00:00";

-- ==========================================
-- جداول إضافية لميزات متقدمة
-- ==========================================

-- جدول أولياء الأمور
CREATE TABLE IF NOT EXISTS `parents` (
    `id` int(11) NOT NULL AUTO_INCREMENT,
    `name` varchar(100) COLLATE utf8mb4_unicode_ci NOT NULL,
    `email` varchar(100) COLLATE utf8mb4_unicode_ci NOT NULL,
    `password` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL,
    `phone` varchar(20) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
    `address` text COLLATE utf8mb4_unicode_ci,
    `national_id` varchar(20) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
    `job` varchar(100) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
    `is_active` tinyint(1) DEFAULT 1,
    `created_at` datetime DEFAULT CURRENT_TIMESTAMP,
    `updated_at` datetime DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    PRIMARY KEY (`id`),
    UNIQUE KEY `email` (`email`),
    KEY `phone` (`phone`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

-- إضافة المرجع الخارجي للطلاب إلى أولياء الأمور
ALTER TABLE `students` 
ADD CONSTRAINT `students_ibfk_3` FOREIGN KEY (`parent_id`) REFERENCES `parents` (`id`) ON DELETE SET NULL;

-- جدول ربط الطلاب بأولياء الأمور (علاقة متعددة)
CREATE TABLE IF NOT EXISTS `student_parent` (
    `id` int(11) NOT NULL AUTO_INCREMENT,
    `student_id` int(11) NOT NULL,
    `parent_id` int(11) NOT NULL,
    `relationship` enum('father','mother','guardian','uncle','aunt','grandfather','grandmother','other') COLLATE utf8mb4_unicode_ci DEFAULT 'father',
    `is_primary` tinyint(1) DEFAULT 0,
    `can_receive_reports` tinyint(1) DEFAULT 1,
    `can_pay_fees` tinyint(1) DEFAULT 1,
    `created_at` datetime DEFAULT CURRENT_TIMESTAMP,
    PRIMARY KEY (`id`),
    UNIQUE KEY `unique_student_parent` (`student_id`,`parent_id`),
    KEY `parent_id` (`parent_id`),
    CONSTRAINT `student_parent_ibfk_1` FOREIGN KEY (`student_id`) REFERENCES `students` (`student_id`) ON DELETE CASCADE,
    CONSTRAINT `student_parent_ibfk_2` FOREIGN KEY (`parent_id`) REFERENCES `parents` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

-- جدول التقييمات والدرجات
CREATE TABLE IF NOT EXISTS `evaluations` (
    `id` int(11) NOT NULL AUTO_INCREMENT,
    `student_id` int(11) NOT NULL,
    `teacher_id` int(11) NOT NULL,
    `subject_id` int(11) DEFAULT NULL,
    `evaluation_type` enum('quiz','exam','homework','participation','project','oral','practical') COLLATE utf8mb4_unicode_ci NOT NULL,
    `title` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL,
    `score` decimal(5,2) DEFAULT NULL,
    `max_score` decimal(5,2) DEFAULT 100.00,
    `percentage` decimal(5,2) GENERATED ALWAYS AS ((`score` / `max_score`) * 100) STORED,
    `evaluation_date` date DEFAULT (curdate()),
    `notes` text COLLATE utf8mb4_unicode_ci,
    `is_published` tinyint(1) DEFAULT 0,
    `created_at` datetime DEFAULT CURRENT_TIMESTAMP,
    `updated_at` datetime DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    PRIMARY KEY (`id`),
    KEY `student_id` (`student_id`),
    KEY `teacher_id` (`teacher_id`),
    KEY `subject_id` (`subject_id`),
    KEY `evaluation_date` (`evaluation_date`),
    CONSTRAINT `evaluations_ibfk_1` FOREIGN KEY (`student_id`) REFERENCES `students` (`student_id`) ON DELETE CASCADE,
    CONSTRAINT `evaluations_ibfk_2` FOREIGN KEY (`teacher_id`) REFERENCES `teachers` (`id`) ON DELETE CASCADE,
    CONSTRAINT `evaluations_ibfk_3` FOREIGN KEY (`subject_id`) REFERENCES `subjects` (`subject_id`) ON DELETE SET NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

-- جدول الواجبات
CREATE TABLE IF NOT EXISTS `assignments` (
    `id` int(11) NOT NULL AUTO_INCREMENT,
    `teacher_id` int(11) NOT NULL,
    `subject_id` int(11) DEFAULT NULL,
    `group_id` int(11) DEFAULT NULL,
    `title` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL,
    `description` text COLLATE utf8mb4_unicode_ci,
    `instructions` text COLLATE utf8mb4_unicode_ci,
    `due_date` datetime DEFAULT NULL,
    `max_score` decimal(5,2) DEFAULT 100.00,
    `is_published` tinyint(1) DEFAULT 0,
    `allow_late_submission` tinyint(1) DEFAULT 0,
    `late_penalty_percent` decimal(5,2) DEFAULT 0.00,
    `created_at` datetime DEFAULT CURRENT_TIMESTAMP,
    `updated_at` datetime DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    PRIMARY KEY (`id`),
    KEY `teacher_id` (`teacher_id`),
    KEY `subject_id` (`subject_id`),
    KEY `group_id` (`group_id`),
    KEY `due_date` (`due_date`),
    CONSTRAINT `assignments_ibfk_1` FOREIGN KEY (`teacher_id`) REFERENCES `teachers` (`id`) ON DELETE CASCADE,
    CONSTRAINT `assignments_ibfk_2` FOREIGN KEY (`subject_id`) REFERENCES `subjects` (`subject_id`) ON DELETE SET NULL,
    CONSTRAINT `assignments_ibfk_3` FOREIGN KEY (`group_id`) REFERENCES `groups` (`group_id`) ON DELETE SET NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

-- جدول تسليم الواجبات
CREATE TABLE IF NOT EXISTS `assignment_submissions` (
    `id` int(11) NOT NULL AUTO_INCREMENT,
    `assignment_id` int(11) NOT NULL,
    `student_id` int(11) NOT NULL,
    `submission_text` text COLLATE utf8mb4_unicode_ci,
    `file_path` varchar(500) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
    `submission_date` datetime DEFAULT CURRENT_TIMESTAMP,
    `status` enum('submitted','late','missing','graded') COLLATE utf8mb4_unicode_ci DEFAULT 'submitted',
    `grade` decimal(5,2) DEFAULT NULL,
    `teacher_feedback` text COLLATE utf8mb4_unicode_ci,
    `graded_at` datetime DEFAULT NULL,
    `graded_by` int(11) DEFAULT NULL,
    PRIMARY KEY (`id`),
    UNIQUE KEY `unique_assignment_student` (`assignment_id`,`student_id`),
    KEY `student_id` (`student_id`),
    KEY `graded_by` (`graded_by`),
    CONSTRAINT `assignment_submissions_ibfk_1` FOREIGN KEY (`assignment_id`) REFERENCES `assignments` (`id`) ON DELETE CASCADE,
    CONSTRAINT `assignment_submissions_ibfk_2` FOREIGN KEY (`student_id`) REFERENCES `students` (`student_id`) ON DELETE CASCADE,
    CONSTRAINT `assignment_submissions_ibfk_3` FOREIGN KEY (`graded_by`) REFERENCES `teachers` (`id`) ON DELETE SET NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

-- جدول الرسائل بين المعلمين وأولياء الأمور
CREATE TABLE IF NOT EXISTS `parent_teacher_messages` (
    `id` int(11) NOT NULL AUTO_INCREMENT,
    `sender_type` enum('teacher','parent') COLLATE utf8mb4_unicode_ci NOT NULL,
    `sender_id` int(11) NOT NULL,
    `receiver_type` enum('teacher','parent') COLLATE utf8mb4_unicode_ci NOT NULL,
    `receiver_id` int(11) NOT NULL,
    `student_id` int(11) DEFAULT NULL,
    `subject` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL,
    `message` text COLLATE utf8mb4_unicode_ci NOT NULL,
    `is_read` tinyint(1) DEFAULT 0,
    `is_important` tinyint(1) DEFAULT 0,
    `attachment_path` varchar(500) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
    `sent_at` datetime DEFAULT CURRENT_TIMESTAMP,
    `read_at` datetime DEFAULT NULL,
    PRIMARY KEY (`id`),
    KEY `sender_type_id` (`sender_type`,`sender_id`),
    KEY `receiver_type_id` (`receiver_type`,`receiver_id`),
    KEY `student_id` (`student_id`),
    KEY `sent_at` (`sent_at`),
    CONSTRAINT `parent_teacher_messages_ibfk_1` FOREIGN KEY (`student_id`) REFERENCES `students` (`student_id`) ON DELETE SET NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

-- جدول الإشعارات
CREATE TABLE IF NOT EXISTS `notifications` (
    `id` int(11) NOT NULL AUTO_INCREMENT,
    `user_type` enum('teacher','parent','student') COLLATE utf8mb4_unicode_ci NOT NULL,
    `user_id` int(11) NOT NULL,
    `title` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL,
    `message` text COLLATE utf8mb4_unicode_ci NOT NULL,
    `type` enum('info','warning','success','error','reminder') COLLATE utf8mb4_unicode_ci DEFAULT 'info',
    `is_read` tinyint(1) DEFAULT 0,
    `action_url` varchar(500) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
    `expires_at` datetime DEFAULT NULL,
    `created_at` datetime DEFAULT CURRENT_TIMESTAMP,
    PRIMARY KEY (`id`),
    KEY `user_type_id` (`user_type`,`user_id`),
    KEY `is_read` (`is_read`),
    KEY `created_at` (`created_at`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

-- جدول الجدول الزمني
CREATE TABLE IF NOT EXISTS `schedule` (
    `id` int(11) NOT NULL AUTO_INCREMENT,
    `teacher_id` int(11) NOT NULL,
    `group_id` int(11) DEFAULT NULL,
    `subject_id` int(11) DEFAULT NULL,
    `day_of_week` enum('sunday','monday','tuesday','wednesday','thursday','friday','saturday') COLLATE utf8mb4_unicode_ci NOT NULL,
    `start_time` time NOT NULL,
    `end_time` time NOT NULL,
    `room` varchar(50) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
    `notes` text COLLATE utf8mb4_unicode_ci,
    `is_active` tinyint(1) DEFAULT 1,
    `created_at` datetime DEFAULT CURRENT_TIMESTAMP,
    PRIMARY KEY (`id`),
    KEY `teacher_id` (`teacher_id`),
    KEY `group_id` (`group_id`),
    KEY `subject_id` (`subject_id`),
    KEY `day_time` (`day_of_week`,`start_time`),
    CONSTRAINT `schedule_ibfk_1` FOREIGN KEY (`teacher_id`) REFERENCES `teachers` (`id`) ON DELETE CASCADE,
    CONSTRAINT `schedule_ibfk_2` FOREIGN KEY (`group_id`) REFERENCES `groups` (`group_id`) ON DELETE SET NULL,
    CONSTRAINT `schedule_ibfk_3` FOREIGN KEY (`subject_id`) REFERENCES `subjects` (`subject_id`) ON DELETE SET NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

-- ==========================================
-- إدراج بيانات تجريبية للجداول الجديدة
-- ==========================================

-- إدراج أولياء أمور تجريبيين
INSERT INTO `parents` (`name`, `email`, `password`, `phone`, `address`, `national_id`, `job`) VALUES
('أحمد محمد علي الأب', 'ahmed.parent@example.com', '$2y$10$92IXUNpkjO0rOQ5byMi.Ye4oKoEa3Ro9llC/.og/at2.uheWG/igi', '01234567890', 'القاهرة، مصر', '12345678901234', 'مهندس'),
('فاطمة أحمد الأم', 'fatima.parent@example.com', '$2y$10$92IXUNpkjO0rOQ5byMi.Ye4oKoEa3Ro9llC/.og/at2.uheWG/igi', '01234567891', 'الإسكندرية، مصر', '12345678901235', 'طبيبة'),
('محمد حسن الأب', 'mohamed.parent@example.com', '$2y$10$92IXUNpkjO0rOQ5byMi.Ye4oKoEa3Ro9llC/.og/at2.uheWG/igi', '01234567892', 'الجيزة، مصر', '12345678901236', 'محاسب'),
('سارة علي الأم', 'sara.parent@example.com', '$2y$10$92IXUNpkjO0rOQ5byMi.Ye4oKoEa3Ro9llC/.og/at2.uheWG/igi', '01234567893', 'القاهرة، مصر', '12345678901237', 'معلمة'),
('خالد محمود الأب', 'khaled.parent@example.com', '$2y$10$92IXUNpkjO0rOQ5byMi.Ye4oKoEa3Ro9llC/.og/at2.uheWG/igi', '01234567894', 'الجيزة، مصر', '12345678901238', 'تاجر');

-- ربط الطلاب بأولياء الأمور
UPDATE `students` SET `parent_id` = 1 WHERE `student_id` = 1;
UPDATE `students` SET `parent_id` = 2 WHERE `student_id` = 2;
UPDATE `students` SET `parent_id` = 3 WHERE `student_id` = 3;
UPDATE `students` SET `parent_id` = 4 WHERE `student_id` = 4;
UPDATE `students` SET `parent_id` = 5 WHERE `student_id` = 5;

-- إدراج علاقات إضافية في جدول student_parent
INSERT INTO `student_parent` (`student_id`, `parent_id`, `relationship`, `is_primary`) VALUES
(1, 1, 'father', 1),
(2, 2, 'mother', 1),
(3, 3, 'father', 1),
(4, 4, 'mother', 1),
(5, 5, 'father', 1);

-- إدراج تقييمات تجريبية
INSERT INTO `evaluations` (`student_id`, `teacher_id`, `subject_id`, `evaluation_type`, `title`, `score`, `max_score`, `evaluation_date`, `is_published`) VALUES
(1, 1, 1, 'quiz', 'اختبار الجبر الأول', 85.00, 100.00, '2024-01-25', 1),
(2, 1, 1, 'quiz', 'اختبار الجبر الأول', 92.00, 100.00, '2024-01-25', 1),
(1, 1, 2, 'exam', 'امتحان الفيزياء الشهري', 78.00, 100.00, '2024-01-30', 1),
(4, 2, 3, 'homework', 'واجب الكيمياء العضوية', 95.00, 100.00, '2024-01-28', 1),
(5, 2, 4, 'participation', 'المشاركة في الفصل', 88.00, 100.00, '2024-01-29', 1);

-- إدراج واجبات تجريبية
INSERT INTO `assignments` (`teacher_id`, `subject_id`, `group_id`, `title`, `description`, `due_date`, `max_score`, `is_published`) VALUES
(1, 1, 1, 'حل مسائل الجبر', 'حل المسائل من الصفحة 45 إلى 50', '2024-02-05 23:59:59', 100.00, 1),
(1, 2, 2, 'تقرير عن الحركة', 'كتابة تقرير مفصل عن قوانين الحركة', '2024-02-07 23:59:59', 100.00, 1),
(2, 3, 3, 'تجربة كيميائية', 'إجراء تجربة وكتابة التقرير', '2024-02-10 23:59:59', 100.00, 1);

-- إدراج رسائل تجريبية
INSERT INTO `parent_teacher_messages` (`sender_type`, `sender_id`, `receiver_type`, `receiver_id`, `student_id`, `subject`, `message`, `is_read`) VALUES
('teacher', 1, 'parent', 1, 1, 'تحسن في الأداء', 'أود إعلامكم بأن محمد يظهر تحسناً ملحوظاً في مادة الرياضيات', 0),
('parent', 2, 'teacher', 1, 2, 'استفسار عن الواجبات', 'هل يمكن توضيح طريقة حل واجب الجبر؟', 1),
('teacher', 2, 'parent', 4, 4, 'موعد اختبار', 'سيكون هناك اختبار في مادة الكيمياء يوم الأحد القادم', 0);

-- إدراج إشعارات تجريبية
INSERT INTO `notifications` (`user_type`, `user_id`, `title`, `message`, `type`, `is_read`) VALUES
('parent', 1, 'درجة جديدة', 'تم رفع درجة جديدة لمحمد في مادة الرياضيات', 'success', 0),
('parent', 2, 'رسالة من المعلم', 'لديك رسالة جديدة من المعلم أحمد', 'info', 0),
('teacher', 1, 'طالب غائب', 'الطالب عمر غائب لليوم الثالث على التوالي', 'warning', 0);

-- إدراج جدول زمني تجريبي
INSERT INTO `schedule` (`teacher_id`, `group_id`, `subject_id`, `day_of_week`, `start_time`, `end_time`, `room`) VALUES
(1, 1, 1, 'saturday', '10:00:00', '11:30:00', 'قاعة أ'),
(1, 1, 1, 'monday', '10:00:00', '11:30:00', 'قاعة أ'),
(1, 1, 1, 'wednesday', '10:00:00', '11:30:00', 'قاعة أ'),
(1, 2, 2, 'sunday', '14:00:00', '15:30:00', 'مختبر الفيزياء'),
(1, 2, 2, 'tuesday', '14:00:00', '15:30:00', 'مختبر الفيزياء'),
(2, 3, 3, 'saturday', '16:00:00', '17:30:00', 'مختبر الكيمياء'),
(2, 3, 3, 'monday', '16:00:00', '17:30:00', 'مختبر الكيمياء');

-- ==========================================
-- إنشاء فهارس إضافية لتحسين الأداء
-- ==========================================

CREATE INDEX IF NOT EXISTS `idx_parents_email_active` ON `parents`(`email`, `is_active`);
CREATE INDEX IF NOT EXISTS `idx_student_parent_primary` ON `student_parent`(`is_primary`);
CREATE INDEX IF NOT EXISTS `idx_evaluations_published` ON `evaluations`(`is_published`);
CREATE INDEX IF NOT EXISTS `idx_assignments_published` ON `assignments`(`is_published`);
CREATE INDEX IF NOT EXISTS `idx_messages_unread` ON `parent_teacher_messages`(`is_read`);
CREATE INDEX IF NOT EXISTS `idx_notifications_unread` ON `notifications`(`is_read`);
CREATE INDEX IF NOT EXISTS `idx_schedule_active` ON `schedule`(`is_active`);

COMMIT;

