<?php
session_start();
include "../includes/functions.php";
check_login();

$error = $success = "";
$upload_dir = '../../uploads/';

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    if (isset($_FILES['file']) && $_FILES['file']['error'] === UPLOAD_ERR_OK) {
        $title = sanitize_input($_POST['title']);
        $description = sanitize_input($_POST['description']);
        $tmp_name = $_FILES['file']['tmp_name'];
        $name = uniqid() . '-' . basename($_FILES['file']['name']);
        $file_path = 'uploads/' . $name;

        if (move_uploaded_file($tmp_name, $upload_dir . $name)) {
            $pdo->prepare("INSERT INTO uploaded_files (title, description, file_path, teacher_id)
                           VALUES (?, ?, ?, ?)")
                ->execute([$title, $description, $file_path, $_SESSION['teacher_id']]);
            $success = "✅ تم رفع الملف بنجاح!";
        } else {
            $error = "❌ فشل رفع الملف.";
        }
    } else {
        $error = "يرجى اختيار ملف صالح.";
    }
}

// جلب الملفات المرفوعة
$stmt = $pdo->prepare("SELECT * FROM uploaded_files WHERE teacher_id = ?");
$stmt->execute([$_SESSION['teacher_id']]);
$files = $stmt->fetchAll(PDO::FETCH_ASSOC);
?>

<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <title>رفع الملفات</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css"  rel="stylesheet">
</head>
<body>

<?php include "../includes/header.php"; ?>
<?php include "../includes/sidebar.php"; ?>

<div class="main-content container mt-4 pt-5">
    <div class="d-flex justify-content-between align-items-center mb-4">
        <h2><i class="fas fa-file-upload me-2"></i> رفع الملفات للطلاب</h2>
        <div class="welcome-message bg-light p-2 rounded shadow-sm">
            <i class="fas fa-user-shield me-2 text-primary"></i> مرحبًا بك <span class="fw-bold text-primary"><?= $_SESSION['name'] ?? 'المعلم' ?></span>
        </div>
    </div>

    <?php if ($error): ?>
        <div class="alert alert-danger"><?= $error ?></div>
    <?php endif; ?>
    <?php if ($success): ?>
        <div class="alert alert-success"><?= $success ?></div>
    <?php endif; ?>

    <form method="post" enctype="multipart/form-data">
        <div class="mb-3">
            <label class="form-label">عنوان الملف</label>
            <input type="text" name="title" class="form-control" required>
        </div>
        <div class="mb-3">
            <label class="form-label">وصف الملف</label>
            <textarea name="description" class="form-control" rows="3"></textarea>
        </div>
        <div class="mb-3">
            <label class="form-label">اختر ملف</label>
            <input type="file" name="file" class="form-control" required>
        </div>
        <button type="submit" class="btn btn-primary w-100">📤 رفع الملف</button>
    </form>

    <h3 class="mt-5">🗂️ الملفات المرفوعة</h3>
    <table class="table table-bordered table-striped text-center align-middle">
        <thead class="table-dark">
            <tr>
                <th>العنوان</th>
                <th>الوصف</th>
                <th>الملف</th>
                <th>التاريخ</th>
            </tr>
        </thead>
        <tbody>
            <?php foreach ($files as $f): ?>
                <tr>
                    <td><?= htmlspecialchars($f['title']) ?></td>
                    <td><?= htmlspecialchars($f['description']) ?></td>
                    <td><a href="../../<?= $f['file_path'] ?>" target="_blank">📄 عرض/تنزيل</a></td>
                    <td><?= date('Y-m-d', strtotime($f['uploaded_at'])) ?></td>
                </tr>
            <?php endforeach; ?>
        </tbody>
    </table>
</div>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script> 
</body>
</html>