<?php
/**
 * إعدادات قاعدة البيانات - النسخة النهائية المحسنة
 * تم التأكد من عدم وجود أي مسافات أو أسطر جديدة قبل أو بعد علامات PHP
 * تم إزالة علامة الإغلاق ?> لضمان عدم وجود إخراج غير مقصود
 */

// تضمين ملف الإعدادات العامة
if (file_exists(__DIR__ . "/../config.php")) {
    require_once __DIR__ . "/../config.php";
} else {
    // إذا لم يكن ملف config.php موجودًا، قد يكون النظام غير مثبت بعد
    // أو هناك مشكلة في المسار. يمكن توجيه المستخدم لصفحة التثبيت.
    header("Location: install.php");
    exit();
}

// التحقق من تعريف الثوابت الأساسية
if (!defined("DB_HOST") || !defined("DB_NAME") || !defined("DB_USER") || !defined("DB_PASS")) {
    die("خطأ: إعدادات قاعدة البيانات غير مكتملة في config.php");
}

$host = DB_HOST;
$port = DB_PORT;
$dbname = DB_NAME;
$username = DB_USER;
$password = DB_PASS;

try {
    $pdo = new PDO("mysql:host=$host;port=$port;dbname=$dbname;charset=utf8mb4", $username, $password);
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
    $pdo->setAttribute(PDO::ATTR_DEFAULT_FETCH_MODE, PDO::FETCH_ASSOC);
    $pdo->setAttribute(PDO::ATTR_EMULATE_PREPARES, false);
} catch (PDOException $e) {
    error_log("Database connection error: " . $e->getMessage());
    // يمكن توجيه المستخدم لصفحة خطأ أو عرض رسالة مناسبة
    die("خطأ في الاتصال بقاعدة البيانات. يرجى التحقق من إعدادات الخادم.");
}

// دالة مساعدة لتسجيل الأخطاء
if (!function_exists("logError")) {
    function logError($message, $file = "error.log") {
        $logFile = LOG_PATH . $file;
        $timestamp = date("Y-m-d H:i:s");
        $logMessage = "[$timestamp] $message" . PHP_EOL;
        file_put_contents($logFile, $logMessage, FILE_APPEND | LOCK_EX);
    }
}

// إنشاء المجلدات المطلوبة إذا لم تكن موجودة
$directories = [UPLOAD_PATH, CACHE_PATH, LOG_PATH];
foreach ($directories as $dir) {
    if (!is_dir($dir)) {
        mkdir($dir, 0755, true);
    }
}



