<?php
/**
 * فحص حالة التثبيت
 * يتم تضمين هذا الملف في جميع الصفحات للتأكد من اكتمال التثبيت
 */

// التحقق من وجود ملف التثبيت
if (!file_exists(__DIR__ . '/.installed') || !file_exists(__DIR__ . '/db.php')) {
    // إذا كان المستخدم يحاول الوصول لملف التثبيت، السماح له
    $currentScript = basename($_SERVER['SCRIPT_NAME']);
    if ($currentScript !== 'install.php') {
        // إعادة توجيه إلى صفحة التثبيت
        $installUrl = dirname($_SERVER['SCRIPT_NAME']) . '/install.php';
        header("Location: $installUrl");
        exit('النظام غير مثبت. يتم إعادة التوجيه إلى صفحة التثبيت...');
    }
} else {
    // إذا كان النظام مثبت ومحاولة الوصول لملف التثبيت، منع الوصول
    $currentScript = basename($_SERVER['SCRIPT_NAME']);
    if ($currentScript === 'install.php') {
        http_response_code(403);
        die('النظام مثبت بالفعل. الوصول لملف التثبيت محظور لأسباب أمنية.');
    }
}

/**
 * الحصول على معلومات التثبيت
 */
function getInstallationInfo() {
    $installFile = __DIR__ . '/.installed';
    if (file_exists($installFile)) {
        $content = file_get_contents($installFile);
        return json_decode($content, true);
    }
    return null;
}

/**
 * التحقق من إصدار النظام
 */
function checkSystemVersion() {
    $info = getInstallationInfo();
    if ($info && isset($info['version'])) {
        return $info['version'];
    }
    return 'غير محدد';
}

/**
 * التحقق من تاريخ التثبيت
 */
function getInstallationDate() {
    $info = getInstallationInfo();
    if ($info && isset($info['installed_at'])) {
        return $info['installed_at'];
    }
    return null;
}

/**
 * التحقق من صحة قاعدة البيانات
 */
function validateDatabaseConnection() {
    try {
        if (!file_exists(__DIR__ . '/db.php')) {
            return false;
        }
        
        // تضمين ملف قاعدة البيانات
        require_once __DIR__ . '/db.php';
        
        // اختبار الاتصال
        $stmt = $pdo->query("SELECT 1");
        return $stmt !== false;
        
    } catch (Exception $e) {
        error_log("Database validation error: " . $e->getMessage());
        return false;
    }
}

/**
 * التحقق من وجود الجداول المطلوبة
 */
function validateRequiredTables() {
    try {
        require_once __DIR__ . '/db.php';
        
        $requiredTables = [
            'distributors',
            'teachers', 
            'students',
            'parents',
            'student_parent',
            'parent_teacher_messages',
            'login_attempts',
            'security_settings'
        ];
        
        foreach ($requiredTables as $table) {
            $stmt = $pdo->prepare("SHOW TABLES LIKE ?");
            $stmt->execute([$table]);
            if (!$stmt->fetch()) {
                return false;
            }
        }
        
        return true;
        
    } catch (Exception $e) {
        error_log("Table validation error: " . $e->getMessage());
        return false;
    }
}

/**
 * إنشاء تقرير حالة النظام
 */
function getSystemStatus() {
    return [
        'installed' => file_exists(__DIR__ . '/.installed'),
        'database_config' => file_exists(__DIR__ . '/db.php'),
        'database_connection' => validateDatabaseConnection(),
        'required_tables' => validateRequiredTables(),
        'version' => checkSystemVersion(),
        'install_date' => getInstallationDate()
    ];
}

// تشغيل فحص التثبيت تلقائياً عند تضمين الملف
// (إلا إذا كان يتم استدعاؤه من ملف التثبيت نفسه)
if (!defined('SKIP_INSTALL_CHECK')) {
    // فحص التثبيت
}


