<?php
// فحص حالة التثبيت
require_once __DIR__ . 
'/includes/install_check.php';

session_start();
error_reporting(E_ALL);
ini_set('display_errors', 1);

// تضمين الملفات المطلوبة
include __DIR__ . '/includes/db.php';
include __DIR__ . '/includes/security.php';

// تضمين ملف الإعدادات العامة
if (file_exists(__DIR__ . "/config.php")) {
    require_once __DIR__ . "/config.php";
} else {
    // إذا لم يكن ملف config.php موجودًا، قد يكون النظام غير مثبت بعد
    // أو هناك مشكلة في المسار. يمكن توجيه المستخدم لصفحة التثبيت.
    header("Location: install.php");
    exit();
}

$error = "";
$user_type = $_POST['user_type'] ?? 'teacher';

// تنظيف الرموز المنتهية الصلاحية
cleanupExpiredTokens();

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $email = sanitizeInput($_POST['email']);
    $password = $_POST['password'];
    $user_type = sanitizeInput($_POST['user_type']);

    // التحقق من صحة البريد الإلكتروني
    if (!validateEmail($email)) {
        $error = "البريد الإلكتروني غير صحيح";
    } else {
        // التحقق من محاولات تسجيل الدخول الفاشلة
        if (!checkLoginAttempts($email)) {
            $error = "تم تجاوز عدد المحاولات المسموحة. يرجى المحاولة بعد 15 دقيقة";
        } else {
            try {
                $user_found = false;
                
                // التحقق حسب نوع المستخدم المحدد
                if ($user_type === 'teacher') {
                    $stmt = $pdo->prepare("SELECT id, name, password FROM teachers WHERE email = ? AND is_active = 1");
                    $stmt->execute([$email]);
                    $user = $stmt->fetch(PDO::FETCH_ASSOC);
                    
                    if ($user && password_verify($password, $user['password'])) {
                        $_SESSION['teacher_id'] = $user['id'];
                        $_SESSION['role'] = 'teacher';
                        $_SESSION['name'] = $user['name'];
                        $_SESSION['last_activity'] = time();
                        
                        logLoginAttempt($email, true, 'teacher');
                        header("Location: teacher/dashboard.php");
                        exit;
                    }
                } elseif ($user_type === 'distributor') {
                    // التحقق من بيانات المدير الافتراضية من config.php
                    if ($email === DEFAULT_ADMIN_EMAIL && password_verify($password, DEFAULT_ADMIN_PASSWORD)) {
                        // هذا هو المدير الافتراضي
                        $_SESSION['distributor_id'] = 0; // يمكن تعيين معرف خاص للمدير الافتراضي
                        $_SESSION['role'] = 'distributor';
                        $_SESSION['name'] = 'مدير النظام';
                        $_SESSION['last_activity'] = time();
                        
                        logLoginAttempt($email, true, 'distributor');
                        header("Location: admin/dashboard.php");
                        exit;
                    } else {
                        // التحقق من جدول الموزعين (إذا كان هناك مديرون آخرون)
                        $stmt = $pdo->prepare("SELECT id, name, password FROM distributors WHERE email = ?");
                        $stmt->execute([$email]);
                        $user = $stmt->fetch(PDO::FETCH_ASSOC);
                        
                        if ($user && password_verify($password, $user['password'])) {
                            $_SESSION['distributor_id'] = $user['id'];
                            $_SESSION['role'] = 'distributor';
                            $_SESSION['name'] = $user['name'];
                            $_SESSION['last_activity'] = time();
                            
                            logLoginAttempt($email, true, 'distributor');
                            header("Location: admin/dashboard.php");
                            exit;
                        }
                    }
                } elseif ($user_type === 'parent') {
                    $stmt = $pdo->prepare("SELECT id, name, password FROM parents WHERE email = ? AND is_active = 1");
                    $stmt->execute([$email]);
                    $user = $stmt->fetch(PDO::FETCH_ASSOC);
                    
                    if ($user && password_verify($password, $user['password'])) {
                        $_SESSION['parent_id'] = $user['id'];
                        $_SESSION['role'] = 'parent';
                        $_SESSION['name'] = $user['name'];
                        $_SESSION['last_activity'] = time();
                        
                        logLoginAttempt($email, true, 'parent');
                        header("Location: parent/dashboard.php");
                        exit;
                    }
                }

                // تسجيل محاولة فاشلة
                logLoginAttempt($email, false, $user_type);
                $error = "بيانات الدخول غير صحيحة";
                
            } catch (PDOException $e) {
                $error = "خطأ في النظام. يرجى المحاولة لاحقاً";
                error_log("Login error: " . $e->getMessage());
            }
        }
    }
}
?>

<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <title>تسجيل الدخول</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css"  rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.4/css/all.min.css">
    <style>
        .user-type-selector {
            margin-bottom: 20px;
        }
        .user-type-btn {
            border: 2px solid #dee2e6;
            background: white;
            color: #6c757d;
            transition: all 0.3s;
        }
        .user-type-btn.active {
            border-color: #0d6efd;
            background: #0d6efd;
            color: white;
        }
        .user-type-btn:hover {
            border-color: #0d6efd;
            color: #0d6efd;
        }
        .user-type-btn.active:hover {
            color: white;
        }
    </style>
</head>
<body class="bg-light">

<div class="container mt-5">
    <div class="row justify-content-center">
        <div class="col-md-6">
            <div class="card shadow-sm">
                <div class="card-header text-center bg-primary text-white">
                    <h4><i class="fas fa-lock me-2"></i> تسجيل الدخول</h4>
                </div>
                <div class="card-body">
                    <?php if (!empty($error)): ?>
                        <div class="alert alert-danger d-flex align-items-center">
                            <i class="fas fa-exclamation-circle me-2"></i> <?= htmlspecialchars($error) ?>
                        </div>
                    <?php endif; ?>

                    <form method="post" id="loginForm">
                        <!-- اختيار نوع المستخدم -->
                        <div class="user-type-selector">
                            <label class="form-label"><i class="fas fa-users me-1"></i> نوع المستخدم</label>
                            <div class="row g-2">
                                <div class="col-4">
                                    <input type="radio" class="btn-check" name="user_type" id="teacher" value="teacher" <?= $user_type === 'teacher' ? 'checked' : '' ?>>
                                    <label class="btn user-type-btn w-100" for="teacher">
                                        <i class="fas fa-chalkboard-teacher d-block mb-1"></i>
                                        معلم
                                    </label>
                                </div>
                                <div class="col-4">
                                    <input type="radio" class="btn-check" name="user_type" id="distributor" value="distributor" <?= $user_type === 'distributor' ? 'checked' : '' ?>>
                                    <label class="btn user-type-btn w-100" for="distributor">
                                        <i class="fas fa-user-cog d-block mb-1"></i>
                                        مدير
                                    </label>
                                </div>
                                <div class="col-4">
                                    <input type="radio" class="btn-check" name="user_type" id="parent" value="parent" <?= $user_type === 'parent' ? 'checked' : '' ?>>
                                    <label class="btn user-type-btn w-100" for="parent">
                                        <i class="fas fa-user-friends d-block mb-1"></i>
                                        ولي أمر
                                    </label>
                                </div>
                            </div>
                        </div>

                        <div class="mb-3">
                            <label class="form-label"><i class="fas fa-envelope me-1"></i> البريد الإلكتروني</label>
                            <div class="input-group">
                                <span class="input-group-text"><i class="fas fa-envelope"></i></span>
                                <input type="email" name="email" class="form-control" value="<?= htmlspecialchars($_POST['email'] ?? '') ?>" required>
                            </div>
                        </div>
                        <div class="mb-3">
                            <label class="form-label"><i class="fas fa-key me-1"></i> كلمة المرور</label>
                            <div class="input-group">
                                <span class="input-group-text"><i class="fas fa-key"></i></span>
                                <input type="password" name="password" class="form-control" required>
                                <button class="btn btn-outline-secondary" type="button" id="togglePassword">
                                    <i class="fas fa-eye"></i>
                                </button>
                            </div>
                        </div>
                        <button type="submit" class="btn btn-primary w-100">
                            <i class="fas fa-sign-in-alt me-2"></i> دخول
                        </button>
                    </form>
                    
                    <div class="text-center mt-3">
                        <small class="text-muted">
                            <i class="fas fa-info-circle me-1"></i>
                            للحصول على حساب جديد، يرجى التواصل مع الإدارة
                        </small>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
<script>
// تبديل إظهار/إخفاء كلمة المرور
document.getElementById('togglePassword').addEventListener('click', function() {
    const passwordInput = document.querySelector('input[name="password"]');
    const icon = this.querySelector('i');
    
    if (passwordInput.type === 'password') {
        passwordInput.type = 'text';
        icon.classList.remove('fa-eye');
        icon.classList.add('fa-eye-slash');
    } else {
        passwordInput.type = 'password';
        icon.classList.remove('fa-eye-slash');
        icon.classList.add('fa-eye');
    }
});

// تحديث حالة أزرار نوع المستخدم
document.querySelectorAll('input[name="user_type"]').forEach(function(radio) {
    radio.addEventListener('change', function() {
        document.querySelectorAll('.user-type-btn').forEach(btn => btn.classList.remove('active'));
        if (this.checked) {
            document.querySelector('label[for="' + this.id + '"]').classList.add('active');
        }
    });
});

// تعيين الحالة الأولية
document.addEventListener('DOMContentLoaded', function() {
    const checkedRadio = document.querySelector('input[name="user_type"]:checked');
    if (checkedRadio) {
        document.querySelector('label[for="' + checkedRadio.id + '"]').classList.add('active');
    }
});
</script>
</body>
</html>

