<?php
session_start();
if (!isset($_SESSION['teacher_id'])) {
    header("Location: ../login.php");
    exit;
}

$error = $success = "";

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $current_password = $_POST['current_password'];
    $new_password = $_POST['new_password'];
    $confirm_password = $_POST['confirm_password'];

    if ($_SESSION['role'] === 'teacher') {
        $stmt = $pdo->prepare("SELECT password FROM teachers WHERE id = ?");
        $stmt->execute([$_SESSION['teacher_id']]);
        $user = $stmt->fetch();
    } else {
        $stmt = $pdo->prepare("SELECT password FROM distributors WHERE id = ?");
        $stmt->execute([$_SESSION['distributor_id']]);
        $user = $stmt->fetch();
    }

    if (!password_verify($current_password, $user['password'])) {
        $error = "كلمة المرور الحالية غير صحيحة";
    } elseif ($new_password !== $confirm_password) {
        $error = "كلمتا المرور لا تتطابقان";
    } else {
        if ($_SESSION['role'] === 'teacher') {
            $pdo->prepare("UPDATE teachers SET password = ? WHERE id = ?")
                ->execute([password_hash($new_password, PASSWORD_DEFAULT), $_SESSION['teacher_id']]);
        } else {
            $pdo->prepare("UPDATE distributors SET password = ? WHERE id = ?")
                ->execute([password_hash($new_password, PASSWORD_DEFAULT), $_SESSION['distributor_id']]);
        }
        $success = "✅ تم تحديث كلمة المرور بنجاح";
    }
}
?>

<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <title>تغيير كلمة المرور - الجوال</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css"  rel="stylesheet">
</head>
<body>

<h4 class="text-center mt-4">🔐 تغيير كلمة المرور</h4>

<div class="container mt-3">
    <?php if ($error): ?>
        <div class="alert alert-danger"><?= $error ?></div>
    <?php endif; ?>
    <?php if ($success): ?>
        <div class="alert alert-success"><?= $success ?></div>
    <?php endif; ?>

    <form method="post">
        <div class="mb-3">
            <label class="form-label">كلمة المرور الحالية</label>
            <input type="password" name="current_password" class="form-control" required>
        </div>
        <div class="mb-3">
            <label class="form-label">كلمة المرور الجديدة</label>
            <input type="password" name="new_password" class="form-control" required>
        </div>
        <div class="mb-3">
            <label class="form-label">تأكيد كلمة المرور</label>
            <input type="password" name="confirm_password" class="form-control" required>
        </div>
        <button type="submit" class="btn btn-primary w-100">💾 حفظ التغييرات</button>
    </form>
</div>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script> 
</body>
</html>