<?php
include 'auth_check.php';

$child_id = $_GET['id'] ?? 0;

// التحقق من أن الطفل مرتبط بولي الأمر
try {
    $stmt = $pdo->prepare("
        SELECT s.*, t.name as teacher_name, t.email as teacher_email, t.phone as teacher_phone,
               sp.relationship, sp.is_primary
        FROM students s
        LEFT JOIN student_parent sp ON s.student_id = sp.student_id
        LEFT JOIN teachers t ON s.teacher_id = t.id
        WHERE s.student_id = ? AND (sp.parent_id = ? OR s.parent_id = ?)
    ");
    $stmt->execute([$child_id, $_SESSION['parent_id'], $_SESSION['parent_id']]);
    $child = $stmt->fetch(PDO::FETCH_ASSOC);
    
    if (!$child) {
        header("Location: dashboard.php");
        exit;
    }
    
    // الحصول على سجل الحضور (آخر 30 يوم)
    $attendance_stmt = $pdo->prepare("
        SELECT date, status, note
        FROM attendance
        WHERE student_id = ? AND date >= DATE_SUB(CURDATE(), INTERVAL 30 DAY)
        ORDER BY date DESC
    ");
    $attendance_stmt->execute([$child_id]);
    $attendance_records = $attendance_stmt->fetchAll(PDO::FETCH_ASSOC);
    
    // حساب نسبة الحضور
    $total_sessions = count($attendance_records);
    $present_sessions = count(array_filter($attendance_records, function($record) {
        return $record['status'] === 'حاضر';
    }));
    $attendance_percentage = $total_sessions > 0 ? round(($present_sessions / $total_sessions) * 100, 1) : 0;
    
    // الحصول على الدرجات/التقييمات
    $grades_stmt = $pdo->prepare("
        SELECT e.*, s.subject_name
        FROM evaluations e
        LEFT JOIN subjects s ON e.subject_id = s.subject_id
        WHERE e.student_id = ?
        ORDER BY e.evaluation_date DESC
        LIMIT 10
    ");
    $grades_stmt->execute([$child_id]);
    $grades = $grades_stmt->fetchAll(PDO::FETCH_ASSOC);
    
    // الحصول على المدفوعات
    $payments_stmt = $pdo->prepare("
        SELECT *
        FROM payments
        WHERE student_id = ?
        ORDER BY payment_date DESC
        LIMIT 10
    ");
    $payments_stmt->execute([$child_id]);
    $payments = $payments_stmt->fetchAll(PDO::FETCH_ASSOC);
    
    // الحصول على الواجبات
    $assignments_stmt = $pdo->prepare("
        SELECT a.*, asub.submission_date, asub.status as submission_status, 
               asub.grade as assignment_grade, asub.teacher_feedback
        FROM assignments a
        LEFT JOIN assignment_submissions asub ON a.id = asub.assignment_id AND asub.student_id = ?
        WHERE a.teacher_id = ?
        ORDER BY a.due_date DESC
        LIMIT 10
    ");
    $assignments_stmt->execute([$child_id, $child['teacher_id']]);
    $assignments = $assignments_stmt->fetchAll(PDO::FETCH_ASSOC);
    
} catch (PDOException $e) {
    $error = "خطأ في استرجاع البيانات: " . $e->getMessage();
    error_log($error);
}
?>

<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>تفاصيل الطالب - <?= htmlspecialchars($child['name']) ?></title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css">
    <link rel="stylesheet" href="../assets/css/style.css">
    <style>
        .info-card {
            background: linear-gradient(135deg, #667eea 0%, #764ba2 100%);
            color: white;
            border-radius: 15px;
        }
        .stat-box {
            background: white;
            border-radius: 10px;
            padding: 20px;
            text-align: center;
            box-shadow: 0 2px 4px rgba(0,0,0,0.1);
        }
        .attendance-present { background-color: #d4edda; color: #155724; }
        .attendance-absent { background-color: #f8d7da; color: #721c24; }
        .attendance-excuse { background-color: #fff3cd; color: #856404; }
    </style>
</head>
<body class="bg-light">

<div class="container-fluid">
    <div class="row">
        <!-- القائمة الجانبية -->
        <nav class="col-md-3 col-lg-2 d-md-block sidebar collapse" style="background: linear-gradient(180deg, #2c3e50 0%, #34495e 100%); min-height: 100vh;">
            <div class="position-sticky pt-3">
                <div class="text-center mb-4">
                    <a href="dashboard.php" class="btn btn-outline-light btn-sm">
                        <i class="fas fa-arrow-right me-1"></i> العودة للرئيسية
                    </a>
                </div>
                
                <ul class="nav flex-column">
                    <li class="nav-item">
                        <a class="nav-link text-white" href="#info">
                            <i class="fas fa-info-circle me-2"></i> المعلومات الأساسية
                        </a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link text-white" href="#attendance">
                            <i class="fas fa-calendar-check me-2"></i> الحضور
                        </a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link text-white" href="#grades">
                            <i class="fas fa-star me-2"></i> الدرجات
                        </a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link text-white" href="#payments">
                            <i class="fas fa-money-bill me-2"></i> المدفوعات
                        </a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link text-white" href="#assignments">
                            <i class="fas fa-tasks me-2"></i> الواجبات
                        </a>
                    </li>
                </ul>
            </div>
        </nav>

        <!-- المحتوى الرئيسي -->
        <main class="col-md-9 ms-sm-auto col-lg-10 px-md-4">
            <div class="d-flex justify-content-between flex-wrap flex-md-nowrap align-items-center pt-3 pb-2 mb-3 border-bottom">
                <h1 class="h2"><i class="fas fa-user-graduate me-2"></i> <?= htmlspecialchars($child['name']) ?></h1>
            </div>

            <?php if (isset($error)): ?>
                <div class="alert alert-danger">
                    <i class="fas fa-exclamation-circle me-2"></i> <?= htmlspecialchars($error) ?>
                </div>
            <?php endif; ?>

            <!-- المعلومات الأساسية -->
            <section id="info" class="mb-5">
                <div class="row">
                    <div class="col-md-8">
                        <div class="card info-card">
                            <div class="card-body">
                                <h5 class="card-title"><i class="fas fa-info-circle me-2"></i> المعلومات الأساسية</h5>
                                <div class="row">
                                    <div class="col-md-6">
                                        <p><strong>الاسم:</strong> <?= htmlspecialchars($child['name']) ?></p>
                                        <p><strong>المرحلة الدراسية:</strong> <?= htmlspecialchars($child['grade_level']) ?></p>
                                        <p><strong>رقم الهاتف:</strong> <?= htmlspecialchars($child['phone']) ?></p>
                                    </div>
                                    <div class="col-md-6">
                                        <p><strong>المعلم:</strong> <?= htmlspecialchars($child['teacher_name'] ?: 'غير محدد') ?></p>
                                        <p><strong>بريد المعلم:</strong> <?= htmlspecialchars($child['teacher_email'] ?: 'غير محدد') ?></p>
                                        <p><strong>هاتف المعلم:</strong> <?= htmlspecialchars($child['teacher_phone'] ?: 'غير محدد') ?></p>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="col-md-4">
                        <div class="stat-box">
                            <i class="fas fa-calendar-check fa-2x text-primary mb-2"></i>
                            <h3 class="text-primary"><?= $attendance_percentage ?>%</h3>
                            <p class="text-muted">نسبة الحضور (30 يوم)</p>
                        </div>
                    </div>
                </div>
            </section>

            <!-- الحضور -->
            <section id="attendance" class="mb-5">
                <h3><i class="fas fa-calendar-check me-2"></i> سجل الحضور (آخر 30 يوم)</h3>
                <div class="card">
                    <div class="card-body">
                        <?php if (empty($attendance_records)): ?>
                            <div class="text-center text-muted">
                                <i class="fas fa-calendar-times fa-3x mb-3"></i>
                                <p>لا توجد سجلات حضور</p>
                            </div>
                        <?php else: ?>
                            <div class="table-responsive">
                                <table class="table table-striped">
                                    <thead>
                                        <tr>
                                            <th>التاريخ</th>
                                            <th>الحالة</th>
                                            <th>ملاحظات</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <?php foreach ($attendance_records as $record): ?>
                                            <tr>
                                                <td><?= date('Y-m-d', strtotime($record['date'])) ?></td>
                                                <td>
                                                    <span class="badge <?php
                                                        echo $record['status'] === 'حاضر' ? 'bg-success' : 
                                                             ($record['status'] === 'غائب' ? 'bg-danger' : 'bg-warning');
                                                    ?>">
                                                        <?= htmlspecialchars($record['status']) ?>
                                                    </span>
                                                </td>
                                                <td><?= htmlspecialchars($record['note'] ?: '-') ?></td>
                                            </tr>
                                        <?php endforeach; ?>
                                    </tbody>
                                </table>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
            </section>

            <!-- الدرجات -->
            <section id="grades" class="mb-5">
                <h3><i class="fas fa-star me-2"></i> الدرجات والتقييمات</h3>
                <div class="card">
                    <div class="card-body">
                        <?php if (empty($grades)): ?>
                            <div class="text-center text-muted">
                                <i class="fas fa-star fa-3x mb-3"></i>
                                <p>لا توجد درجات مسجلة</p>
                            </div>
                        <?php else: ?>
                            <div class="table-responsive">
                                <table class="table table-striped">
                                    <thead>
                                        <tr>
                                            <th>التاريخ</th>
                                            <th>النوع</th>
                                            <th>العنوان</th>
                                            <th>المادة</th>
                                            <th>الدرجة</th>
                                            <th>النهاية العظمى</th>
                                            <th>النسبة</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <?php foreach ($grades as $grade): ?>
                                            <tr>
                                                <td><?= date('Y-m-d', strtotime($grade['evaluation_date'])) ?></td>
                                                <td>
                                                    <span class="badge bg-info">
                                                        <?= htmlspecialchars($grade['evaluation_type']) ?>
                                                    </span>
                                                </td>
                                                <td><?= htmlspecialchars($grade['title']) ?></td>
                                                <td><?= htmlspecialchars($grade['subject_name'] ?: '-') ?></td>
                                                <td><?= $grade['score'] ?></td>
                                                <td><?= $grade['max_score'] ?></td>
                                                <td>
                                                    <?php 
                                                    $percentage = ($grade['score'] / $grade['max_score']) * 100;
                                                    $badge_class = $percentage >= 85 ? 'bg-success' : ($percentage >= 70 ? 'bg-warning' : 'bg-danger');
                                                    ?>
                                                    <span class="badge <?= $badge_class ?>">
                                                        <?= round($percentage, 1) ?>%
                                                    </span>
                                                </td>
                                            </tr>
                                        <?php endforeach; ?>
                                    </tbody>
                                </table>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
            </section>

            <!-- المدفوعات -->
            <section id="payments" class="mb-5">
                <h3><i class="fas fa-money-bill me-2"></i> سجل المدفوعات</h3>
                <div class="card">
                    <div class="card-body">
                        <?php if (empty($payments)): ?>
                            <div class="text-center text-muted">
                                <i class="fas fa-money-bill fa-3x mb-3"></i>
                                <p>لا توجد مدفوعات مسجلة</p>
                            </div>
                        <?php else: ?>
                            <div class="table-responsive">
                                <table class="table table-striped">
                                    <thead>
                                        <tr>
                                            <th>التاريخ</th>
                                            <th>المبلغ المدفوع</th>
                                            <th>المبلغ المستحق</th>
                                            <th>ملاحظات</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <?php foreach ($payments as $payment): ?>
                                            <tr>
                                                <td><?= date('Y-m-d', strtotime($payment['payment_date'])) ?></td>
                                                <td class="text-success"><?= number_format($payment['amount_paid'], 2) ?> ج.م</td>
                                                <td class="text-danger"><?= number_format($payment['due_amount'], 2) ?> ج.م</td>
                                                <td><?= htmlspecialchars($payment['notes'] ?: '-') ?></td>
                                            </tr>
                                        <?php endforeach; ?>
                                    </tbody>
                                </table>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
            </section>

            <!-- الواجبات -->
            <section id="assignments" class="mb-5">
                <h3><i class="fas fa-tasks me-2"></i> الواجبات</h3>
                <div class="card">
                    <div class="card-body">
                        <?php if (empty($assignments)): ?>
                            <div class="text-center text-muted">
                                <i class="fas fa-tasks fa-3x mb-3"></i>
                                <p>لا توجد واجبات</p>
                            </div>
                        <?php else: ?>
                            <div class="table-responsive">
                                <table class="table table-striped">
                                    <thead>
                                        <tr>
                                            <th>العنوان</th>
                                            <th>الوصف</th>
                                            <th>تاريخ التسليم</th>
                                            <th>حالة التسليم</th>
                                            <th>الدرجة</th>
                                            <th>ملاحظات المعلم</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <?php foreach ($assignments as $assignment): ?>
                                            <tr>
                                                <td><?= htmlspecialchars($assignment['title']) ?></td>
                                                <td><?= htmlspecialchars($assignment['description'] ?: '-') ?></td>
                                                <td><?= $assignment['due_date'] ? date('Y-m-d', strtotime($assignment['due_date'])) : '-' ?></td>
                                                <td>
                                                    <?php if ($assignment['submission_status']): ?>
                                                        <span class="badge <?= $assignment['submission_status'] === 'submitted' ? 'bg-success' : ($assignment['submission_status'] === 'late' ? 'bg-warning' : 'bg-danger') ?>">
                                                            <?= $assignment['submission_status'] === 'submitted' ? 'مُسلم' : ($assignment['submission_status'] === 'late' ? 'متأخر' : 'مفقود') ?>
                                                        </span>
                                                    <?php else: ?>
                                                        <span class="badge bg-secondary">لم يُسلم</span>
                                                    <?php endif; ?>
                                                </td>
                                                <td><?= $assignment['assignment_grade'] ? $assignment['assignment_grade'] : '-' ?></td>
                                                <td><?= htmlspecialchars($assignment['teacher_feedback'] ?: '-') ?></td>
                                            </tr>
                                        <?php endforeach; ?>
                                    </tbody>
                                </table>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
            </section>
        </main>
    </div>
</div>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
<script>
// تمرير سلس للأقسام
document.querySelectorAll('a[href^="#"]').forEach(anchor => {
    anchor.addEventListener('click', function (e) {
        e.preventDefault();
        const target = document.querySelector(this.getAttribute('href'));
        if (target) {
            target.scrollIntoView({
                behavior: 'smooth',
                block: 'start'
            });
        }
    });
});
</script>
</body>
</html>

