<?php
include 'auth_check.php';

// الحصول على قائمة الأطفال المرتبطين بولي الأمر
try {
    $stmt = $pdo->prepare("
        SELECT s.*, t.name as teacher_name, t.email as teacher_email,
               sp.relationship, sp.is_primary
        FROM students s
        LEFT JOIN student_parent sp ON s.student_id = sp.student_id
        LEFT JOIN teachers t ON s.teacher_id = t.id
        WHERE sp.parent_id = ? OR s.parent_id = ?
        ORDER BY s.name
    ");
    $stmt->execute([$_SESSION['parent_id'], $_SESSION['parent_id']]);
    $children = $stmt->fetchAll(PDO::FETCH_ASSOC);
    
    // إحصائيات عامة
    $total_children = count($children);
    
    // حساب نسبة الحضور الإجمالية
    $attendance_stmt = $pdo->prepare("
        SELECT 
            COUNT(*) as total_sessions,
            SUM(CASE WHEN a.status = 'حاضر' THEN 1 ELSE 0 END) as present_sessions
        FROM attendance a
        JOIN students s ON a.student_id = s.student_id
        LEFT JOIN student_parent sp ON s.student_id = sp.student_id
        WHERE (sp.parent_id = ? OR s.parent_id = ?)
        AND a.date >= DATE_SUB(CURDATE(), INTERVAL 30 DAY)
    ");
    $attendance_stmt->execute([$_SESSION['parent_id'], $_SESSION['parent_id']]);
    $attendance_stats = $attendance_stmt->fetch(PDO::FETCH_ASSOC);
    
    $attendance_percentage = $attendance_stats['total_sessions'] > 0 
        ? round(($attendance_stats['present_sessions'] / $attendance_stats['total_sessions']) * 100, 1)
        : 0;
    
    // إجمالي المدفوعات المستحقة
    $payments_stmt = $pdo->prepare("
        SELECT SUM(due_amount) as total_due
        FROM payments p
        JOIN students s ON p.student_id = s.student_id
        LEFT JOIN student_parent sp ON s.student_id = sp.student_id
        WHERE (sp.parent_id = ? OR s.parent_id = ?)
        AND p.due_amount > 0
    ");
    $payments_stmt->execute([$_SESSION['parent_id'], $_SESSION['parent_id']]);
    $total_due = $payments_stmt->fetchColumn() ?: 0;
    
    // الواجبات المعلقة
    $assignments_stmt = $pdo->prepare("
        SELECT COUNT(*) as pending_assignments
        FROM assignments a
        JOIN students s ON s.teacher_id = a.teacher_id
        LEFT JOIN student_parent sp ON s.student_id = sp.student_id
        LEFT JOIN assignment_submissions asub ON a.id = asub.assignment_id AND s.student_id = asub.student_id
        WHERE (sp.parent_id = ? OR s.parent_id = ?)
        AND a.due_date >= CURDATE()
        AND asub.id IS NULL
    ");
    $assignments_stmt->execute([$_SESSION['parent_id'], $_SESSION['parent_id']]);
    $pending_assignments = $assignments_stmt->fetchColumn() ?: 0;
    
} catch (PDOException $e) {
    $error = "خطأ في استرجاع البيانات: " . $e->getMessage();
    error_log($error);
}
?>

<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>لوحة تحكم ولي الأمر</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css">
    <link rel="stylesheet" href="../assets/css/style.css">
    <style>
        .stats-card {
            background: linear-gradient(135deg, #667eea 0%, #764ba2 100%);
            color: white;
            border-radius: 15px;
            padding: 20px;
            margin-bottom: 20px;
        }
        .child-card {
            border: none;
            border-radius: 15px;
            box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
            transition: transform 0.3s ease;
        }
        .child-card:hover {
            transform: translateY(-5px);
        }
        .sidebar {
            background: linear-gradient(180deg, #2c3e50 0%, #34495e 100%);
            min-height: 100vh;
        }
        .nav-link {
            color: #ecf0f1 !important;
            border-radius: 10px;
            margin: 5px 0;
        }
        .nav-link:hover, .nav-link.active {
            background: rgba(255, 255, 255, 0.1);
            color: white !important;
        }
    </style>
</head>
<body class="bg-light">

<div class="container-fluid">
    <div class="row">
        <!-- القائمة الجانبية -->
        <nav class="col-md-3 col-lg-2 d-md-block sidebar collapse">
            <div class="position-sticky pt-3">
                <div class="text-center mb-4">
                    <i class="fas fa-user-friends fa-3x text-white mb-2"></i>
                    <h5 class="text-white">مرحباً <?= htmlspecialchars($parent['name']) ?></h5>
                </div>
                
                <ul class="nav flex-column">
                    <li class="nav-item">
                        <a class="nav-link active" href="dashboard.php">
                            <i class="fas fa-home me-2"></i> الرئيسية
                        </a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="children.php">
                            <i class="fas fa-child me-2"></i> أطفالي
                        </a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="attendance.php">
                            <i class="fas fa-calendar-check me-2"></i> الحضور
                        </a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="grades.php">
                            <i class="fas fa-star me-2"></i> الدرجات
                        </a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="payments.php">
                            <i class="fas fa-money-bill me-2"></i> المدفوعات
                        </a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="assignments.php">
                            <i class="fas fa-tasks me-2"></i> الواجبات
                        </a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="messages.php">
                            <i class="fas fa-envelope me-2"></i> الرسائل
                        </a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="profile.php">
                            <i class="fas fa-user me-2"></i> الملف الشخصي
                        </a>
                    </li>
                    <li class="nav-item mt-3">
                        <a class="nav-link text-danger" href="../logout.php">
                            <i class="fas fa-sign-out-alt me-2"></i> تسجيل الخروج
                        </a>
                    </li>
                </ul>
            </div>
        </nav>

        <!-- المحتوى الرئيسي -->
        <main class="col-md-9 ms-sm-auto col-lg-10 px-md-4">
            <div class="d-flex justify-content-between flex-wrap flex-md-nowrap align-items-center pt-3 pb-2 mb-3 border-bottom">
                <h1 class="h2"><i class="fas fa-home me-2"></i> لوحة التحكم</h1>
                <div class="btn-toolbar mb-2 mb-md-0">
                    <div class="btn-group me-2">
                        <button type="button" class="btn btn-sm btn-outline-secondary">
                            <i class="fas fa-calendar me-1"></i> <?= date('Y-m-d') ?>
                        </button>
                    </div>
                </div>
            </div>

            <?php if (isset($error)): ?>
                <div class="alert alert-danger">
                    <i class="fas fa-exclamation-circle me-2"></i> <?= htmlspecialchars($error) ?>
                </div>
            <?php endif; ?>

            <!-- الإحصائيات -->
            <div class="row mb-4">
                <div class="col-md-3">
                    <div class="stats-card text-center">
                        <i class="fas fa-child fa-2x mb-2"></i>
                        <h3><?= $total_children ?></h3>
                        <p class="mb-0">عدد الأطفال</p>
                    </div>
                </div>
                <div class="col-md-3">
                    <div class="stats-card text-center">
                        <i class="fas fa-calendar-check fa-2x mb-2"></i>
                        <h3><?= $attendance_percentage ?>%</h3>
                        <p class="mb-0">نسبة الحضور</p>
                    </div>
                </div>
                <div class="col-md-3">
                    <div class="stats-card text-center">
                        <i class="fas fa-money-bill fa-2x mb-2"></i>
                        <h3><?= number_format($total_due, 2) ?></h3>
                        <p class="mb-0">المبلغ المستحق</p>
                    </div>
                </div>
                <div class="col-md-3">
                    <div class="stats-card text-center">
                        <i class="fas fa-tasks fa-2x mb-2"></i>
                        <h3><?= $pending_assignments ?></h3>
                        <p class="mb-0">واجبات معلقة</p>
                    </div>
                </div>
            </div>

            <!-- قائمة الأطفال -->
            <div class="row">
                <div class="col-12">
                    <h3 class="mb-3"><i class="fas fa-child me-2"></i> أطفالي</h3>
                    
                    <?php if (empty($children)): ?>
                        <div class="alert alert-info text-center">
                            <i class="fas fa-info-circle fa-2x mb-3"></i>
                            <h5>لا توجد بيانات أطفال مرتبطة بحسابك</h5>
                            <p>يرجى التواصل مع الإدارة لربط حساب أطفالك</p>
                        </div>
                    <?php else: ?>
                        <div class="row">
                            <?php foreach ($children as $child): ?>
                                <div class="col-md-6 col-lg-4 mb-3">
                                    <div class="card child-card">
                                        <div class="card-body">
                                            <div class="d-flex align-items-center mb-3">
                                                <div class="bg-primary rounded-circle p-3 me-3">
                                                    <i class="fas fa-user-graduate text-white"></i>
                                                </div>
                                                <div>
                                                    <h5 class="card-title mb-1"><?= htmlspecialchars($child['name']) ?></h5>
                                                    <small class="text-muted"><?= htmlspecialchars($child['grade_level']) ?></small>
                                                </div>
                                            </div>
                                            
                                            <div class="mb-2">
                                                <small class="text-muted">المعلم:</small>
                                                <span class="fw-bold"><?= htmlspecialchars($child['teacher_name'] ?: 'غير محدد') ?></span>
                                            </div>
                                            
                                            <div class="mb-3">
                                                <small class="text-muted">حالة الدفع:</small>
                                                <span class="badge <?= $child['payment_status'] === 'paid' ? 'bg-success' : 'bg-warning' ?>">
                                                    <?= $child['payment_status'] === 'paid' ? 'مدفوع' : 'غير مدفوع' ?>
                                                </span>
                                            </div>
                                            
                                            <div class="d-grid gap-2">
                                                <a href="child_details.php?id=<?= $child['student_id'] ?>" class="btn btn-primary btn-sm">
                                                    <i class="fas fa-eye me-1"></i> عرض التفاصيل
                                                </a>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            <?php endforeach; ?>
                        </div>
                    <?php endif; ?>
                </div>
            </div>
        </main>
    </div>
</div>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>

