<?php
session_start();
include "../includes/functions.php";
check_login();

if (!isset($_GET['id'])) {
    header("Location: view-parents.php");
    exit;
}

$id = $_GET['id'];
$stmt = $pdo->prepare("SELECT * FROM parents WHERE parent_id = ? AND teacher_id = ?");
$stmt->execute([$id, $_SESSION['teacher_id']]);
$parent = $stmt->fetch();

if (!$parent) {
    header("Location: view-parents.php");
    exit;
}

$error = $success = "";

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $name = sanitize_input($_POST['name']);
    $relation = sanitize_input($_POST['relation']);
    $phone = sanitize_input($_POST['phone']);
    $whatsapp = sanitize_input($_POST['whatsapp']);

    if (empty($name) || empty($relation) || empty($phone)) {
        $error = "يرجى ملء الحقول المطلوبة";
    } else {
        $pdo->prepare("UPDATE parents SET name=?, relation=?, phone=?, whatsapp=? WHERE parent_id=?")
            ->execute([$name, $relation, $phone, $whatsapp, $id]);
        $success = "تم تحديث بيانات ولي الأمر بنجاح!";
    }
}
?>

<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <title>تعديل بيانات ولي الأمر</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css"  rel="stylesheet">
</head>
<body>

<?php include "../includes/header.php"; ?>
<?php include "../includes/sidebar.php"; ?>

<div class="main-content container mt-4 pt-5">
    <div class="d-flex justify-content-between align-items-center mb-4">
        <h2>✏️ تعديل بيانات ولي الأمر</h2>
        <div class="welcome-message bg-light p-2 rounded shadow-sm">
            <i class="fas fa-user-shield me-2 text-primary"></i> مرحبًا بك <span class="fw-bold text-primary"><?= $_SESSION['name'] ?? 'المستخدم' ?></span>
        </div>
    </div>

    <?php if ($error): ?>
        <div class="alert alert-danger"><?= $error ?></div>
    <?php endif; ?>
    <?php if ($success): ?>
        <div class="alert alert-success"><?= $success ?></div>
    <?php endif; ?>

    <form method="post">
        <div class="mb-3">
            <label class="form-label">الاسم</label>
            <input type="text" name="name" value="<?= htmlspecialchars($parent['name']) ?>" class="form-control" required>
        </div>
        <div class="mb-3">
            <label class="form-label">العلاقة بالطالب</label>
            <input type="text" name="relation" value="<?= $parent['relation'] ?>" class="form-control" required>
        </div>
        <div class="mb-3">
            <label class="form-label">رقم الجوال</label>
            <input type="text" name="phone" value="<?= $parent['phone'] ?>" class="form-control" required>
        </div>
        <div class="mb-3">
            <label class="form-label">رقم الواتساب</label>
            <input type="text" name="whatsapp" value="<?= $parent['whatsapp'] ?>" class="form-control">
        </div>
        <button type="submit" class="btn btn-primary">تحديث البيانات</button>
    </form>
</div>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script> 
</body>
</html>