<?php
session_start();
if (!isset($_SESSION['distributor_id'])) {
    header("Location: login.php");
    exit;
}

include 'includes/db.php';

$error = "";
$success = "";

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $name = $_POST['name'];
    $email = $_POST['email'];
    $password = password_hash($_POST['password'], PASSWORD_DEFAULT);
    $subscription_type = $_POST['subscription_type'];
    $subdomain = strtolower(trim($_POST['subdomain']));
    
    $start_date = date('Y-m-d');
    $end_date = ($subscription_type == 'annual') ? date('Y-m-d', strtotime('+1 year')) : date('Y-m-d', strtotime('+6 months'));

    // التحقق مما إذا كان البريد أو الدومين الفرعي مستخدمًا بالفعل
    $stmt = $pdo->prepare("SELECT * FROM teachers WHERE email = ? OR subdomain = ?");
    $stmt->execute([$email, $subdomain]);

    if ($stmt->fetch()) {
        $error = "البريد الإلكتروني أو الدومين الفرعي مستخدم بالفعل";
    } else {
        // إدخال بيانات المعلم
        $pdo->prepare("INSERT INTO teachers (name, email, password, role, subscription_type, subscription_start, subscription_end, subdomain)
                       VALUES (?, ?, ?, 'teacher', ?, ?, ?, ?)")
           ->execute([$name, $email, $password, $subscription_type, $start_date, $end_date, $subdomain]);

        $success = "✅ تم تسجيل المعلم بنجاح!";
    }
}
?>

<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <title>تسجيل معلم جديد</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css"  rel="stylesheet">
</head>
<body>

<?php include 'includes/header.php'; ?>
<?php include 'includes/sidebar.php'; ?>

<div class="main-content container mt-4">
    <h2 class="text-center mb-4">➕ تسجيل معلم جديد</h2>

    <?php if ($error): ?>
        <div class="alert alert-danger"><?= $error ?></div>
    <?php endif; ?>
    <?php if ($success): ?>
        <div class="alert alert-success"><?= $success ?></div>
    <?php endif; ?>

    <form method="post">
        <div class="mb-3">
            <label class="form-label">الاسم</label>
            <input type="text" name="name" class="form-control" required>
        </div>
        <div class="mb-3">
            <label class="form-label">البريد الإلكتروني</label>
            <input type="email" name="email" class="form-control" required>
        </div>
        <div class="mb-3">
            <label class="form-label">كلمة المرور</label>
            <input type="password" name="password" class="form-control" required>
        </div>
        <div class="mb-3">
            <label class="form-label">نوع الاشتراك</label>
            <select name="subscription_type" class="form-select" required>
                <option value="">-- اختر نوع الاشتراك --</option>
                <option value="semi_annual">اشتراك نصف سنوي</option>
                <option value="annual">اشتراك سنوي</option>
            </select>
        </div>
        <div class="mb-3">
            <label class="form-label">الدومين الفرعي</label>
            <div class="input-group">
                <input type="text" name="subdomain" class="form-control" required>
                <span class="input-group-text">.yourdomain.com</span>
            </div>
        </div>
        <button type="submit" class="btn btn-primary w-100">💾 تسجيل المعلم</button>
    </form>
</div>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script> 
</body>
</html>