-- seed_fixed.sql - ملف البيانات الأساسية المصحح
-- تم إصلاح جميع المشاكل والمراجع المفقودة

SET SQL_MODE = "NO_AUTO_VALUE_ON_ZERO";
START TRANSACTION;
SET time_zone = "+00:00";

-- ==========================================
-- الجداول الأساسية
-- ==========================================

-- جدول الموزعين (المديرين)
CREATE TABLE IF NOT EXISTS `distributors` (
    `id` int(11) NOT NULL AUTO_INCREMENT,
    `name` varchar(100) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
    `email` varchar(100) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
    `password` varchar(255) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
    `phone` varchar(20) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
    `is_active` tinyint(1) DEFAULT 1,
    `created_at` datetime DEFAULT CURRENT_TIMESTAMP,
    `updated_at` datetime DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    PRIMARY KEY (`id`),
    UNIQUE KEY `email` (`email`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

-- جدول المعلمين
CREATE TABLE IF NOT EXISTS `teachers` (
    `id` int(11) NOT NULL AUTO_INCREMENT,
    `name` varchar(100) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
    `email` varchar(100) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
    `password` varchar(255) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
    `role` enum('admin','distributor','teacher') COLLATE utf8mb4_unicode_ci DEFAULT 'teacher',
    `subscription_type` enum('annual','semi_annual','monthly') COLLATE utf8mb4_unicode_ci DEFAULT 'annual',
    `subscription_start` date DEFAULT NULL,
    `subscription_end` date DEFAULT NULL,
    `is_active` tinyint(1) DEFAULT 1,
    `subdomain` varchar(100) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
    `custom_css` text COLLATE utf8mb4_unicode_ci,
    `phone` varchar(20) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
    `address` text COLLATE utf8mb4_unicode_ci,
    `created_at` datetime DEFAULT CURRENT_TIMESTAMP,
    `updated_at` datetime DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    PRIMARY KEY (`id`),
    UNIQUE KEY `email` (`email`),
    UNIQUE KEY `subdomain` (`subdomain`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

-- جدول المواد الدراسية
CREATE TABLE IF NOT EXISTS `subjects` (
    `subject_id` int(11) NOT NULL AUTO_INCREMENT,
    `subject_name` varchar(100) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
    `teacher_id` int(11) DEFAULT NULL,
    `description` text COLLATE utf8mb4_unicode_ci,
    `is_active` tinyint(1) DEFAULT 1,
    `created_at` datetime DEFAULT CURRENT_TIMESTAMP,
    PRIMARY KEY (`subject_id`),
    KEY `teacher_id` (`teacher_id`),
    CONSTRAINT `subjects_ibfk_1` FOREIGN KEY (`teacher_id`) REFERENCES `teachers` (`id`) ON DELETE SET NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

-- جدول المجموعات
CREATE TABLE IF NOT EXISTS `groups` (
    `group_id` int(11) NOT NULL AUTO_INCREMENT,
    `group_name` varchar(100) COLLATE utf8mb4_unicode_ci NOT NULL,
    `teacher_id` int(11) DEFAULT NULL,
    `subject_id` int(11) DEFAULT NULL,
    `max_students` int(11) DEFAULT 30,
    `schedule_time` time DEFAULT NULL,
    `schedule_days` varchar(50) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
    `is_active` tinyint(1) DEFAULT 1,
    `created_at` datetime DEFAULT CURRENT_TIMESTAMP,
    PRIMARY KEY (`group_id`),
    KEY `teacher_id` (`teacher_id`),
    KEY `subject_id` (`subject_id`),
    CONSTRAINT `groups_ibfk_1` FOREIGN KEY (`teacher_id`) REFERENCES `teachers` (`id`) ON DELETE SET NULL,
    CONSTRAINT `groups_ibfk_2` FOREIGN KEY (`subject_id`) REFERENCES `subjects` (`subject_id`) ON DELETE SET NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

-- جدول الطلاب
CREATE TABLE IF NOT EXISTS `students` (
    `student_id` int(11) NOT NULL AUTO_INCREMENT,
    `name` varchar(100) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
    `grade_level` varchar(50) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
    `phone` varchar(20) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
    `parent_code` varchar(50) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
    `payment_status` enum('paid','unpaid','partial') COLLATE utf8mb4_unicode_ci DEFAULT 'unpaid',
    `group_id` int(11) DEFAULT NULL,
    `teacher_id` int(11) DEFAULT NULL,
    `parent_id` int(11) DEFAULT NULL,
    `address` text COLLATE utf8mb4_unicode_ci,
    `birth_date` date DEFAULT NULL,
    `enrollment_date` date DEFAULT CURRENT_DATE,
    `is_active` tinyint(1) DEFAULT 1,
    `notes` text COLLATE utf8mb4_unicode_ci,
    `created_at` datetime DEFAULT CURRENT_TIMESTAMP,
    `updated_at` datetime DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    PRIMARY KEY (`student_id`),
    KEY `teacher_id` (`teacher_id`),
    KEY `group_id` (`group_id`),
    KEY `parent_id` (`parent_id`),
    CONSTRAINT `students_ibfk_1` FOREIGN KEY (`teacher_id`) REFERENCES `teachers` (`id`) ON DELETE SET NULL,
    CONSTRAINT `students_ibfk_2` FOREIGN KEY (`group_id`) REFERENCES `groups` (`group_id`) ON DELETE SET NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

-- جدول الحضور
CREATE TABLE IF NOT EXISTS `attendance` (
    `id` int(11) NOT NULL AUTO_INCREMENT,
    `student_id` int(11) NOT NULL,
    `teacher_id` int(11) NOT NULL,
    `date` date NOT NULL,
    `status` enum('present','absent','late','excused') COLLATE utf8mb4_unicode_ci DEFAULT 'present',
    `notes` text COLLATE utf8mb4_unicode_ci,
    `created_at` datetime DEFAULT CURRENT_TIMESTAMP,
    PRIMARY KEY (`id`),
    UNIQUE KEY `unique_attendance` (`student_id`,`date`),
    KEY `teacher_id` (`teacher_id`),
    KEY `date` (`date`),
    CONSTRAINT `attendance_ibfk_1` FOREIGN KEY (`student_id`) REFERENCES `students` (`student_id`) ON DELETE CASCADE,
    CONSTRAINT `attendance_ibfk_2` FOREIGN KEY (`teacher_id`) REFERENCES `teachers` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

-- جدول المدفوعات
CREATE TABLE IF NOT EXISTS `payments` (
    `id` int(11) NOT NULL AUTO_INCREMENT,
    `student_id` int(11) NOT NULL,
    `teacher_id` int(11) NOT NULL,
    `amount` decimal(10,2) NOT NULL,
    `due_amount` decimal(10,2) DEFAULT 0.00,
    `payment_date` date DEFAULT CURRENT_DATE,
    `payment_method` enum('cash','bank_transfer','online','check') COLLATE utf8mb4_unicode_ci DEFAULT 'cash',
    `payment_type` enum('monthly','semester','annual','registration') COLLATE utf8mb4_unicode_ci DEFAULT 'monthly',
    `status` enum('paid','pending','overdue','cancelled') COLLATE utf8mb4_unicode_ci DEFAULT 'paid',
    `notes` text COLLATE utf8mb4_unicode_ci,
    `receipt_number` varchar(50) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
    `created_at` datetime DEFAULT CURRENT_TIMESTAMP,
    PRIMARY KEY (`id`),
    KEY `student_id` (`student_id`),
    KEY `teacher_id` (`teacher_id`),
    KEY `payment_date` (`payment_date`),
    CONSTRAINT `payments_ibfk_1` FOREIGN KEY (`student_id`) REFERENCES `students` (`student_id`) ON DELETE CASCADE,
    CONSTRAINT `payments_ibfk_2` FOREIGN KEY (`teacher_id`) REFERENCES `teachers` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

-- ==========================================
-- إدراج البيانات التجريبية
-- ==========================================

-- إدراج معلم تجريبي
INSERT INTO `teachers` (`name`, `email`, `password`, `role`, `subscription_type`, `subscription_start`, `subscription_end`, `is_active`, `phone`) VALUES
('أحمد محمد المعلم', 'teacher@example.com', '$2y$10$92IXUNpkjO0rOQ5byMi.Ye4oKoEa3Ro9llC/.og/at2.uheWG/igi', 'teacher', 'annual', '2024-01-01', '2024-12-31', 1, '01234567890'),
('فاطمة علي المعلمة', 'teacher2@example.com', '$2y$10$92IXUNpkjO0rOQ5byMi.Ye4oKoEa3Ro9llC/.og/at2.uheWG/igi', 'teacher', 'annual', '2024-01-01', '2024-12-31', 1, '01234567891');

-- إدراج المواد الدراسية
INSERT INTO `subjects` (`subject_name`, `teacher_id`, `description`) VALUES
('الرياضيات', 1, 'مادة الرياضيات للمرحلة الثانوية'),
('الفيزياء', 1, 'مادة الفيزياء للمرحلة الثانوية'),
('الكيمياء', 2, 'مادة الكيمياء للمرحلة الثانوية'),
('اللغة العربية', 2, 'مادة اللغة العربية');

-- إدراج المجموعات
INSERT INTO `groups` (`group_name`, `teacher_id`, `subject_id`, `max_students`, `schedule_time`, `schedule_days`) VALUES
('مجموعة الرياضيات أ', 1, 1, 25, '10:00:00', 'السبت,الاثنين,الأربعاء'),
('مجموعة الفيزياء أ', 1, 2, 20, '14:00:00', 'الأحد,الثلاثاء,الخميس'),
('مجموعة الكيمياء أ', 2, 3, 30, '16:00:00', 'السبت,الاثنين'),
('مجموعة اللغة العربية أ', 2, 4, 35, '09:00:00', 'الأحد,الثلاثاء,الخميس');

-- إدراج طلاب تجريبيين
INSERT INTO `students` (`name`, `grade_level`, `phone`, `parent_code`, `payment_status`, `group_id`, `teacher_id`, `address`, `enrollment_date`) VALUES
('محمد أحمد علي', 'الثالث الثانوي', '01111111111', 'PAR001', 'paid', 1, 1, 'القاهرة، مصر', '2024-01-15'),
('سارة محمد حسن', 'الثالث الثانوي', '01222222222', 'PAR002', 'paid', 1, 1, 'الجيزة، مصر', '2024-01-16'),
('عمر خالد محمود', 'الثاني الثانوي', '01333333333', 'PAR003', 'unpaid', 2, 1, 'الإسكندرية، مصر', '2024-01-17'),
('نور فاطمة أحمد', 'الثالث الثانوي', '01444444444', 'PAR004', 'paid', 3, 2, 'القاهرة، مصر', '2024-01-18'),
('يوسف علي حسن', 'الثاني الثانوي', '01555555555', 'PAR005', 'partial', 4, 2, 'الجيزة، مصر', '2024-01-19');

-- إدراج بيانات حضور تجريبية
INSERT INTO `attendance` (`student_id`, `teacher_id`, `date`, `status`, `notes`) VALUES
(1, 1, '2024-01-20', 'present', ''),
(2, 1, '2024-01-20', 'present', ''),
(3, 1, '2024-01-20', 'absent', 'مريض'),
(1, 1, '2024-01-22', 'present', ''),
(2, 1, '2024-01-22', 'late', 'تأخر 10 دقائق');

-- إدراج بيانات مدفوعات تجريبية
INSERT INTO `payments` (`student_id`, `teacher_id`, `amount`, `due_amount`, `payment_date`, `payment_method`, `payment_type`, `status`, `receipt_number`) VALUES
(1, 1, 500.00, 0.00, '2024-01-15', 'cash', 'monthly', 'paid', 'REC001'),
(2, 1, 500.00, 0.00, '2024-01-16', 'bank_transfer', 'monthly', 'paid', 'REC002'),
(3, 1, 500.00, 500.00, '2024-01-17', 'cash', 'monthly', 'pending', 'REC003'),
(4, 2, 450.00, 0.00, '2024-01-18', 'cash', 'monthly', 'paid', 'REC004'),
(5, 2, 450.00, 225.00, '2024-01-19', 'cash', 'monthly', 'paid', 'REC005');

-- ==========================================
-- إنشاء الفهارس لتحسين الأداء
-- ==========================================

-- فهارس للبحث السريع
CREATE INDEX IF NOT EXISTS `idx_students_teacher_active` ON `students`(`teacher_id`, `is_active`);
CREATE INDEX IF NOT EXISTS `idx_students_group_active` ON `students`(`group_id`, `is_active`);
CREATE INDEX IF NOT EXISTS `idx_attendance_student_date` ON `attendance`(`student_id`, `date`);
CREATE INDEX IF NOT EXISTS `idx_payments_student_date` ON `payments`(`student_id`, `payment_date`);
CREATE INDEX IF NOT EXISTS `idx_payments_status` ON `payments`(`status`);
CREATE INDEX IF NOT EXISTS `idx_teachers_active` ON `teachers`(`is_active`);
CREATE INDEX IF NOT EXISTS `idx_groups_teacher_active` ON `groups`(`teacher_id`, `is_active`);

COMMIT;

