<?php
session_start();
include "../includes/functions.php";

$error = $success = "";

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $current_password = $_POST['current_password'];
    $new_password = $_POST['new_password'];
    $confirm_password = $_POST['confirm_password'];

    if ($_SESSION['role'] === 'teacher') {
        $stmt = $pdo->prepare("SELECT password FROM teachers WHERE id = ?");
        $stmt->execute([$_SESSION['teacher_id']]);
        $user = $stmt->fetch();
    } else {
        $stmt = $pdo->prepare("SELECT password FROM distributors WHERE id = ?");
        $stmt->execute([$_SESSION['distributor_id']]);
        $user = $stmt->fetch();
    }

    if (!password_verify($current_password, $user['password'])) {
        $error = "كلمة المرور الحالية غير صحيحة";
    } elseif ($new_password !== $confirm_password) {
        $error = "كلمتا المرور لا تتطابقان";
    } else {
        if ($_SESSION['role'] === 'teacher') {
            $pdo->prepare("UPDATE teachers SET password = ? WHERE id = ?")
                ->execute([password_hash($new_password, PASSWORD_DEFAULT), $_SESSION['teacher_id']]);
        } else {
            $pdo->prepare("UPDATE distributors SET password = ? WHERE id = ?")
                ->execute([password_hash($new_password, PASSWORD_DEFAULT), $_SESSION['distributor_id']]);
        }
        $success = "✅ تم تحديث كلمة المرور بنجاح";
    }
}
?>

<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <title>تغيير كلمة المرور</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css"  rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css" rel="stylesheet">
    <link rel="stylesheet" href="../assets/css/main.css">
    <script src="../assets/js/main.js"></script>
</head>
<body>

<?php include "../includes/header.php"; ?>
<?php include "../includes/sidebar.php"; ?>

<div class="main-content container mt-4 pt-5">
    <div class="d-flex justify-content-between align-items-center mb-4">
        <h2><i class="fas fa-key me-2"></i> تغيير كلمة المرور</h2>
        <div class="welcome-message bg-light p-2 rounded shadow-sm">
            <i class="fas fa-user-shield me-2 text-primary"></i> مرحبًا بك <span class="fw-bold text-primary"><?= $_SESSION['name'] ?? 'المستخدم' ?></span>
        </div>
    </div>
    
    <?php if ($error): ?>
        <div class="alert alert-danger"><i class="fas fa-exclamation-circle me-2"></i><?= $error ?></div>
    <?php endif; ?>
    <?php if ($success): ?>
        <div class="alert alert-success"><i class="fas fa-check-circle me-2"></i><?= $success ?></div>
    <?php endif; ?>

    <form method="post" class="card p-4 shadow-sm">
        <div class="mb-3">
            <label class="form-label">كلمة المرور الحالية</label>
            <div class="input-group">
                <span class="input-group-text"><i class="fas fa-lock"></i></span>
                <input type="password" name="current_password" class="form-control" required>
            </div>
        </div>
        <div class="mb-3">
            <label class="form-label">كلمة المرور الجديدة</label>
            <div class="input-group">
                <span class="input-group-text"><i class="fas fa-key"></i></span>
                <input type="password" name="new_password" class="form-control" required>
            </div>
        </div>
        <div class="mb-3">
            <label class="form-label">تأكيد كلمة المرور الجديدة</label>
            <div class="input-group">
                <span class="input-group-text"><i class="fas fa-check-double"></i></span>
                <input type="password" name="confirm_password" class="form-control" required>
            </div>
        </div>
        <button type="submit" class="btn btn-primary"><i class="fas fa-save me-2"></i> حفظ التغييرات</button>
    </form>
</div>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script> 
</body>
</html>