<?php
session_start();
include "../../includes/functions.php";
check_login();

if (!isset($_GET['group_id'])) {
    header("Location: groups.php");
    exit;
}

$group_id = $_GET['group_id'];
$stmt = $pdo->prepare("SELECT g.*, s.subject_name FROM groups g
                        JOIN subjects s ON g.subject_id = s.subject_id
                        WHERE g.group_id = ? AND g.teacher_id = ?");
$stmt->execute([$group_id, $_SESSION['teacher_id']]);
$group = $stmt->fetch();

if (!$group) {
    header("Location: groups.php");
    exit;
}

$error = $success = "";

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $subject_id = $_POST['subject_id'];
    $group_name = sanitize_input($_POST['group_name']);
    $day = $_POST['day'];
    $time = $_POST['time'];
    $capacity = $_POST['capacity'];
    $payment_type = $_POST['payment_type'];

    $pdo->prepare("UPDATE groups SET subject_id=?, group_name=?, day=?, time=?, capacity=?, payment_type=?
                    WHERE group_id=? AND teacher_id=?")
        ->execute([$subject_id, $group_name, $day, $time, $capacity, $payment_type, $group_id, $_SESSION['teacher_id']]);
    $success = "✅ تم تحديث بيانات المجموعة بنجاح!";
}
?>

<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <title>تعديل المجموعة</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css"  rel="stylesheet">
</head>
<body>

<?php include "../../includes/header.php"; ?>
<?php include "../../includes/sidebar.php"; ?>

<div class="main-content container mt-4 pt-5">
    <div class="d-flex justify-content-between align-items-center mb-4">
        <h2>🛠️ تعديل بيانات المجموعة</h2>
        <div class="welcome-message bg-light p-2 rounded shadow-sm">
            <i class="fas fa-user-shield me-2 text-primary"></i> مرحبًا بك <span class="fw-bold text-primary"><?= $_SESSION['name'] ?? 'المستخدم' ?></span>
        </div>
    </div>

    <?php if ($error): ?>
        <div class="alert alert-danger"><?= $error ?></div>
    <?php endif; ?>
    <?php if ($success): ?>
        <div class="alert alert-success"><?= $success ?></div>
    <?php endif; ?>

    <form method="post">
        <div class="row g-3 mb-3">
            <div class="col-md-6">
                <label class="form-label">اختر مادة</label>
                <select name="subject_id" class="form-select" required>
                    <?php
                    $stmt = $pdo->query("SELECT subject_id, subject_name FROM subjects WHERE teacher_id = ".$_SESSION['teacher_id']);
                    while ($s = $stmt->fetch()):
                    ?>
                        <option value="<?= $s['subject_id'] ?>" <?= $s['subject_id'] == $group['subject_id'] ? 'selected' : '' ?>>
                            <?= htmlspecialchars($s['subject_name']) ?>
                        </option>
                    <?php endwhile; ?>
                </select>
            </div>
            <div class="col-md-6">
                <label class="form-label">اسم المجموعة</label>
                <input type="text" name="group_name" value="<?= htmlspecialchars($group['group_name']) ?>" class="form-control" required>
            </div>
        </div>

        <div class="row g-3 mb-3 mt-3">
            <div class="col-md-6">
                <label class="form-label">اليوم</label>
                <select name="day" class="form-select" required>
                    <option value="السبت" <?= $group['day'] == 'السبت' ? 'selected' : '' ?>>السبت</option>
                    <option value="الأحد" <?= $group['day'] == 'الأحد' ? 'selected' : '' ?>>الأحد</option>
                    <option value="الاثنين" <?= $group['day'] == 'الاثنين' ? 'selected' : '' ?>>الاثنين</option>
                    <option value="الثلاثاء" <?= $group['day'] == 'الثلاثاء' ? 'selected' : '' ?>>الثلاثاء</option>
                    <option value="الأربعاء" <?= $group['day'] == 'الأربعاء' ? 'selected' : '' ?>>الأربعاء</option>
                    <option value="الخميس" <?= $group['day'] == 'الخميس' ? 'selected' : '' ?>>الخميس</option>
				    <option value="الجمعة" <?= $group['day'] == 'الجمعة' ? 'selected' : '' ?>>الجمعة</option>

                </select>
            </div>
            <div class="col-md-6">
                <label class="form-label">الوقت</label>
                <input type="time" name="time" value="<?= date('H:i', strtotime($group['time'])) ?>" class="form-control" required>
            </div>
        </div>

        <div class="row g-3 mb-3 mt-3">
            <div class="col-md-6">
                <label class="form-label">عدد الطلاب</label>
                <input type="number" name="capacity" value="<?= $group['capacity'] ?>" class="form-control" min="1" max="50" required>
            </div>
            <div class="col-md-6">
                <label class="form-label">نوع الدفع</label>
                <select name="payment_type" class="form-select" required>
                    <option value="monthly" <?= $group['payment_type'] == 'monthly' ? 'selected' : '' ?>>شهري</option>
                    <option value="per_session" <?= $group['payment_type'] == 'per_session' ? 'selected' : '' ?>>لكل جلسة</option>
                </select>
            </div>
        </div>

        <button type="submit" class="btn btn-primary mt-3">💾 حفظ التعديلات</button>
    </form>
</div>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script> 
</body>
</html>