<?php
session_start();
include "../../includes/functions.php";
check_login();

if (!isset($_GET['id'])) {
    header("Location: subjects.php");
    exit;
}

$subject_id = $_GET['id'];
$stmt = $pdo->prepare("SELECT * FROM subjects WHERE subject_id = ? AND teacher_id = ?");
$stmt->execute([$subject_id, $_SESSION['teacher_id']]);
$subject = $stmt->fetch();

if (!$subject) {
    header("Location: subjects.php");
    exit;
}

$error = $success = "";

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $new_name = sanitize_input($_POST['subject_name']);
    if (empty($new_name)) {
        $error = "يرجى إدخال اسم المادة";
    } else {
        $pdo->prepare("UPDATE subjects SET subject_name = ? WHERE subject_id = ?")
            ->execute([$new_name, $subject_id]);
        $success = "✅ تم تحديث اسم المادة بنجاح!";
    }
}
?>

<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <title>تعديل المادة</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css"  rel="stylesheet">
</head>
<body>

<?php include "../../includes/header.php"; ?>
<?php include "../../includes/sidebar.php"; ?>

<div class="main-content container mt-4 pt-5">
    <div class="d-flex justify-content-between align-items-center mb-4">
        <h2>✏️ تعديل اسم المادة</h2>
        <div class="welcome-message bg-light p-2 rounded shadow-sm">
            <i class="fas fa-user-shield me-2 text-primary"></i> مرحبًا بك <span class="fw-bold text-primary"><?= $_SESSION['name'] ?? 'المستخدم' ?></span>
        </div>
    </div>

    <?php if ($error): ?>
        <div class="alert alert-danger"><?= $error ?></div>
    <?php endif; ?>
    <?php if ($success): ?>
        <div class="alert alert-success"><?= $success ?></div>
    <?php endif; ?>

    <form method="post">
        <div class="mb-3">
            <label class="form-label">اسم المادة</label>
            <input type="text" name="subject_name" value="<?= htmlspecialchars($subject['subject_name']) ?>" class="form-control" required>
        </div>
        <button type="submit" class="btn btn-primary">تحديث الاسم</button>
    </form>
</div>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script> 
</body>
</html>