<?php
session_start();
include "../../includes/functions.php";
check_login();

// جلب المجموعات الخاصة بالمعلم
$stmt = $pdo->prepare("SELECT g.group_id, s.subject_name, g.group_name, g.day, g.time, g.capacity, g.payment_type 
                        FROM groups g
                        JOIN subjects s ON g.subject_id = s.subject_id
                        WHERE g.teacher_id = ?");
$stmt->execute([$_SESSION['teacher_id']]);
$groups = $stmt->fetchAll(PDO::FETCH_ASSOC);

$error = $success = "";

if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['group_name'])) {
    $subject_id = $_POST['subject_id'];
    $group_name = sanitize_input($_POST['group_name']);
    $day = $_POST['day'];
    $time = $_POST['time'];
    $capacity = $_POST['capacity'];
    $payment_type = $_POST['payment_type'];

    $pdo->prepare("INSERT INTO groups (subject_id, group_name, day, time, capacity, payment_type, teacher_id)
                   VALUES (?, ?, ?, ?, ?, ?, ?)")
        ->execute([$subject_id, $group_name, $day, $time, $capacity, $payment_type, $_SESSION['teacher_id']]);
    $success = "تم إنشاء المجموعة بنجاح!";
}
?>

<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <title>إدارة المجموعات</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css"  rel="stylesheet">
</head>
<body>

<?php include "../../includes/header.php"; ?>
<?php include "../../includes/sidebar.php"; ?>

<div class="main-content container mt-4 pt-5">
    <div class="d-flex justify-content-between align-items-center mb-3">
        <h2>👥 إدارة المجموعات</h2>
        <div class="d-flex align-items-center gap-3">
            <div class="welcome-message bg-light p-2 rounded shadow-sm">
                <i class="fas fa-user-shield me-2 text-primary"></i> مرحبًا بك <span class="fw-bold text-primary"><?= $_SESSION['name'] ?? 'المستخدم' ?></span>
            </div>
            <button class="btn btn-success" data-bs-toggle="modal" data-bs-target="#addGroupModal">➕ إضافة مجموعة جديدة</button>
        </div>
    </div>

    <table class="table table-bordered table-striped text-center">
        <thead class="table-dark">
            <tr>
                <th>#</th>
                <th>اسم المادة</th>
                <th>اسم المجموعة</th>
                <th>اليوم</th>
                <th>الوقت</th>
                <th>العدد</th>
                <th>طريقة الدفع</th>
                <th>الإجراءات</th>
            </tr>
        </thead>
        <tbody>
            <?php foreach ($groups as $g): ?>
                <tr>
                    <td><?= $g['group_id'] ?></td>
                    <td><?= $g['subject_name'] ?></td>
                    <td><?= htmlspecialchars($g['group_name']) ?></td>
                    <td><?= $g['day'] ?></td>
                    <td><?= date("g:i A", strtotime($g['time'])) ?></td>
                    <td><?= $g['capacity'] ?></td>
                    <td><?= $g['payment_type'] ?></td>
                    <td>
                        <a href="edit-group.php?id=<?= $g['group_id'] ?>" class="btn btn-sm btn-primary me-1">✏️ تعديل</a>
                        <a href="?delete_id=<?= $g['group_id'] ?>" onclick="return confirm('هل أنت متأكد؟')" class="btn btn-sm btn-danger me-1">🗑️ حذف</a>
                    </td>
                </tr>
            <?php endforeach; ?>
        </tbody>
    </table>
</div>

<!-- نموذج إضافة مجموعة -->
<div class="modal fade" id="addGroupModal" tabindex="-1">
    <div class="modal-dialog modal-lg">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title">إنشاء مجموعة جديدة</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
            </div>
            <div class="modal-body">
                <form method="post">
                    <div class="row g-3">
                        <div class="col-md-6">
                            <label class="form-label">اختر مادة</label>
                            <select name="subject_id" class="form-select" required>
                                <?php
                                $stmt = $pdo->query("SELECT subject_id, subject_name FROM subjects WHERE teacher_id = ".$_SESSION['teacher_id']);
                                while ($s = $stmt->fetch()):
                                ?>
                                    <option value="<?= $s['subject_id'] ?>"><?= $s['subject_name'] ?></option>
                                <?php endwhile; ?>
                            </select>
                        </div>
                        <div class="col-md-6">
                            <label class="form-label">اسم المجموعة</label>
                            <input type="text" name="group_name" class="form-control" required>
                        </div>
                    </div>

                    <div class="row g-3 mt-3">
                        <div class="col-md-6">
                            <label class="form-label">اليوم</label>
                            <select name="day" class="form-select" required>
                                <option value="">-- اختر يوم --</option>
								<option value="السبت">السبت</option>
                                <option value="الأحد">الأحد</option>
                                <option value="الاثنين">الاثنين</option>
                                <option value="الثلاثاء">الثلاثاء</option>
                                <option value="الأربعاء">الأربعاء</option>
                                <option value="الخميس">الخميس</option>
								<option value="الجمعة">الجمعة</option>
                            </select>
                        </div>
                        <div class="col-md-6">
                            <label class="form-label">الوقت</label>
                            <input type="time" name="time" class="form-control" required>
                        </div>
                    </div>

                    <div class="row g-3 mt-3">
                        <div class="col-md-6">
                            <label class="form-label">الحد الأقصى للطلاب</label>
                            <input type="number" name="capacity" class="form-control" min="1" max="100" required>
                        </div>
                        <div class="col-md-6">
                            <label class="form-label">نوع الدفع</label>
                            <select name="payment_type" class="form-select" required>
                                <option value="">-- اختر نوع الدفع --</option>
                                <option value="monthly">شهري</option>
                                <option value="per_session">لكل جلسة</option>
                            </select>
                        </div>
                    </div>

                    <button type="submit" class="btn btn-primary mt-4 w-100">💾 حفظ المجموعة</button>
                </form>
            </div>
        </div>
    </div>
</div>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script> 
</body>
</html>