<?php
session_start();
include "../../includes/functions.php";
check_login();

// جلب المواد الخاصة بالمعلم
$stmt = $pdo->prepare("SELECT * FROM subjects WHERE teacher_id = ?");
$stmt->execute([$_SESSION['teacher_id']]);
$subjects = $stmt->fetchAll(PDO::FETCH_ASSOC);

$error = $success = "";

if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['subject_name'])) {
    $subject_name = sanitize_input($_POST['subject_name']);
    $pdo->prepare("INSERT INTO subjects (subject_name, teacher_id) VALUES (?, ?)")
        ->execute([$subject_name, $_SESSION['teacher_id']]);
    $success = "✅ تم إضافة المادة بنجاح";
}
?>

<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <title>إدارة المواد</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css"  rel="stylesheet">
</head>
<body>

<?php include "../../includes/header.php"; ?>
<?php include "../../includes/sidebar.php"; ?>

<div class="main-content container mt-4 pt-5">
    <div class="d-flex justify-content-between align-items-center mb-3">
        <h2>📚 إدارة المواد الدراسية</h2>
        <div class="d-flex align-items-center gap-3">
            <div class="welcome-message bg-light p-2 rounded shadow-sm">
                <i class="fas fa-user-shield me-2 text-primary"></i> مرحبًا بك <span class="fw-bold text-primary"><?= $_SESSION['name'] ?? 'المستخدم' ?></span>
            </div>
            <a href="#" class="btn btn-success" data-bs-toggle="modal" data-bs-target="#addSubjectModal">➕ إضافة مادة جديدة</a>
        </div>
    </div>

    <!-- قائمة المواد -->
    <table class="table table-bordered table-striped text-center">
        <thead class="table-dark">
            <tr>
                <th>#</th>
                <th>اسم المادة</th>
                <th>الإجراءات</th>
            </tr>
        </thead>
        <tbody>
            <?php foreach ($subjects as $subject): ?>
                <tr>
                    <td><?= $subject['subject_id'] ?></td>
                    <td><?= htmlspecialchars($subject['subject_name']) ?></td>
                    <td>
                        <a href="edit-subject.php?id=<?= $subject['subject_id'] ?>" class="btn btn-sm btn-primary me-1">✏️ تعديل</a>
                        <a href="?delete_id=<?= $subject['subject_id'] ?>" onclick="return confirm('هل أنت متأكد؟')" class="btn btn-sm btn-danger me-1">🗑️ حذف</a>
                    </td>
                </tr>
            <?php endforeach; ?>
        </tbody>
    </table>
</div>

<!-- نموذج إضافة مادة -->
<div class="modal fade" id="addSubjectModal" tabindex="-1">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title">إضافة مادة جديدة</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
            </div>
            <div class="modal-body">
                <form method="post">
                    <div class="mb-3">
                        <label class="form-label">اسم المادة</label>
                        <input type="text" name="subject_name" class="form-control" required>
                    </div>
                    <button type="submit" class="btn btn-primary w-100">حفظ</button>
                </form>
            </div>
        </div>
    </div>
</div>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script> 
</body>
</html>