<?php
/**
 * صفحة حالة النظام - للمديرين فقط
 */

// تعريف ثابت لتجنب فحص التثبيت
define('SKIP_INSTALL_CHECK', true);

session_start();

// التحقق من تسجيل دخول المدير
if (!isset($_SESSION['distributor_id']) || $_SESSION['role'] !== 'distributor') {
    header('Location: login.php');
    exit();
}

require_once 'includes/install_check.php';

// الحصول على حالة النظام
$systemStatus = getSystemStatus();

// معلومات إضافية
$phpVersion = PHP_VERSION;
$extensions = get_loaded_extensions();
$memoryLimit = ini_get('memory_limit');
$maxExecutionTime = ini_get('max_execution_time');
$uploadMaxFilesize = ini_get('upload_max_filesize');

// معلومات قاعدة البيانات
$dbInfo = [];
if ($systemStatus['database_connection']) {
    try {
        require_once 'includes/db.php';
        
        // حجم قاعدة البيانات
        $stmt = $pdo->query("
            SELECT 
                ROUND(SUM(data_length + index_length) / 1024 / 1024, 2) AS db_size_mb,
                COUNT(*) as table_count
            FROM information_schema.tables 
            WHERE table_schema = DATABASE()
        ");
        $dbStats = $stmt->fetch();
        
        $dbInfo = [
            'size_mb' => $dbStats['db_size_mb'] ?? 0,
            'table_count' => $dbStats['table_count'] ?? 0,
            'version' => $pdo->query("SELECT VERSION()")->fetchColumn()
        ];
        
    } catch (Exception $e) {
        $dbInfo['error'] = $e->getMessage();
    }
}

// معلومات الملفات والمجلدات
$directories = [
    'uploads' => 'uploads/',
    'cache' => 'cache/',
    'includes' => 'includes/',
    'parent' => 'parent/',
    'teacher' => 'teacher/',
    'admin' => 'admin/'
];

$dirInfo = [];
foreach ($directories as $name => $path) {
    $dirInfo[$name] = [
        'exists' => is_dir($path),
        'writable' => is_writable($path),
        'size' => is_dir($path) ? formatBytes(getDirSize($path)) : 'غير موجود'
    ];
}

/**
 * حساب حجم المجلد
 */
function getDirSize($directory) {
    $size = 0;
    if (is_dir($directory)) {
        foreach (new RecursiveIteratorIterator(new RecursiveDirectoryIterator($directory)) as $file) {
            $size += $file->getSize();
        }
    }
    return $size;
}

/**
 * تنسيق حجم الملف
 */
function formatBytes($size, $precision = 2) {
    $units = ['B', 'KB', 'MB', 'GB', 'TB'];
    
    for ($i = 0; $size > 1024 && $i < count($units) - 1; $i++) {
        $size /= 1024;
    }
    
    return round($size, $precision) . ' ' . $units[$i];
}
?>

<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>حالة النظام - نظام إدارة التدريب</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css">
    <style>
        .status-card {
            border-radius: 15px;
            border: none;
            box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
            transition: transform 0.2s;
        }
        .status-card:hover {
            transform: translateY(-2px);
        }
        .status-ok {
            color: #28a745;
        }
        .status-warning {
            color: #ffc107;
        }
        .status-error {
            color: #dc3545;
        }
        .info-table th {
            background-color: #f8f9fa;
            border-top: none;
        }
        .navbar-brand {
            font-weight: bold;
        }
    </style>
</head>
<body class="bg-light">

<nav class="navbar navbar-expand-lg navbar-dark bg-dark">
    <div class="container">
        <a class="navbar-brand" href="admin/dashboard.php">
            <i class="fas fa-cogs me-2"></i>نظام إدارة التدريب
        </a>
        <div class="navbar-nav ms-auto">
            <a class="nav-link" href="admin/dashboard.php">
                <i class="fas fa-arrow-right me-1"></i>العودة للوحة التحكم
            </a>
        </div>
    </div>
</nav>

<div class="container mt-4">
    <div class="row">
        <div class="col-12">
            <h1 class="mb-4">
                <i class="fas fa-heartbeat me-2"></i>حالة النظام
            </h1>
        </div>
    </div>

    <!-- بطاقات الحالة الرئيسية -->
    <div class="row mb-4">
        <div class="col-md-3 mb-3">
            <div class="card status-card text-center">
                <div class="card-body">
                    <i class="fas fa-check-circle fa-3x <?= $systemStatus['installed'] ? 'status-ok' : 'status-error' ?> mb-3"></i>
                    <h5>حالة التثبيت</h5>
                    <p class="mb-0"><?= $systemStatus['installed'] ? 'مثبت' : 'غير مثبت' ?></p>
                </div>
            </div>
        </div>
        
        <div class="col-md-3 mb-3">
            <div class="card status-card text-center">
                <div class="card-body">
                    <i class="fas fa-database fa-3x <?= $systemStatus['database_connection'] ? 'status-ok' : 'status-error' ?> mb-3"></i>
                    <h5>قاعدة البيانات</h5>
                    <p class="mb-0"><?= $systemStatus['database_connection'] ? 'متصلة' : 'غير متصلة' ?></p>
                </div>
            </div>
        </div>
        
        <div class="col-md-3 mb-3">
            <div class="card status-card text-center">
                <div class="card-body">
                    <i class="fas fa-table fa-3x <?= $systemStatus['required_tables'] ? 'status-ok' : 'status-error' ?> mb-3"></i>
                    <h5>الجداول المطلوبة</h5>
                    <p class="mb-0"><?= $systemStatus['required_tables'] ? 'موجودة' : 'ناقصة' ?></p>
                </div>
            </div>
        </div>
        
        <div class="col-md-3 mb-3">
            <div class="card status-card text-center">
                <div class="card-body">
                    <i class="fas fa-code-branch fa-3x status-ok mb-3"></i>
                    <h5>إصدار النظام</h5>
                    <p class="mb-0"><?= htmlspecialchars($systemStatus['version']) ?></p>
                </div>
            </div>
        </div>
    </div>

    <div class="row">
        <!-- معلومات PHP -->
        <div class="col-md-6 mb-4">
            <div class="card status-card">
                <div class="card-header">
                    <h5 class="mb-0"><i class="fab fa-php me-2"></i>معلومات PHP</h5>
                </div>
                <div class="card-body">
                    <table class="table table-sm info-table">
                        <tr>
                            <th>إصدار PHP</th>
                            <td><?= $phpVersion ?></td>
                        </tr>
                        <tr>
                            <th>حد الذاكرة</th>
                            <td><?= $memoryLimit ?></td>
                        </tr>
                        <tr>
                            <th>حد وقت التنفيذ</th>
                            <td><?= $maxExecutionTime ?> ثانية</td>
                        </tr>
                        <tr>
                            <th>حد رفع الملفات</th>
                            <td><?= $uploadMaxFilesize ?></td>
                        </tr>
                    </table>
                    
                    <h6 class="mt-3">الامتدادات المهمة:</h6>
                    <div class="row">
                        <?php 
                        $importantExtensions = ['pdo', 'pdo_mysql', 'gd', 'curl', 'mbstring', 'json', 'zip'];
                        foreach ($importantExtensions as $ext): 
                            $loaded = in_array($ext, $extensions);
                        ?>
                            <div class="col-6">
                                <span class="<?= $loaded ? 'status-ok' : 'status-error' ?>">
                                    <i class="fas fa-<?= $loaded ? 'check' : 'times' ?> me-1"></i>
                                    <?= $ext ?>
                                </span>
                            </div>
                        <?php endforeach; ?>
                    </div>
                </div>
            </div>
        </div>

        <!-- معلومات قاعدة البيانات -->
        <div class="col-md-6 mb-4">
            <div class="card status-card">
                <div class="card-header">
                    <h5 class="mb-0"><i class="fas fa-database me-2"></i>معلومات قاعدة البيانات</h5>
                </div>
                <div class="card-body">
                    <?php if ($systemStatus['database_connection']): ?>
                        <table class="table table-sm info-table">
                            <tr>
                                <th>إصدار MySQL</th>
                                <td><?= $dbInfo['version'] ?? 'غير محدد' ?></td>
                            </tr>
                            <tr>
                                <th>حجم قاعدة البيانات</th>
                                <td><?= $dbInfo['size_mb'] ?? 0 ?> ميجابايت</td>
                            </tr>
                            <tr>
                                <th>عدد الجداول</th>
                                <td><?= $dbInfo['table_count'] ?? 0 ?> جدول</td>
                            </tr>
                            <tr>
                                <th>تاريخ التثبيت</th>
                                <td><?= $systemStatus['install_date'] ? date('Y-m-d H:i', strtotime($systemStatus['install_date'])) : 'غير محدد' ?></td>
                            </tr>
                        </table>
                    <?php else: ?>
                        <div class="alert alert-danger">
                            <i class="fas fa-exclamation-triangle me-2"></i>
                            لا يمكن الاتصال بقاعدة البيانات
                            <?php if (isset($dbInfo['error'])): ?>
                                <br><small><?= htmlspecialchars($dbInfo['error']) ?></small>
                            <?php endif; ?>
                        </div>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </div>

    <!-- معلومات المجلدات -->
    <div class="row">
        <div class="col-12 mb-4">
            <div class="card status-card">
                <div class="card-header">
                    <h5 class="mb-0"><i class="fas fa-folder me-2"></i>حالة المجلدات</h5>
                </div>
                <div class="card-body">
                    <div class="table-responsive">
                        <table class="table table-sm info-table">
                            <thead>
                                <tr>
                                    <th>المجلد</th>
                                    <th>موجود</th>
                                    <th>قابل للكتابة</th>
                                    <th>الحجم</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($dirInfo as $name => $info): ?>
                                    <tr>
                                        <td><code><?= $name ?>/</code></td>
                                        <td>
                                            <span class="<?= $info['exists'] ? 'status-ok' : 'status-error' ?>">
                                                <i class="fas fa-<?= $info['exists'] ? 'check' : 'times' ?>"></i>
                                            </span>
                                        </td>
                                        <td>
                                            <span class="<?= $info['writable'] ? 'status-ok' : 'status-warning' ?>">
                                                <i class="fas fa-<?= $info['writable'] ? 'check' : 'exclamation-triangle' ?>"></i>
                                            </span>
                                        </td>
                                        <td><?= $info['size'] ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- معلومات الخادم -->
    <div class="row">
        <div class="col-12 mb-4">
            <div class="card status-card">
                <div class="card-header">
                    <h5 class="mb-0"><i class="fas fa-server me-2"></i>معلومات الخادم</h5>
                </div>
                <div class="card-body">
                    <div class="row">
                        <div class="col-md-6">
                            <table class="table table-sm info-table">
                                <tr>
                                    <th>نظام التشغيل</th>
                                    <td><?= PHP_OS ?></td>
                                </tr>
                                <tr>
                                    <th>خادم الويب</th>
                                    <td><?= $_SERVER['SERVER_SOFTWARE'] ?? 'غير محدد' ?></td>
                                </tr>
                                <tr>
                                    <th>اسم الخادم</th>
                                    <td><?= $_SERVER['SERVER_NAME'] ?? 'غير محدد' ?></td>
                                </tr>
                            </table>
                        </div>
                        <div class="col-md-6">
                            <table class="table table-sm info-table">
                                <tr>
                                    <th>عنوان IP</th>
                                    <td><?= $_SERVER['SERVER_ADDR'] ?? 'غير محدد' ?></td>
                                </tr>
                                <tr>
                                    <th>المنفذ</th>
                                    <td><?= $_SERVER['SERVER_PORT'] ?? 'غير محدد' ?></td>
                                </tr>
                                <tr>
                                    <th>البروتوكول</th>
                                    <td><?= isset($_SERVER['HTTPS']) ? 'HTTPS' : 'HTTP' ?></td>
                                </tr>
                            </table>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- أزرار الإجراءات -->
    <div class="row">
        <div class="col-12 text-center mb-4">
            <a href="admin/dashboard.php" class="btn btn-primary me-2">
                <i class="fas fa-arrow-right me-1"></i>العودة للوحة التحكم
            </a>
            <button onclick="location.reload()" class="btn btn-outline-primary">
                <i class="fas fa-sync-alt me-1"></i>تحديث الصفحة
            </button>
        </div>
    </div>
</div>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>

