<?php
session_start();
include "../../includes/functions.php";
check_login();

// جلب طلاب المجموعة الحالية (إذا تم اختيارها)
$students = [];
if (isset($_POST['group_id'])) {
    $group_id = $_POST['group_id'];
    $stmt = $pdo->prepare("SELECT student_id, name FROM students WHERE group_id = ? AND teacher_id = ?");
    $stmt->execute([$group_id, $_SESSION['teacher_id']]);
    $students = $stmt->fetchAll(PDO::FETCH_ASSOC);
}

// حفظ حالة الحضور
if ($_SERVER['REQUEST_METHOD'] == 'POST' && !empty($_POST['attendance'])) {
    $date = date('Y-m-d');

    foreach ($_POST['attendance'] as $student_id => $status) {
        $note = isset($_POST['note'][$student_id]) ? $_POST['note'][$student_id] : '';
        $pdo->prepare("INSERT INTO attendance (student_id, date, status, note, teacher_id)
                       VALUES (?, ?, ?, ?, ?)
                       ON DUPLICATE KEY UPDATE date=VALUES(date), status=VALUES(status), note=VALUES(note)")
            ->execute([$student_id, $date, $status, $note, $_SESSION['teacher_id']]);
}
?>
<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <title>تسجيل الحضور</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css"  rel="stylesheet">
    <style>
        body {
            font-family: 'Cairo', sans-serif;
            background-color: #f9f9f9;
        }
        .table thead {
            background-color: #0d6efd;
            color: white;
        }
    </style>
</head>
<body>

<?php include "../../includes/header.php"; ?>
<?php include "../../includes/sidebar.php"; ?>

<div class="main-content container mt-4 pt-5">
    <div class="d-flex justify-content-between align-items-center mb-4">
        <h2><i class="fas fa-clipboard-check me-2"></i> تسجيل الحضور</h2>
        <div class="welcome-message bg-light p-2 rounded shadow-sm">
            <i class="fas fa-user-shield me-2 text-primary"></i> مرحبًا بك <span class="fw-bold text-primary"><?= $_SESSION['name'] ?? 'المعلم' ?></span>
        </div>
    </div>

    <form method="post">
        <div class="row g-3 mb-3">
            <div class="col-md-4">
                <label class="form-label">اختر مجموعة</label>
                <select name="group_id" class="form-select" required onchange="this.form.submit()">
                    <option value="">-- اختر مجموعة --</option>
                    <?php
                    // جلب المجموعات الخاصة بالمعلم
                    $stmt = $pdo->prepare("SELECT group_id, group_name FROM groups WHERE teacher_id = ?");
                    $stmt->execute([$_SESSION['teacher_id']]);
                    while ($group = $stmt->fetch()) {
                        $selected = (isset($_POST['group_id']) && $_POST['group_id'] == $group['group_id']) ? 'selected' : '';
                        echo "<option value='{$group['group_id']}' $selected>{$group['group_name']}</option>";
                    }
                    ?>
                </select>
            </div>
        </div>
    </form>

    <?php if (!empty($students)): ?>
        <form method="post">
            <input type="hidden" name="group_id" value="<?= $group_id ?>">

            <table class="table table-bordered table-striped text-center align-middle">
                <thead>
                    <tr>
                        <th>الطالب</th>
                        <th>الحالة</th>
                        <th>ملاحظات</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($students as $student): ?>
                        <tr>
                            <td><?= htmlspecialchars($student['name']) ?></td>
                            <td>
                                <select name="attendance[<?= $student['student_id'] ?>]" class="form-select" required>
                                    <option value="حاضر">✔ حاضر</option>
                                    <option value="غائب">❌ غائب</option>
                                    <option value="عذر">❓ عذر</option>
                                </select>
                            </td>
                            <td>
                                <textarea name="note[<?= $student['student_id'] ?>]" class="form-control" rows="1"></textarea>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>

            <button type="submit" class="btn btn-primary mt-3">💾 حفظ الحضور</button>
        </form>
    <?php else: ?>
        <div class="alert alert-info mt-4">يرجى اختيار مجموعة من القائمة أولاً.</div>
    <?php endif; ?>
</div>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script> 
</body>
</html>