<?php
session_start();
if (!isset($_SESSION['teacher_id'])) {
    header("Location: ../../login.php");
    exit;
}

// استخدام DOCUMENT_ROOT للوصول إلى includes/db.php بشكل آمن
include "../includes/db.php";

$teacher_id = $_SESSION['teacher_id'];

try {
    // عدد الطلاب
    $stmt = $pdo->prepare("SELECT COUNT(*) FROM students WHERE teacher_id = ?");
    $stmt->execute([$teacher_id]);
    $total_students = $stmt->fetchColumn();

    // الإيرادات الشهرية
    $stmt = $pdo->query("SELECT SUM(amount_paid) FROM payments WHERE student_id IN 
                         (SELECT student_id FROM students WHERE teacher_id = $teacher_id)");
    $total_payments = $stmt->fetchColumn();

    // نسبة الحضور
    $stmt = $pdo->query("SELECT COUNT(*) AS total, 
                                  SUM(CASE WHEN status = 'حاضر' THEN 1 ELSE 0 END) AS present
                           FROM attendance WHERE student_id IN 
                           (SELECT student_id FROM students WHERE teacher_id = $teacher_id)");

    $row = $stmt->fetch(PDO::FETCH_ASSOC);
    $attendance_rate = round(($row['present'] / max(1, $row['total'])) * 100, 2);

} catch (PDOException $e) {
    die("❌ خطأ في النظام: " . $e->getMessage());
}
?>

<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <title>لوحة التحكم</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css"  rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css" rel="stylesheet">
    <link rel="stylesheet" href="/assets/css/style.css">
</head>
<body>

<?php include '../includes/header.php'; ?>
<?php include '../includes/sidebar.php'; ?>

<div class="main-content container mt-4 pt-5">
    <div class="d-flex justify-content-between align-items-center mb-4">
        <h2><i class="fas fa-tachometer-alt me-2"></i> لوحة التحكم</h2>
        <div class="welcome-message bg-light p-2 rounded shadow-sm">
            <i class="fas fa-user-shield me-2 text-primary"></i> مرحبًا بك <span class="fw-bold text-primary"><?= htmlspecialchars($_SESSION['name'] ?? 'المعلم') ?></span>
        </div>
    </div>

    <div class="row g-4 mt-2">
        <div class="col-md-4">
            <div class="stats-card bg-primary text-white">
                <i class="fas fa-user-graduate"></i>
                <h5>عدد الطلاب</h5>
                <h2><?= $total_students ?></h2>
            </div>
        </div>
        <div class="col-md-4">
            <div class="stats-card bg-success text-white">
                <i class="fas fa-money-bill-wave"></i>
                <h5>إجمالي الإيرادات</h5>
                <h2><?= number_format($total_payments, 2) ?> ج.م</h2>
            </div>
        </div>
        <div class="col-md-4">
            <div class="stats-card bg-info text-white">
                <i class="fas fa-chart-pie"></i>
                <h5>نسبة الحضور</h5>
                <h2><?= $attendance_rate ?>%</h2>
            </div>
        </div>
    </div>
</div>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
<script src="../assets/js/main.js"></script>
</body>
</html>