<?php
session_start();
require_once '../includes/db.php';
require_once '../includes/security.php';

// التحقق من تسجيل دخول المعلم
if (!isset($_SESSION['teacher_id']) || $_SESSION['role'] !== 'teacher') {
    header('Location: ../login.php');
    exit();
}

$teacher_id = $_SESSION['teacher_id'];
$success = '';
$error = '';

// معالجة إرسال رسالة جديدة
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['send_message'])) {
    $parent_id = $_POST['parent_id'] ?? 0;
    $student_id = $_POST['student_id'] ?? 0;
    $subject = sanitizeInput($_POST['subject'] ?? '');
    $message = sanitizeInput($_POST['message'] ?? '');
    
    if ($parent_id && $student_id && $subject && $message) {
        try {
            // التحقق من أن الطالب مرتبط بالمعلم وولي الأمر
            $check_stmt = $pdo->prepare("
                SELECT s.student_id 
                FROM students s
                LEFT JOIN student_parent sp ON s.student_id = sp.student_id
                WHERE s.student_id = ? AND s.teacher_id = ? 
                AND (sp.parent_id = ? OR s.parent_id = ?)
            ");
            $check_stmt->execute([$student_id, $teacher_id, $parent_id, $parent_id]);
            
            if ($check_stmt->fetch()) {
                $stmt = $pdo->prepare("
                    INSERT INTO parent_teacher_messages 
                    (sender_type, sender_id, receiver_type, receiver_id, student_id, subject, message) 
                    VALUES ('teacher', ?, 'parent', ?, ?, ?, ?)
                ");
                $stmt->execute([$teacher_id, $parent_id, $student_id, $subject, $message]);
                $success = "تم إرسال الرسالة بنجاح";
            } else {
                $error = "غير مسموح بإرسال رسالة لهذا ولي الأمر";
            }
        } catch (PDOException $e) {
            $error = "خطأ في إرسال الرسالة";
            error_log("Message send error: " . $e->getMessage());
        }
    } else {
        $error = "يرجى ملء جميع الحقول المطلوبة";
    }
}

// معالجة تحديد الرسالة كمقروءة
if (isset($_GET['mark_read'])) {
    $message_id = $_GET['mark_read'];
    try {
        $stmt = $pdo->prepare("
            UPDATE parent_teacher_messages 
            SET is_read = 1 
            WHERE id = ? AND receiver_type = 'teacher' AND receiver_id = ?
        ");
        $stmt->execute([$message_id, $teacher_id]);
    } catch (PDOException $e) {
        error_log("Mark read error: " . $e->getMessage());
    }
}

// الحصول على قائمة الطلاب وأولياء الأمور المرتبطين بالمعلم
try {
    $students_parents_stmt = $pdo->prepare("
        SELECT DISTINCT s.student_id, s.name as student_name, 
               p.id as parent_id, p.name as parent_name, p.email as parent_email,
               sp.relationship
        FROM students s
        LEFT JOIN student_parent sp ON s.student_id = sp.student_id
        LEFT JOIN parents p ON sp.parent_id = p.id OR s.parent_id = p.id
        WHERE s.teacher_id = ? AND p.id IS NOT NULL
        ORDER BY s.name, p.name
    ");
    $students_parents_stmt->execute([$teacher_id]);
    $students_parents = $students_parents_stmt->fetchAll(PDO::FETCH_ASSOC);
    
    // الحصول على الرسائل
    $messages_stmt = $pdo->prepare("
        SELECT ptm.*, 
               CASE 
                   WHEN ptm.sender_type = 'teacher' THEN t.name
                   ELSE p.name
               END as sender_name,
               CASE 
                   WHEN ptm.receiver_type = 'teacher' THEN t2.name
                   ELSE p2.name
               END as receiver_name,
               s.name as student_name
        FROM parent_teacher_messages ptm
        LEFT JOIN teachers t ON ptm.sender_type = 'teacher' AND ptm.sender_id = t.id
        LEFT JOIN teachers t2 ON ptm.receiver_type = 'teacher' AND ptm.receiver_id = t2.id
        LEFT JOIN parents p ON ptm.sender_type = 'parent' AND ptm.sender_id = p.id
        LEFT JOIN parents p2 ON ptm.receiver_type = 'parent' AND ptm.receiver_id = p2.id
        LEFT JOIN students s ON ptm.student_id = s.student_id
        WHERE (ptm.sender_type = 'teacher' AND ptm.sender_id = ?) 
           OR (ptm.receiver_type = 'teacher' AND ptm.receiver_id = ?)
        ORDER BY ptm.sent_at DESC
    ");
    $messages_stmt->execute([$teacher_id, $teacher_id]);
    $messages = $messages_stmt->fetchAll(PDO::FETCH_ASSOC);
    
} catch (PDOException $e) {
    $error = "خطأ في استرجاع البيانات";
    error_log("Messages fetch error: " . $e->getMessage());
}
?>

<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>رسائل أولياء الأمور</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css">
    <link rel="stylesheet" href="../assets/css/style.css">
    <style>
        .message-card {
            border-radius: 15px;
            margin-bottom: 15px;
            transition: transform 0.2s;
        }
        .message-card:hover {
            transform: translateY(-2px);
        }
        .message-unread {
            border-left: 4px solid #007bff;
            background-color: #f8f9fa;
        }
        .message-sent {
            border-left: 4px solid #28a745;
        }
        .message-received {
            border-left: 4px solid #17a2b8;
        }
    </style>
</head>
<body class="bg-light">

<?php include '../includes/header.php'; ?>

<div class="container-fluid">
    <div class="row">
        <?php include '../includes/sidebar.php'; ?>
        
        <main class="col-md-9 ms-sm-auto col-lg-10 px-md-4">
            <div class="d-flex justify-content-between flex-wrap flex-md-nowrap align-items-center pt-3 pb-2 mb-3 border-bottom">
                <h1 class="h2"><i class="fas fa-envelope me-2"></i> رسائل أولياء الأمور</h1>
                <button class="btn btn-primary" data-bs-toggle="modal" data-bs-target="#newMessageModal">
                    <i class="fas fa-plus me-1"></i> رسالة جديدة
                </button>
            </div>

            <?php if ($success): ?>
                <div class="alert alert-success alert-dismissible fade show">
                    <i class="fas fa-check-circle me-2"></i> <?= htmlspecialchars($success) ?>
                    <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
                </div>
            <?php endif; ?>

            <?php if ($error): ?>
                <div class="alert alert-danger alert-dismissible fade show">
                    <i class="fas fa-exclamation-circle me-2"></i> <?= htmlspecialchars($error) ?>
                    <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
                </div>
            <?php endif; ?>

            <!-- إحصائيات سريعة -->
            <div class="row mb-4">
                <div class="col-md-4">
                    <div class="card bg-primary text-white">
                        <div class="card-body text-center">
                            <i class="fas fa-envelope fa-2x mb-2"></i>
                            <h4><?= count($messages) ?></h4>
                            <p class="mb-0">إجمالي الرسائل</p>
                        </div>
                    </div>
                </div>
                <div class="col-md-4">
                    <div class="card bg-info text-white">
                        <div class="card-body text-center">
                            <i class="fas fa-envelope-open fa-2x mb-2"></i>
                            <h4><?= count(array_filter($messages, function($m) use ($teacher_id) { 
                                return $m['receiver_type'] === 'teacher' && $m['receiver_id'] == $teacher_id && !$m['is_read']; 
                            })) ?></h4>
                            <p class="mb-0">رسائل غير مقروءة</p>
                        </div>
                    </div>
                </div>
                <div class="col-md-4">
                    <div class="card bg-success text-white">
                        <div class="card-body text-center">
                            <i class="fas fa-users fa-2x mb-2"></i>
                            <h4><?= count(array_unique(array_column($students_parents, 'parent_id'))) ?></h4>
                            <p class="mb-0">أولياء أمور متصلين</p>
                        </div>
                    </div>
                </div>
            </div>

            <!-- قائمة الرسائل -->
            <div class="row">
                <div class="col-12">
                    <?php if (empty($messages)): ?>
                        <div class="text-center py-5">
                            <i class="fas fa-envelope fa-4x text-muted mb-3"></i>
                            <h4 class="text-muted">لا توجد رسائل</h4>
                            <p class="text-muted">ابدأ محادثة جديدة مع أولياء الأمور</p>
                            <button class="btn btn-primary" data-bs-toggle="modal" data-bs-target="#newMessageModal">
                                <i class="fas fa-plus me-1"></i> إرسال رسالة جديدة
                            </button>
                        </div>
                    <?php else: ?>
                        <?php foreach ($messages as $message): ?>
                            <div class="card message-card <?php
                                if ($message['receiver_type'] === 'teacher' && $message['receiver_id'] == $teacher_id) {
                                    echo $message['is_read'] ? 'message-received' : 'message-unread';
                                } else {
                                    echo 'message-sent';
                                }
                            ?>">
                                <div class="card-body">
                                    <div class="d-flex justify-content-between align-items-start mb-2">
                                        <div>
                                            <h6 class="card-title mb-1">
                                                <?= htmlspecialchars($message['subject']) ?>
                                                <?php if ($message['receiver_type'] === 'teacher' && $message['receiver_id'] == $teacher_id && !$message['is_read']): ?>
                                                    <span class="badge bg-primary">جديد</span>
                                                <?php endif; ?>
                                            </h6>
                                            <small class="text-muted">
                                                <?php if ($message['sender_type'] === 'teacher' && $message['sender_id'] == $teacher_id): ?>
                                                    <i class="fas fa-arrow-left me-1"></i> إلى: <?= htmlspecialchars($message['receiver_name']) ?>
                                                <?php else: ?>
                                                    <i class="fas fa-arrow-right me-1"></i> من: <?= htmlspecialchars($message['sender_name']) ?>
                                                <?php endif; ?>
                                                | الطالب: <?= htmlspecialchars($message['student_name']) ?>
                                            </small>
                                        </div>
                                        <div class="text-end">
                                            <small class="text-muted">
                                                <?= date('Y-m-d H:i', strtotime($message['sent_at'])) ?>
                                            </small>
                                            <?php if ($message['receiver_type'] === 'teacher' && $message['receiver_id'] == $teacher_id && !$message['is_read']): ?>
                                                <br>
                                                <a href="?mark_read=<?= $message['id'] ?>" class="btn btn-sm btn-outline-primary">
                                                    <i class="fas fa-check me-1"></i> تحديد كمقروء
                                                </a>
                                            <?php endif; ?>
                                        </div>
                                    </div>
                                    <p class="card-text"><?= nl2br(htmlspecialchars($message['message'])) ?></p>
                                </div>
                            </div>
                        <?php endforeach; ?>
                    <?php endif; ?>
                </div>
            </div>
        </main>
    </div>
</div>

<!-- نافذة رسالة جديدة -->
<div class="modal fade" id="newMessageModal" tabindex="-1">
    <div class="modal-dialog modal-lg">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title"><i class="fas fa-envelope me-2"></i> رسالة جديدة</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
            </div>
            <form method="post">
                <div class="modal-body">
                    <div class="mb-3">
                        <label class="form-label">الطالب وولي الأمر</label>
                        <select name="student_parent" class="form-select" required id="studentParentSelect">
                            <option value="">اختر الطالب وولي الأمر</option>
                            <?php foreach ($students_parents as $sp): ?>
                                <option value="<?= $sp['student_id'] ?>|<?= $sp['parent_id'] ?>">
                                    <?= htmlspecialchars($sp['student_name']) ?> - ولي الأمر: <?= htmlspecialchars($sp['parent_name']) ?> (<?= htmlspecialchars($sp['parent_email']) ?>)
                                </option>
                            <?php endforeach; ?>
                        </select>
                        <input type="hidden" name="student_id" id="studentId">
                        <input type="hidden" name="parent_id" id="parentId">
                    </div>
                    
                    <div class="mb-3">
                        <label class="form-label">موضوع الرسالة</label>
                        <input type="text" name="subject" class="form-control" required>
                    </div>
                    
                    <div class="mb-3">
                        <label class="form-label">نص الرسالة</label>
                        <textarea name="message" class="form-control" rows="5" required></textarea>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">إلغاء</button>
                    <button type="submit" name="send_message" class="btn btn-primary">
                        <i class="fas fa-paper-plane me-1"></i> إرسال
                    </button>
                </div>
            </form>
        </div>
    </div>
</div>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
<script>
// تحديث الحقول المخفية عند اختيار الطالب وولي الأمر
document.getElementById('studentParentSelect').addEventListener('change', function() {
    const value = this.value;
    if (value) {
        const [studentId, parentId] = value.split('|');
        document.getElementById('studentId').value = studentId;
        document.getElementById('parentId').value = parentId;
    } else {
        document.getElementById('studentId').value = '';
        document.getElementById('parentId').value = '';
    }
});
</script>
</body>
</html>

