<?php
session_start();
require_once '../includes/db.php';

// Check if user is logged in and is a teacher
if (!isset($_SESSION['user_id']) || $_SESSION['role'] !== 'teacher') {
    header('Location: ../login.php');
    exit();
}

$teacher_id = $_SESSION['user_id'];
$message = '';
$error = '';

// Handle form submissions
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['action'])) {
        switch ($_POST['action']) {
            case 'add_parent':
                $name = trim($_POST['name']);
                $email = trim($_POST['email']);
                $phone = trim($_POST['phone']);
                $address = trim($_POST['address']);
                $relationship_type = $_POST['relationship_type'];
                
                if (!empty($name)) {
                    try {
                        $stmt = $pdo->prepare("INSERT INTO parents (name, email, phone, address, relationship_type, teacher_id) VALUES (?, ?, ?, ?, ?, ?)");
                        $stmt->execute([$name, $email, $phone, $address, $relationship_type, $teacher_id]);
                        $message = "تم إضافة ولي الأمر بنجاح";
                    } catch (PDOException $e) {
                        $error = "خطأ في إضافة ولي الأمر: " . $e->getMessage();
                    }
                } else {
                    $error = "اسم ولي الأمر مطلوب";
                }
                break;
                
            case 'edit_parent':
                $parent_id = $_POST['parent_id'];
                $name = trim($_POST['name']);
                $email = trim($_POST['email']);
                $phone = trim($_POST['phone']);
                $address = trim($_POST['address']);
                $relationship_type = $_POST['relationship_type'];
                
                try {
                    $stmt = $pdo->prepare("UPDATE parents SET name = ?, email = ?, phone = ?, address = ?, relationship_type = ? WHERE id = ? AND teacher_id = ?");
                    $stmt->execute([$name, $email, $phone, $address, $relationship_type, $parent_id, $teacher_id]);
                    $message = "تم تحديث بيانات ولي الأمر بنجاح";
                } catch (PDOException $e) {
                    $error = "خطأ في تحديث بيانات ولي الأمر: " . $e->getMessage();
                }
                break;
                
            case 'delete_parent':
                $parent_id = $_POST['parent_id'];
                try {
                    $stmt = $pdo->prepare("DELETE FROM parents WHERE id = ? AND teacher_id = ?");
                    $stmt->execute([$parent_id, $teacher_id]);
                    $message = "تم حذف ولي الأمر بنجاح";
                } catch (PDOException $e) {
                    $error = "خطأ في حذف ولي الأمر: " . $e->getMessage();
                }
                break;
        }
    }
}

// Fetch all parents for this teacher
$stmt = $pdo->prepare("SELECT * FROM parents WHERE teacher_id = ? ORDER BY name");
$stmt->execute([$teacher_id]);
$parents = $stmt->fetchAll();

// Get parent for editing if requested
$edit_parent = null;
if (isset($_GET['edit']) && is_numeric($_GET['edit'])) {
    $stmt = $pdo->prepare("SELECT * FROM parents WHERE id = ? AND teacher_id = ?");
    $stmt->execute([$_GET['edit'], $teacher_id]);
    $edit_parent = $stmt->fetch();
}
?>

<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>إدارة أولياء الأمور</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
    <style>
        body { font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif; }
        .sidebar { background: linear-gradient(135deg, #667eea 0%, #764ba2 100%); }
        .card { border: none; box-shadow: 0 0.125rem 0.25rem rgba(0, 0, 0, 0.075); }
        .btn-primary { background: linear-gradient(135deg, #667eea 0%, #764ba2 100%); border: none; }
        .table th { background-color: #f8f9fa; border-top: none; }
    </style>
</head>
<body class="bg-light">
    <div class="container-fluid">
        <div class="row">
            <!-- Sidebar -->
            <div class="col-md-3 col-lg-2 px-0">
                <?php include '../includes/sidebar.php'; ?>
            </div>
            
            <!-- Main Content -->
            <div class="col-md-9 col-lg-10">
                <div class="container-fluid py-4">
                    <div class="d-flex justify-content-between align-items-center mb-4">
                        <h2><i class="fas fa-users me-2"></i>إدارة أولياء الأمور</h2>
                        <a href="dashboard.php" class="btn btn-outline-secondary">
                            <i class="fas fa-arrow-right me-2"></i>العودة للوحة التحكم
                        </a>
                    </div>

                    <?php if ($message): ?>
                        <div class="alert alert-success alert-dismissible fade show" role="alert">
                            <?= htmlspecialchars($message) ?>
                            <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
                        </div>
                    <?php endif; ?>

                    <?php if ($error): ?>
                        <div class="alert alert-danger alert-dismissible fade show" role="alert">
                            <?= htmlspecialchars($error) ?>
                            <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
                        </div>
                    <?php endif; ?>

                    <!-- Add/Edit Parent Form -->
                    <div class="card mb-4">
                        <div class="card-header">
                            <h5 class="mb-0">
                                <i class="fas fa-user-plus me-2"></i>
                                <?= $edit_parent ? 'تعديل بيانات ولي الأمر' : 'إضافة ولي أمر جديد' ?>
                            </h5>
                        </div>
                        <div class="card-body">
                            <form method="POST">
                                <input type="hidden" name="action" value="<?= $edit_parent ? 'edit_parent' : 'add_parent' ?>">
                                <?php if ($edit_parent): ?>
                                    <input type="hidden" name="parent_id" value="<?= $edit_parent['id'] ?>">
                                <?php endif; ?>
                                
                                <div class="row">
                                    <div class="col-md-6 mb-3">
                                        <label for="name" class="form-label">الاسم الكامل *</label>
                                        <input type="text" class="form-control" id="name" name="name" 
                                               value="<?= $edit_parent ? htmlspecialchars($edit_parent['name']) : '' ?>" required>
                                    </div>
                                    <div class="col-md-6 mb-3">
                                        <label for="email" class="form-label">البريد الإلكتروني</label>
                                        <input type="email" class="form-control" id="email" name="email" 
                                               value="<?= $edit_parent ? htmlspecialchars($edit_parent['email']) : '' ?>">
                                    </div>
                                </div>
                                
                                <div class="row">
                                    <div class="col-md-6 mb-3">
                                        <label for="phone" class="form-label">رقم الهاتف</label>
                                        <input type="tel" class="form-control" id="phone" name="phone" 
                                               value="<?= $edit_parent ? htmlspecialchars($edit_parent['phone']) : '' ?>">
                                    </div>
                                    <div class="col-md-6 mb-3">
                                        <label for="relationship_type" class="form-label">صلة القرابة</label>
                                        <select class="form-select" id="relationship_type" name="relationship_type">
                                            <option value="father" <?= $edit_parent && $edit_parent['relationship_type'] === 'father' ? 'selected' : '' ?>>والد</option>
                                            <option value="mother" <?= $edit_parent && $edit_parent['relationship_type'] === 'mother' ? 'selected' : '' ?>>والدة</option>
                                            <option value="guardian" <?= $edit_parent && $edit_parent['relationship_type'] === 'guardian' ? 'selected' : '' ?>>وصي</option>
                                            <option value="other" <?= $edit_parent && $edit_parent['relationship_type'] === 'other' ? 'selected' : '' ?>>أخرى</option>
                                        </select>
                                    </div>
                                </div>
                                
                                <div class="mb-3">
                                    <label for="address" class="form-label">العنوان</label>
                                    <textarea class="form-control" id="address" name="address" rows="3"><?= $edit_parent ? htmlspecialchars($edit_parent['address']) : '' ?></textarea>
                                </div>
                                
                                <div class="d-flex gap-2">
                                    <button type="submit" class="btn btn-primary">
                                        <i class="fas fa-save me-2"></i>
                                        <?= $edit_parent ? 'تحديث البيانات' : 'إضافة ولي الأمر' ?>
                                    </button>
                                    <?php if ($edit_parent): ?>
                                        <a href="parents.php" class="btn btn-secondary">
                                            <i class="fas fa-times me-2"></i>إلغاء التعديل
                                        </a>
                                    <?php endif; ?>
                                </div>
                            </form>
                        </div>
                    </div>

                    <!-- Parents List -->
                    <div class="card">
                        <div class="card-header">
                            <h5 class="mb-0">
                                <i class="fas fa-list me-2"></i>قائمة أولياء الأمور
                                <span class="badge bg-primary ms-2"><?= count($parents) ?></span>
                            </h5>
                        </div>
                        <div class="card-body">
                            <?php if (empty($parents)): ?>
                                <div class="text-center py-4">
                                    <i class="fas fa-users fa-3x text-muted mb-3"></i>
                                    <p class="text-muted">لا توجد بيانات أولياء أمور مسجلة</p>
                                </div>
                            <?php else: ?>
                                <div class="table-responsive">
                                    <table class="table table-hover">
                                        <thead>
                                            <tr>
                                                <th>الاسم</th>
                                                <th>صلة القرابة</th>
                                                <th>رقم الهاتف</th>
                                                <th>البريد الإلكتروني</th>
                                                <th>تاريخ التسجيل</th>
                                                <th>الإجراءات</th>
                                            </tr>
                                        </thead>
                                        <tbody>
                                            <?php foreach ($parents as $parent): ?>
                                                <tr>
                                                    <td>
                                                        <strong><?= htmlspecialchars($parent['name']) ?></strong>
                                                    </td>
                                                    <td>
                                                        <?php
                                                        $relationships = [
                                                            'father' => 'والد',
                                                            'mother' => 'والدة',
                                                            'guardian' => 'وصي',
                                                            'other' => 'أخرى'
                                                        ];
                                                        echo $relationships[$parent['relationship_type']] ?? $parent['relationship_type'];
                                                        ?>
                                                    </td>
                                                    <td><?= htmlspecialchars($parent['phone']) ?></td>
                                                    <td><?= htmlspecialchars($parent['email']) ?></td>
                                                    <td><?= date('Y-m-d', strtotime($parent['created_at'])) ?></td>
                                                    <td>
                                                        <div class="btn-group" role="group">
                                                            <a href="parents.php?edit=<?= $parent['id'] ?>" class="btn btn-sm btn-outline-primary">
                                                                <i class="fas fa-edit"></i>
                                                            </a>
                                                            <form method="POST" style="display: inline;" 
                                                                  onsubmit="return confirm('هل أنت متأكد من حذف ولي الأمر؟')">
                                                                <input type="hidden" name="action" value="delete_parent">
                                                                <input type="hidden" name="parent_id" value="<?= $parent['id'] ?>">
                                                                <button type="submit" class="btn btn-sm btn-outline-danger">
                                                                    <i class="fas fa-trash"></i>
                                                                </button>
                                                            </form>
                                                        </div>
                                                    </td>
                                                </tr>
                                            <?php endforeach; ?>
                                        </tbody>
                                    </table>
                                </div>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>

