<?php
session_start();
include "../../../includes/functions.php";
check_login();

$month = date('m');
$year = date('Y');

if (isset($_POST['month']) && isset($_POST['year'])) {
    $month = $_POST['month'];
    $year = $_POST['year'];
}

// عدد الطلاب
$stmt = $pdo->prepare("SELECT COUNT(*) FROM students WHERE teacher_id = ? AND DATE_FORMAT(created_at, '%Y-%m') = '$year-$month'");
$stmt->execute([$_SESSION['teacher_id']]);
$total_students = $stmt->fetchColumn();

// الإيرادات الشهرية
$stmt = $pdo->prepare("SELECT SUM(amount_paid) FROM payments WHERE student_id IN 
                        (SELECT student_id FROM students WHERE teacher_id = ?)
                        AND YEAR(payment_date) = ? AND MONTH(payment_date) = ?");
$stmt->execute([$_SESSION['teacher_id'], $year, $month]);
$total_payments = $stmt->fetchColumn();

// نسبة الحضور
$stmt = $pdo->prepare("SELECT COUNT(*) AS total, 
                               SUM(CASE WHEN status = 'حاضر' THEN 1 ELSE 0 END) AS present
                        FROM attendance WHERE student_id IN 
                        (SELECT student_id FROM students WHERE teacher_id = ?)
                        AND YEAR(date) = ? AND MONTH(date) = ?");
$stmt->execute([$_SESSION['teacher_id'], $year, $month]);
$row = $stmt->fetch(PDO::FETCH_ASSOC);

$attendance_rate = round(($row['present'] / max(1, $row['total'])) * 100, 2);
?>

<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <title>التقرير الشهري</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css"  rel="stylesheet">
    <style>
        .report-card {
            transition: transform 0.2s;
        }
        .report-card:hover {
            transform: scale(1.02);
        }
    </style>
</head>
<body>

<?php include "../../../includes/header.php"; ?>
<?php include "../../../includes/sidebar.php"; ?>

<div class="main-content container mt-4 pt-5">
    <div class="d-flex justify-content-between align-items-center mb-4">
        <h2><i class="fas fa-chart-bar me-2"></i> التقرير الشهري</h2>
        <div class="welcome-message bg-light p-2 rounded shadow-sm">
            <i class="fas fa-user-shield me-2 text-primary"></i> مرحبًا بك <span class="fw-bold text-primary"><?= $_SESSION['name'] ?? 'المعلم' ?></span>
        </div>
    </div>

    <form method="post" class="mb-4">
        <div class="row g-3 align-items-center">
            <div class="col-md-4">
                <label class="form-label">اختر الشهر</label>
                <select name="month" class="form-select" required>
                    <?php for ($m = 1; $m <= 12; $m++): ?>
                        <option value="<?= str_pad($m, 2, '0', STR_PAD_LEFT) ?>" <?= $m == $month ? 'selected' : '' ?>>
                            <?= $m ?> - <?= date("F", mktime(0, 0, 0, $m, 10)) ?>
                        </option>
                    <?php endfor; ?>
                </select>
            </div>
            <div class="col-md-4">
                <label class="form-label">السنة</label>
                <input type="number" name="year" class="form-control" value="<?= $year ?>" min="2020" max="2030" required>
            </div>
            <div class="col-md-4">
                <button type="submit" class="btn btn-primary mt-4 w-100">🔎 عرض التقرير</button>
            </div>
        </div>
    </form>

    <div class="row g-4 mt-4">
        <div class="col-md-4">
            <div class="card report-card bg-secondary text-white text-center p-3 shadow-sm">
                <h5>🧑‍🎓 عدد الطلاب</h5>
                <h2><?= $total_students ?></h2>
            </div>
        </div>
        <div class="col-md-4">
            <div class="card report-card bg-success text-white text-center p-3 shadow-sm">
                <h5>💰 إجمالي الدخل</h5>
                <h2><?= number_format($total_payments, 2) ?> ج.م</h2>
            </div>
        </div>
        <div class="col-md-4">
            <div class="card report-card bg-info text-white text-center p-3 shadow-sm">
                <h5>✅ نسبة الحضور</h5>
                <h2><?= $attendance_rate ?>%</h2>
            </div>
        </div>
    </div>
</div>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script> 
</body>
</html>