<?php
session_start();
require_once '../includes/db.php';

// Check if user is logged in and is a teacher
if (!isset($_SESSION['user_id']) || $_SESSION['role'] !== 'teacher') {
    header('Location: ../login.php');
    exit();
}

$teacher_id = $_SESSION['user_id'];
$message = '';
$error = '';

// Handle form submissions
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['action'])) {
        switch ($_POST['action']) {
            case 'add_student':
                $name = trim($_POST['name']);
                $grade_level = trim($_POST['grade_level']);
                $phone = trim($_POST['phone']);
                $parent_id = $_POST['parent_id'] ?: null;
                $group_id = $_POST['group_id'] ?: null;
                $individual_price = $_POST['individual_price'] ?: null;
                $payment_type = $_POST['payment_type'];
                
                if (!empty($name)) {
                    try {
                        $stmt = $pdo->prepare("INSERT INTO students (name, grade_level, phone, parent_id, group_id, individual_price, payment_type, teacher_id) VALUES (?, ?, ?, ?, ?, ?, ?, ?)");
                        $stmt->execute([$name, $grade_level, $phone, $parent_id, $group_id, $individual_price, $payment_type, $teacher_id]);
                        $message = "تم إضافة الطالب بنجاح";
                    } catch (PDOException $e) {
                        $error = "خطأ في إضافة الطالب: " . $e->getMessage();
                    }
                } else {
                    $error = "اسم الطالب مطلوب";
                }
                break;
                
            case 'edit_student':
                $student_id = $_POST['student_id'];
                $name = trim($_POST['name']);
                $grade_level = trim($_POST['grade_level']);
                $phone = trim($_POST['phone']);
                $parent_id = $_POST['parent_id'] ?: null;
                $group_id = $_POST['group_id'] ?: null;
                $individual_price = $_POST['individual_price'] ?: null;
                $payment_type = $_POST['payment_type'];
                
                try {
                    $stmt = $pdo->prepare("UPDATE students SET name = ?, grade_level = ?, phone = ?, parent_id = ?, group_id = ?, individual_price = ?, payment_type = ? WHERE student_id = ? AND teacher_id = ?");
                    $stmt->execute([$name, $grade_level, $phone, $parent_id, $group_id, $individual_price, $payment_type, $student_id, $teacher_id]);
                    $message = "تم تحديث بيانات الطالب بنجاح";
                } catch (PDOException $e) {
                    $error = "خطأ في تحديث بيانات الطالب: " . $e->getMessage();
                }
                break;
                
            case 'delete_student':
                $student_id = $_POST['student_id'];
                try {
                    $stmt = $pdo->prepare("DELETE FROM students WHERE student_id = ? AND teacher_id = ?");
                    $stmt->execute([$student_id, $teacher_id]);
                    $message = "تم حذف الطالب بنجاح";
                } catch (PDOException $e) {
                    $error = "خطأ في حذف الطالب: " . $e->getMessage();
                }
                break;
        }
    }
}

// Fetch all parents for this teacher
$stmt = $pdo->prepare("SELECT * FROM parents WHERE teacher_id = ? ORDER BY name");
$stmt->execute([$teacher_id]);
$parents = $stmt->fetchAll();

// Fetch all study groups for this teacher
$stmt = $pdo->prepare("SELECT * FROM study_groups WHERE teacher_id = ? AND is_active = 1 ORDER BY name");
$stmt->execute([$teacher_id]);
$groups = $stmt->fetchAll();

// Fetch all students for this teacher with parent and group information
$stmt = $pdo->prepare("
    SELECT s.*, p.name as parent_name, sg.name as group_name, sg.type as group_type 
    FROM students s 
    LEFT JOIN parents p ON s.parent_id = p.id 
    LEFT JOIN study_groups sg ON s.group_id = sg.id 
    WHERE s.teacher_id = ? 
    ORDER BY s.name
");
$stmt->execute([$teacher_id]);
$students = $stmt->fetchAll();

// Get student for editing if requested
$edit_student = null;
if (isset($_GET['edit']) && is_numeric($_GET['edit'])) {
    $stmt = $pdo->prepare("SELECT * FROM students WHERE student_id = ? AND teacher_id = ?");
    $stmt->execute([$_GET['edit'], $teacher_id]);
    $edit_student = $stmt->fetch();
}
?>

<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>إدارة الطلاب</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
    <style>
        body { font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif; }
        .sidebar { background: linear-gradient(135deg, #667eea 0%, #764ba2 100%); }
        .card { border: none; box-shadow: 0 0.125rem 0.25rem rgba(0, 0, 0, 0.075); }
        .btn-primary { background: linear-gradient(135deg, #667eea 0%, #764ba2 100%); border: none; }
        .table th { background-color: #f8f9fa; border-top: none; }
        .badge-public { background-color: #28a745; }
        .badge-private { background-color: #007bff; }
        .badge-individual { background-color: #6f42c1; }
    </style>
</head>
<body class="bg-light">
    <div class="container-fluid">
        <div class="row">
            <!-- Sidebar -->
            <div class="col-md-3 col-lg-2 px-0">
                <?php include '../includes/sidebar.php'; ?>
            </div>
            
            <!-- Main Content -->
            <div class="col-md-9 col-lg-10">
                <div class="container-fluid py-4">
                    <div class="d-flex justify-content-between align-items-center mb-4">
                        <h2><i class="fas fa-user-graduate me-2"></i>إدارة الطلاب</h2>
                        <div>
                            <a href="parents.php" class="btn btn-outline-info me-2">
                                <i class="fas fa-users me-2"></i>إدارة أولياء الأمور
                            </a>
                            <a href="dashboard.php" class="btn btn-outline-secondary">
                                <i class="fas fa-arrow-right me-2"></i>العودة للوحة التحكم
                            </a>
                        </div>
                    </div>

                    <?php if ($message): ?>
                        <div class="alert alert-success alert-dismissible fade show" role="alert">
                            <?= htmlspecialchars($message) ?>
                            <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
                        </div>
                    <?php endif; ?>

                    <?php if ($error): ?>
                        <div class="alert alert-danger alert-dismissible fade show" role="alert">
                            <?= htmlspecialchars($error) ?>
                            <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
                        </div>
                    <?php endif; ?>

                    <!-- Add/Edit Student Form -->
                    <div class="card mb-4">
                        <div class="card-header">
                            <h5 class="mb-0">
                                <i class="fas fa-user-plus me-2"></i>
                                <?= $edit_student ? 'تعديل بيانات الطالب' : 'إضافة طالب جديد' ?>
                            </h5>
                        </div>
                        <div class="card-body">
                            <form method="POST">
                                <input type="hidden" name="action" value="<?= $edit_student ? 'edit_student' : 'add_student' ?>">
                                <?php if ($edit_student): ?>
                                    <input type="hidden" name="student_id" value="<?= $edit_student['student_id'] ?>">
                                <?php endif; ?>
                                
                                <div class="row">
                                    <div class="col-md-6 mb-3">
                                        <label for="name" class="form-label">اسم الطالب *</label>
                                        <input type="text" class="form-control" id="name" name="name" 
                                               value="<?= $edit_student ? htmlspecialchars($edit_student['name']) : '' ?>" required>
                                    </div>
                                    <div class="col-md-6 mb-3">
                                        <label for="grade_level" class="form-label">المرحلة الدراسية</label>
                                        <input type="text" class="form-control" id="grade_level" name="grade_level" 
                                               value="<?= $edit_student ? htmlspecialchars($edit_student['grade_level']) : '' ?>" 
                                               placeholder="مثال: الصف الثالث الابتدائي">
                                    </div>
                                </div>
                                
                                <div class="row">
                                    <div class="col-md-6 mb-3">
                                        <label for="phone" class="form-label">رقم الهاتف</label>
                                        <input type="tel" class="form-control" id="phone" name="phone" 
                                               value="<?= $edit_student ? htmlspecialchars($edit_student['phone']) : '' ?>">
                                    </div>
                                    <div class="col-md-6 mb-3">
                                        <label for="parent_id" class="form-label">ولي الأمر</label>
                                        <select class="form-select" id="parent_id" name="parent_id">
                                            <option value="">اختر ولي الأمر</option>
                                            <?php foreach ($parents as $parent): ?>
                                                <option value="<?= $parent['id'] ?>" 
                                                        <?= $edit_student && $edit_student['parent_id'] == $parent['id'] ? 'selected' : '' ?>>
                                                    <?= htmlspecialchars($parent['name']) ?>
                                                </option>
                                            <?php endforeach; ?>
                                        </select>
                                    </div>
                                </div>
                                
                                <div class="row">
                                    <div class="col-md-6 mb-3">
                                        <label for="group_id" class="form-label">المجموعة</label>
                                        <select class="form-select" id="group_id" name="group_id">
                                            <option value="">بدون مجموعة (طالب فردي)</option>
                                            <?php foreach ($groups as $group): ?>
                                                <option value="<?= $group['id'] ?>" 
                                                        <?= $edit_student && $edit_student['group_id'] == $group['id'] ? 'selected' : '' ?>>
                                                    <?= htmlspecialchars($group['name']) ?> 
                                                    (<?= $group['type'] === 'public' ? 'عامة' : ($group['type'] === 'private' ? 'خاصة' : 'فردية') ?>)
                                                </option>
                                            <?php endforeach; ?>
                                        </select>
                                    </div>
                                    <div class="col-md-6 mb-3">
                                        <label for="payment_type" class="form-label">نوع الدفع</label>
                                        <select class="form-select" id="payment_type" name="payment_type">
                                            <option value="monthly" <?= $edit_student && $edit_student['payment_type'] === 'monthly' ? 'selected' : '' ?>>شهري</option>
                                            <option value="per_session" <?= $edit_student && $edit_student['payment_type'] === 'per_session' ? 'selected' : '' ?>>بالحصة</option>
                                        </select>
                                    </div>
                                </div>
                                
                                <div class="row">
                                    <div class="col-md-6 mb-3">
                                        <label for="individual_price" class="form-label">السعر الفردي (للطلاب الفرديين فقط)</label>
                                        <input type="number" step="0.01" class="form-control" id="individual_price" name="individual_price" 
                                               value="<?= $edit_student ? $edit_student['individual_price'] : '' ?>" 
                                               placeholder="اتركه فارغاً إذا كان في مجموعة">
                                    </div>
                                </div>
                                
                                <div class="d-flex gap-2">
                                    <button type="submit" class="btn btn-primary">
                                        <i class="fas fa-save me-2"></i>
                                        <?= $edit_student ? 'تحديث البيانات' : 'إضافة الطالب' ?>
                                    </button>
                                    <?php if ($edit_student): ?>
                                        <a href="students.php" class="btn btn-secondary">
                                            <i class="fas fa-times me-2"></i>إلغاء التعديل
                                        </a>
                                    <?php endif; ?>
                                </div>
                            </form>
                        </div>
                    </div>

                    <!-- Students List -->
                    <div class="card">
                        <div class="card-header">
                            <h5 class="mb-0">
                                <i class="fas fa-list me-2"></i>قائمة الطلاب
                                <span class="badge bg-primary ms-2"><?= count($students) ?></span>
                            </h5>
                        </div>
                        <div class="card-body">
                            <?php if (empty($students)): ?>
                                <div class="text-center py-4">
                                    <i class="fas fa-user-graduate fa-3x text-muted mb-3"></i>
                                    <p class="text-muted">لا توجد بيانات طلاب مسجلة</p>
                                </div>
                            <?php else: ?>
                                <div class="table-responsive">
                                    <table class="table table-hover">
                                        <thead>
                                            <tr>
                                                <th>اسم الطالب</th>
                                                <th>المرحلة الدراسية</th>
                                                <th>ولي الأمر</th>
                                                <th>المجموعة</th>
                                                <th>نوع الدفع</th>
                                                <th>السعر</th>
                                                <th>الإجراءات</th>
                                            </tr>
                                        </thead>
                                        <tbody>
                                            <?php foreach ($students as $student): ?>
                                                <tr>
                                                    <td>
                                                        <strong><?= htmlspecialchars($student['name']) ?></strong>
                                                        <?php if ($student['phone']): ?>
                                                            <br><small class="text-muted"><?= htmlspecialchars($student['phone']) ?></small>
                                                        <?php endif; ?>
                                                    </td>
                                                    <td><?= htmlspecialchars($student['grade_level']) ?></td>
                                                    <td><?= htmlspecialchars($student['parent_name'] ?? 'غير محدد') ?></td>
                                                    <td>
                                                        <?php if ($student['group_name']): ?>
                                                            <?= htmlspecialchars($student['group_name']) ?>
                                                            <br>
                                                            <span class="badge badge-<?= $student['group_type'] ?>">
                                                                <?= $student['group_type'] === 'public' ? 'عامة' : ($student['group_type'] === 'private' ? 'خاصة' : 'فردية') ?>
                                                            </span>
                                                        <?php else: ?>
                                                            <span class="badge badge-individual">طالب فردي</span>
                                                        <?php endif; ?>
                                                    </td>
                                                    <td>
                                                        <span class="badge bg-<?= $student['payment_type'] === 'monthly' ? 'success' : 'info' ?>">
                                                            <?= $student['payment_type'] === 'monthly' ? 'شهري' : 'بالحصة' ?>
                                                        </span>
                                                    </td>
                                                    <td>
                                                        <?php if ($student['individual_price']): ?>
                                                            <?= number_format($student['individual_price'], 2) ?> ج.م
                                                        <?php else: ?>
                                                            حسب المجموعة
                                                        <?php endif; ?>
                                                    </td>
                                                    <td>
                                                        <div class="btn-group" role="group">
                                                            <a href="students.php?edit=<?= $student['student_id'] ?>" class="btn btn-sm btn-outline-primary">
                                                                <i class="fas fa-edit"></i>
                                                            </a>
                                                            <form method="POST" style="display: inline;" 
                                                                  onsubmit="return confirm('هل أنت متأكد من حذف الطالب؟')">
                                                                <input type="hidden" name="action" value="delete_student">
                                                                <input type="hidden" name="student_id" value="<?= $student['student_id'] ?>">
                                                                <button type="submit" class="btn btn-sm btn-outline-danger">
                                                                    <i class="fas fa-trash"></i>
                                                                </button>
                                                            </form>
                                                        </div>
                                                    </td>
                                                </tr>
                                            <?php endforeach; ?>
                                        </tbody>
                                    </table>
                                </div>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        // Show/hide individual price field based on group selection
        document.getElementById('group_id').addEventListener('change', function() {
            const individualPriceField = document.getElementById('individual_price');
            const individualPriceLabel = document.querySelector('label[for="individual_price"]');
            
            if (this.value === '') {
                individualPriceField.style.display = 'block';
                individualPriceLabel.style.display = 'block';
                individualPriceField.required = true;
            } else {
                individualPriceField.style.display = 'none';
                individualPriceLabel.style.display = 'none';
                individualPriceField.required = false;
                individualPriceField.value = '';
            }
        });
        
        // Initialize on page load
        document.getElementById('group_id').dispatchEvent(new Event('change'));
    </script>
</body>
</html>

