<?php
session_start();
include "../../../includes/functions.php";
check_login();

$error = $success = "";

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $name = sanitize_input($_POST['name']);
    $grade_level = sanitize_input($_POST['grade_level']);
    $phone = sanitize_input($_POST['phone']);
    $parent_code = sanitize_input($_POST['parent_code']);

    if (empty($name) || empty($grade_level) || empty($phone)) {
        $error = "يرجى ملء جميع الحقول المطلوبة";
    } else {
        $pdo->prepare("INSERT INTO students 
                       (name, grade_level, phone, parent_code, payment_status, teacher_id) 
                       VALUES (?, ?, ?, ?, 'unpaid', ?)")
            ->execute([$name, $grade_level, $phone, $parent_code, $_SESSION['teacher_id']]);
        $success = "تم إضافة الطالب بنجاح!";
    }
}
?>

<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <title>إضافة طالب جديد</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css"  rel="stylesheet">
</head>
<body>

<?php include "../../../includes/header.php"; ?>
<?php include "../../../includes/sidebar.php"; ?>

<div class="main-content container mt-4 pt-5">
    <div class="d-flex justify-content-between align-items-center mb-4">
        <h2><i class="fas fa-user-plus me-2"></i> إضافة طالب جديد</h2>
        <div class="welcome-message bg-light p-2 rounded shadow-sm">
            <i class="fas fa-user-shield me-2 text-primary"></i> مرحبًا بك <span class="fw-bold text-primary"><?= $_SESSION['name'] ?? 'المعلم' ?></span>
        </div>
    </div>

    <?php if ($error): ?>
        <div class="alert alert-danger"><?= $error ?></div>
    <?php endif; ?>
    <?php if ($success): ?>
        <div class="alert alert-success"><?= $success ?></div>
    <?php endif; ?>

    <form method="post">
        <div class="mb-3">
            <label class="form-label">الاسم</label>
            <input type="text" name="name" class="form-control" required>
        </div>
        <div class="mb-3">
            <label class="form-label">المرحلة الدراسية</label>
            <input type="text" name="grade_level" class="form-control" required>
        </div>
        <div class="mb-3">
            <label class="form-label">رقم الجوال</label>
            <input type="text" name="phone" class="form-control" required>
        </div>
        <div class="mb-3">
            <label class="form-label">كود ولي الأمر</label>
            <input type="text" name="parent_code" class="form-control">
        </div>
        <button type="submit" class="btn btn-primary">💾 حفظ الطالب</button>
    </form>
</div>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script> 
</body>
</html>