<?php
session_start();
include "../../../../includes/functions.php";
check_login();

if (!isset($_GET['id'])) {
    header("Location: view-students.php");
    exit;
}

$id = $_GET['id'];
$stmt = $pdo->prepare("SELECT * FROM students WHERE student_id = ? AND teacher_id = ?");
$stmt->execute([$id, $_SESSION['teacher_id']]);
$student = $stmt->fetch();

$error = $success = "";

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $name = sanitize_input($_POST['name']);
    $grade_level = sanitize_input($_POST['grade_level']);
    $phone = sanitize_input($_POST['phone']);
    $parent_code = sanitize_input($_POST['parent_code']);
    $payment_status = $_POST['payment_status'];

    if (empty($name) || empty($grade_level) || empty($phone)) {
        $error = "يرجى ملء جميع الحقول المطلوبة";
    } else {
        $pdo->prepare("UPDATE students SET name=?, grade_level=?, phone=?, parent_code=?, payment_status=? WHERE student_id=?")
            ->execute([$name, $grade_level, $phone, $parent_code, $payment_status, $id]);
        $success = "تم تحديث بيانات الطالب بنجاح!";
    }
}
?>

<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <title>تعديل بيانات الطالب</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css"  rel="stylesheet">
</head>
<body>

<?php include "../../../../includes/header.php"; ?>
<?php include "../../../../includes/sidebar.php"; ?>

<div class="main-content container mt-4 pt-5">
    <div class="d-flex justify-content-between align-items-center mb-4">
        <h2><i class="fas fa-user-edit me-2"></i> تعديل بيانات الطالب</h2>
        <div class="welcome-message bg-light p-2 rounded shadow-sm">
            <i class="fas fa-user-shield me-2 text-primary"></i> مرحبًا بك <span class="fw-bold text-primary"><?= $_SESSION['name'] ?? 'المعلم' ?></span>
        </div>
    </div>

    <?php if ($error): ?>
        <div class="alert alert-danger"><?= $error ?></div>
    <?php endif; ?>
    <?php if ($success): ?>
        <div class="alert alert-success"><?= $success ?></div>
    <?php endif; ?>

    <form method="post">
        <div class="mb-3">
            <label class="form-label">الاسم</label>
            <input type="text" name="name" value="<?= htmlspecialchars($student['name']) ?>" class="form-control" required>
        </div>
        <div class="mb-3">
            <label class="form-label">المرحلة الدراسية</label>
            <input type="text" name="grade_level" value="<?= $student['grade_level'] ?>" class="form-control" required>
        </div>
        <div class="mb-3">
            <label class="form-label">رقم الجوال</label>
            <input type="text" name="phone" value="<?= $student['phone'] ?>" class="form-control" required>
        </div>
        <div class="mb-3">
            <label class="form-label">كود ولي الأمر</label>
            <input type="text" name="parent_code" value="<?= $student['parent_code'] ?>" class="form-control">
        </div>
        <div class="mb-3">
            <label class="form-label">حالة الدفع</label>
            <select name="payment_status" class="form-select" required>
                <option value="paid" <?= $student['payment_status'] == 'paid' ? 'selected' : '' ?>>مدفوعة</option>
                <option value="unpaid" <?= $student['payment_status'] == 'unpaid' ? 'selected' : '' ?>>غير مدفوعة</option>
            </select>
        </div>
        <button type="submit" class="btn btn-primary">تحديث البيانات</button>
    </form>
</div>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script> 
</body>
</html>