<?php
/**
 * ملف اختبار بسيط لتشخيص مشاكل النظام
 * يساعد في تحديد سبب الأخطاء بدون استخدام أسماء ملفات قد تكون محظورة
 */

// تفعيل عرض الأخطاء
error_reporting(E_ALL);
ini_set('display_errors', 1);

echo "<h1>اختبار النظام</h1>";
echo "<hr>";

// فحص 1: معلومات PHP الأساسية
echo "<h3>1. معلومات PHP:</h3>";
echo "إصدار PHP: " . PHP_VERSION . "<br>";
echo "نظام التشغيل: " . PHP_OS . "<br>";
echo "الوقت الحالي: " . date('Y-m-d H:i:s') . "<br>";

echo "<hr>";

// فحص 2: الملفات المطلوبة
echo "<h3>2. فحص الملفات:</h3>";
$files = ['includes/db.php', 'includes/security.php', 'includes/.installed', 'index.php'];

foreach ($files as $file) {
    if (file_exists($file)) {
        echo "✅ $file - موجود<br>";
    } else {
        echo "❌ $file - غير موجود<br>";
    }
}

echo "<hr>";

// فحص 3: اختبار الاتصال بقاعدة البيانات
echo "<h3>3. اختبار قاعدة البيانات:</h3>";
try {
    if (file_exists('includes/db.php')) {
        // قراءة أول 100 حرف من ملف db.php للتحقق من وجود مشاكل
        $db_content = file_get_contents('includes/db.php', false, null, 0, 100);
        
        if (substr($db_content, 0, 5) !== '<?php') {
            echo "⚠️ تحذير: مشكلة في بداية ملف db.php<br>";
            echo "البداية: " . htmlspecialchars(substr($db_content, 0, 20)) . "<br>";
        } else {
            echo "✅ ملف db.php يبدأ بشكل صحيح<br>";
        }
        
        // محاولة تضمين الملف
        ob_start();
        include 'includes/db.php';
        $output = ob_get_clean();
        
        if (!empty($output)) {
            echo "⚠️ تحذير: ملف db.php ينتج إخراجاً:<br>";
            echo "<pre>" . htmlspecialchars($output) . "</pre>";
        } else {
            echo "✅ ملف db.php لا ينتج إخراجاً غير مرغوب<br>";
        }
        
        if (isset($pdo)) {
            echo "✅ متغير \$pdo موجود<br>";
            
            // اختبار استعلام بسيط
            $stmt = $pdo->query("SELECT 1 as test");
            $result = $stmt->fetch();
            echo "✅ اختبار الاستعلام ناجح: " . $result['test'] . "<br>";
            
        } else {
            echo "❌ متغير \$pdo غير موجود<br>";
        }
        
    } else {
        echo "❌ ملف db.php غير موجود<br>";
    }
} catch (Exception $e) {
    echo "❌ خطأ: " . $e->getMessage() . "<br>";
}

echo "<hr>";

// فحص 4: اختبار Headers
echo "<h3>4. فحص Headers:</h3>";
if (headers_sent($file, $line)) {
    echo "❌ تم إرسال Headers في: $file السطر: $line<br>";
} else {
    echo "✅ Headers لم يتم إرسالها بعد<br>";
}

echo "<hr>";

// فحص 5: متغيرات الخادم
echo "<h3>5. معلومات الخادم:</h3>";
echo "HTTP_HOST: " . ($_SERVER['HTTP_HOST'] ?? 'غير محدد') . "<br>";
echo "REQUEST_URI: " . ($_SERVER['REQUEST_URI'] ?? 'غير محدد') . "<br>";
echo "DOCUMENT_ROOT: " . ($_SERVER['DOCUMENT_ROOT'] ?? 'غير محدد') . "<br>";

echo "<hr>";
echo "<p><strong>انتهى الاختبار:</strong> " . date('Y-m-d H:i:s') . "</p>";

